/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.nop;

import java.math.BigDecimal;

import tools.descartes.dql.models.mapping.domain.AbstractSeriesResult;
import tools.descartes.dql.models.mapping.domain.ConfidenceInterval;
import tools.descartes.dql.models.mapping.domain.DomainFactory;
import tools.descartes.dql.models.mapping.domain.SeriesResultElement;

public class OnlineSeriesUpdateThread extends Thread {

	private AbstractSeriesResult seriesResult;
	private int maxNumberOfResults;
	private int tickrateInMillis;

	public OnlineSeriesUpdateThread(AbstractSeriesResult seriesResult, 
			int maxNumberOfResults, int tickrateInMillis) {
		this.seriesResult = seriesResult;
		this.maxNumberOfResults = maxNumberOfResults;
		this.tickrateInMillis = tickrateInMillis;
	}

	public void run() {
		for (int i = 0; i < maxNumberOfResults; i++) {
			SeriesResultElement newElem = DomainFactory.eINSTANCE.createSeriesResultElement();
			newElem.setX(BigDecimal.valueOf(i));
			newElem.setY(BigDecimal.valueOf(2 * Math.pow(i, 2.0) + 3 * i));
			ConfidenceInterval ci = DomainFactory.eINSTANCE.createConfidenceInterval();
			ci.setAccuracy(BigDecimal.valueOf(0.95));
			ci.setIntervalHalfLength(BigDecimal.valueOf(0.2));
			newElem.setConfidenceInterval(ci);
			seriesResult.getElements().add(newElem);
			sleep();
		}
	}

	private void sleep() {
		try {
			Thread.sleep(tickrateInMillis);
		} catch (InterruptedException e) {
			e.printStackTrace();
		}
	}

}
