/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector.pdr;

import java.io.File;
import java.util.HashMap;
import java.util.Map;

import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.IWorkspaceRoot;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IPath;
import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.resource.ResourceSet;
import org.eclipse.emf.ecore.resource.impl.ResourceSetImpl;

import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;
import tools.descartes.dql.models.repository.ObservationRepository;

public class RepositoryHelper {

	public static Map<String, Entity> buildEntityIndex(final EntityMapping mapping) {

		final Map<String, Entity> entityIndex = new HashMap<String, Entity>(mapping.getEntities().size());

		for (final Entity e : mapping.getEntities()) {
			entityIndex.put(e.getIdentifier(), e);
		}

		return entityIndex;
	}

	public static Map<String, Probe> buildProbeIndex(final Entity latestEntity) {
		final EList<Probe> probes = latestEntity.getProbes();
		final Map<String, Probe> latestProbeIndex = new HashMap<String, Probe>(probes.size());

		for (final Probe p : probes) {
			latestProbeIndex.put(p.getMetricName(), p);
		}

		return latestProbeIndex;
	}

	public static ObservationRepository loadModelInstance(final String modelLocation) {
		final ResourceSet resourceSet = new ResourceSetImpl();
		final URI modelURI = URI.createFileURI(modelLocation);
		final org.eclipse.emf.ecore.resource.Resource model = resourceSet.getResource(modelURI, true);

		return (ObservationRepository) model.getContents().get(0);
	}

	public static String qualifyModelLocation(final String modelLocation) {
		final IWorkspace workspace = ResourcesPlugin.getWorkspace();
		final IWorkspaceRoot root = workspace.getRoot();
		final IPath location = root.getLocation();
		final IPath modelPath = location.append(modelLocation);
		final File modelFile = modelPath.toFile();

		if (!modelFile.isFile()) {
			throw new IllegalArgumentException(modelLocation + " is not available");
		}

		return modelPath.toString();
	}

}
