package tools.descartes.dql.connector.vsp.reuse;

import static tools.descartes.dql.connector.vsp.VSphereSession.SVC_INST_NAME;

import java.util.Map;

import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLSession;
import javax.xml.ws.BindingProvider;

import org.apache.log4j.Logger;

import tools.descartes.dql.connector.vsp.VSphereSession;
import tools.descartes.dql.core.engine.util.DQLLogger;

import com.vmware.vim25.InvalidLocaleFaultMsg;
import com.vmware.vim25.InvalidLoginFaultMsg;
import com.vmware.vim25.ManagedObjectReference;
import com.vmware.vim25.RuntimeFaultFaultMsg;
import com.vmware.vim25.ServiceContent;
import com.vmware.vim25.VimPortType;
import com.vmware.vim25.VimService;

public class VSphereConnectionHelper {
	private final static Logger log = DQLLogger
			.getLogger(VSphereConnectionHelper.class.getName());

	public static void connect(final VSphereSession session, final String url,
			final String userName, final String password) {

		final HostnameVerifier hv = new HostnameVerifier() {
			@Override
			public boolean verify(final String urlHostName,
					final SSLSession session) {
				return true;
			}
		};

		try {
			TrustAllTrustManager.trustAllHttpsCertificates();
		} catch (Exception e) {
			log.error("TrustManager could not be installed. " + e.getMessage());
			e.printStackTrace();
		}

		HttpsURLConnection.setDefaultHostnameVerifier(hv);

		final ManagedObjectReference managedObjectReference = session
				.getManagedObjectReference();
		managedObjectReference.setType(SVC_INST_NAME);
		managedObjectReference.setValue(SVC_INST_NAME);

		session.setVimService(new VimService());
		final VimService vimService = session.getVimService();

		session.setVimPort(vimService.getVimPort());
		final VimPortType vimPort = session.getVimPort();

		final BindingProvider bindingProvider = (BindingProvider) vimPort;
		final Map<String, Object> ctxt = bindingProvider.getRequestContext();

		ctxt.put(BindingProvider.ENDPOINT_ADDRESS_PROPERTY, url);
		ctxt.put(BindingProvider.SESSION_MAINTAIN_PROPERTY, true);

		ServiceContent svcContent = null;
		
		try {
			svcContent = vimPort.retrieveServiceContent(managedObjectReference);
		} catch (RuntimeFaultFaultMsg e) {
			log.error("ServiceContent could not be retrieved. " + e.getMessage());
			e.printStackTrace();
		}
		session.setServiceContent(svcContent);

		try {
			vimPort.login(svcContent.getSessionManager(), userName, password, null);
		} catch (Exception e) {
			log.error("Login to vSphere failed. " + e.getMessage());
			e.printStackTrace();
		}
		
		session.setConnected(true);
	}

	public static void disconnect(final VSphereSession session)	{
		if (session.isConnected()) {
			final VimPortType vimPort = session.getVimPort();
			final ServiceContent serviceContent = session.getServiceContent();

			try {
				vimPort.logout(serviceContent.getSessionManager());
			} catch (RuntimeFaultFaultMsg e) {
				log.error("Logout from vSphere failed. " + e.getMessage());
				e.printStackTrace();
			}
		}

		session.setConnected(false);
	}
}
