/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.connector;

import java.util.List;

import tools.descartes.dql.models.mapping.mapping.EntityMapping;

/**
 * This interface defines the necessary methods to execute queries to detect
 * performance issues. The information retrieved can be used to identify
 * optimization potential of entities in performance model instances.
 * 
 * @author Fabian Gorsler <fabian.gorsler@student.kit.edu>
 */
public interface PerformanceIssueQueryConnector extends StatefulQueryConnector {
	/**
	 * Get the list of supported exploration strategy names
	 * 
	 * @return A list of exploration strategy names
	 */
	public List<String> getSupportedExplorationStrategyNames();

	/**
	 * Request the connector to compute and detect all possible bottlenecks in a
	 * performance model instance
	 * 
	 * @param request
	 *            A mapping model consisting of model entities and probes to be
	 *            computed
	 * @return A mapping model instance with bottlenecks
	 */
	public EntityMapping requestBottleneckDetection(EntityMapping request);

	/**
	 * Set the name of the exploration strategy used for parameter space
	 * exploration in a query with degrees of freedom
	 * 
	 * @see #getSupportedExplorationStrategyNames()
	 * 
	 * @param explorationStrategy
	 *            The name of an exploration strategy
	 */
	public void setBottleneckDetectionExplorationStrategy(String explorationStrategy);

	/**
	 * Test whether bottleneck detection requests are supported by the
	 * implementing class
	 * 
	 * @return True if bottleneck detection requests are supported, false
	 *         otherwise
	 */
	public boolean supportsBottleneckDetectionRequests();

}
