/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.core.engine.aggregates;

import java.util.Map;
import java.util.Set;

import tools.descartes.dql.models.mapping.domain.Entity;
import tools.descartes.dql.models.mapping.domain.Probe;
import tools.descartes.dql.models.mapping.mapping.EntityMapping;

/**
 * An AggregateProcessor is responsible for the calculation of a single
 * aggregate found in a query. The AggregateProcessor performs all necessary
 * steps during pre- and post-processing and instantiates an AggregateCalculator
 * usable to calculate the requested aggregate.
 * 
 * @author Fabian Gorsler <fabian.gorsler@student.kit.edu>
 * 
 */
public interface AggregateProcessor {
	/**
	 * Post-processing of an aggregate consisting of the calculation of the
	 * aggregate value
	 * 
	 * @param response
	 *            The response to be returned as query execution result
	 * @param entityIndex
	 *            An index structure to look-up entities by their identifier
	 * @param probeIndex
	 *            An index structure to look-up Probes by their metricName by
	 *            entity
	 */
	public void postProcess(EntityMapping response, Map<String, Entity> entityIndex,
			Map<String, Map<String, Probe>> probeIndex);

	/**
	 * Pre-processing of aggregates consists of determining if all required
	 * Probes are set on all required Entities
	 * 
	 * @param request
	 *            The request to be sent to the query connector
	 * @param aliasMap
	 *            A map of aliases for entities
	 * @return An index structure of Probes that need to be added to the request
	 *         in order to calculate the requested aggregate
	 */
	public Map<String, Set<String>> preProcess(EntityMapping request, Map<String, Entity> aliasMap);
}
