/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.core.engine.util;

import static tools.descartes.dql.connector.PerformanceMetricsQueryConnector.DOF_VARIATION_END_KEY;
import static tools.descartes.dql.connector.PerformanceMetricsQueryConnector.DOF_VARIATION_FUNCTION_KEY;
import static tools.descartes.dql.connector.PerformanceMetricsQueryConnector.DOF_VARIATION_INTERVAL_FUNCTION_VALUE;
import static tools.descartes.dql.connector.PerformanceMetricsQueryConnector.DOF_VARIATION_START_KEY;
import static tools.descartes.dql.connector.PerformanceMetricsQueryConnector.DOF_VARIATION_STEP_KEY;
import static tools.descartes.dql.connector.PerformanceMetricsQueryConnector.DOF_VARIATION_VALUE_FUNCTION_VALUE;
import static tools.descartes.dql.connector.PerformanceMetricsQueryConnector.DOF_VARIATION_VALUE_KEY;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

import org.eclipse.emf.common.util.URI;
import org.eclipse.emf.ecore.resource.Resource;
import org.eclipse.xtext.resource.XtextResource;
import org.eclipse.xtext.resource.XtextResourceSet;

import tools.descartes.dql.core.engine.Activator;
import tools.descartes.dql.lang.descartesQL.ConfigurationPropertiesClause;
import tools.descartes.dql.lang.descartesQL.ConfigurationPropertyClause;
import tools.descartes.dql.lang.descartesQL.DescartesQL;
import tools.descartes.dql.lang.descartesQL.IntervalVariationClause;
import tools.descartes.dql.lang.descartesQL.ValueVariationClause;

import com.google.inject.Injector;

public class QueryParserHelper {

	public static Properties intervalToProperties(final IntervalVariationClause interval) {
		final Properties properties = new Properties();

		properties.put(DOF_VARIATION_FUNCTION_KEY, DOF_VARIATION_INTERVAL_FUNCTION_VALUE);
		properties.put(DOF_VARIATION_START_KEY, interval.getStart());
		properties.put(DOF_VARIATION_END_KEY, interval.getEnd());
		properties.put(DOF_VARIATION_STEP_KEY, interval.getStep());

		return properties;
	}

	/**
	 * Parse a String into a query http://wiki.eclipse.org/Xtext/FAQ
	 * 
	 * @param query
	 *            The String representing a query
	 * @return The DescartesQL model representing the query
	 */
	public static DescartesQL stringToModel(final String query) {
		// To access Xtext run-time already deployed
		final Injector injector = Activator.getDqlInjector();

		// EMF magic further obscured by dependency injection of Xtext
		final XtextResourceSet resourceSet = injector.getInstance(XtextResourceSet.class);
		resourceSet.addLoadOption(XtextResource.OPTION_RESOLVE_ALL, Boolean.TRUE);
		final Resource resource = resourceSet.createResource(URI.createURI("dummy:/url.dql"));
		final InputStream in = new ByteArrayInputStream(query.getBytes());

		try {
			resource.load(in, resourceSet.getLoadOptions());
		} catch (final IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		final DescartesQL model = (DescartesQL) resource.getContents().get(0);

		return model;
	}

	public static Properties toFlatConfigurationPropertiesClause(final ConfigurationPropertiesClause clause) {
		final Properties properties = new Properties();
		StringBuilder sbKey = null;
		String key = null;

		// TODO: Omit call to this method in case of null values
		if (clause == null) {
			return properties;
		}

		for (final ConfigurationPropertyClause property : clause.getProperties()) {
			sbKey = new StringBuilder();

			for (final String part : property.getKey()) {
				sbKey.append(part).append(".");
			}

			key = sbKey.substring(0, sbKey.length() - 1);
			properties.put(key, property.getValue());
		}

		return properties;
	}

	public static Properties valueToProperties(final ValueVariationClause value) {
		final Properties properties = new Properties();

		properties.put(DOF_VARIATION_FUNCTION_KEY, DOF_VARIATION_VALUE_FUNCTION_VALUE);
		properties.put(DOF_VARIATION_VALUE_KEY, value.getValue().toString());

		return properties;
	}
}
