/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.lang.ui;

import java.util.Iterator;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.xtext.ide.editor.syntaxcoloring.IHighlightedPositionAcceptor;
import org.eclipse.xtext.ide.editor.syntaxcoloring.ISemanticHighlightingCalculator;
import org.eclipse.xtext.nodemodel.INode;
import org.eclipse.xtext.nodemodel.util.NodeModelUtils;
import org.eclipse.xtext.resource.XtextResource;
import org.eclipse.xtext.ui.editor.syntaxcoloring.DefaultHighlightingConfiguration;
import org.eclipse.xtext.util.CancelIndicator;

import tools.descartes.dql.lang.descartesQL.ChildrenClause;
import tools.descartes.dql.lang.descartesQL.DescartesQLPackage;
import tools.descartes.dql.lang.descartesQL.EntityReference;
import tools.descartes.dql.lang.descartesQL.FindClause;
import tools.descartes.dql.lang.descartesQL.ParentClause;

public class SyntaxHighlighting implements ISemanticHighlightingCalculator {

	@Override
	public void provideHighlightingFor(XtextResource arg0, IHighlightedPositionAcceptor arg1, CancelIndicator arg2) {
		for (Iterator<EObject> contents = arg0.getAllContents(); contents.hasNext();) {
			EObject element = contents.next();
			if (element instanceof EntityReference)
				highlightAsDataType(element, DescartesQLPackage.Literals.ENTITY_REFERENCE__TYPE, arg1);
			if (element instanceof ChildrenClause)
				highlightAsDefault(element, DescartesQLPackage.Literals.CHILDREN_CLAUSE__CONTENT, arg1);
			if (element instanceof ParentClause)
				highlightAsDefault(element, DescartesQLPackage.Literals.PARENT_CLAUSE__CONTENT, arg1);
			if (element instanceof FindClause)
				highlightAsDefault(element, DescartesQLPackage.Literals.FIND_CLAUSE__START, arg1);
		}
	}

	protected void highlightAsDefault(EObject element, EStructuralFeature feature,
			IHighlightedPositionAcceptor acceptor) {
		for (INode node : NodeModelUtils.findNodesForFeature(element, feature))
			acceptor.addPosition(node.getOffset(), node.getLength(), DefaultHighlightingConfiguration.DEFAULT_ID);
	}

	protected void highlightAsDataType(EObject element, EStructuralFeature feature,
			IHighlightedPositionAcceptor acceptor) {
		for (INode node : NodeModelUtils.findNodesForFeature(element, feature))
			acceptor.addPosition(node.getOffset(), node.getLength(), DefaultHighlightingConfiguration.KEYWORD_ID);
	}

}