/**
 * ==============================================
 *  DQL Adapter for SimQPN
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Simon Eismann, Juergen Walter and other contributors.
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.whatif.tests;

import java.io.File;
import java.io.IOException;
import java.util.List;

import org.junit.Test;

import tools.descartes.dql.models.mapping.mapping.EntityMapping;

public class FilterTests extends WhatIfQueryTest {

	@Test
	public void discreteFilterTest() throws IOException {
		String queryName = "discreteFilter.dql";
		queryName = File.separator + "WhatIfTestfiles" + File.separator + "Filtertests" + File.separator + queryName;
		List<EntityMapping> results = executeQuery(queryName);

		if (WRITE_RESULTS)
			writeResults(results, "Filter", "discrete");

		validateResults(results, "Filter", "discrete", 3);
	}

	@Test
	public void entitiyFilterTest() throws IOException {
		String queryName = "entityFilter.dql";
		queryName = File.separator + "WhatIfTestfiles" + File.separator + "Filtertests" + File.separator + queryName;
		List<EntityMapping> results = executeQuery(queryName);

		if (WRITE_RESULTS)
			writeResults(results, "Filter", "entity");

		validateResults(results, "Filter", "entity", 3);
	}

	@Test
	public void metricFilterTest() throws IOException {
		String queryName = "metricFilter.dql";
		queryName = File.separator + "WhatIfTestfiles" + File.separator + "Filtertests" + File.separator + queryName;
		List<EntityMapping> results = executeQuery(queryName);

		if (WRITE_RESULTS)
			writeResults(results, "Filter", "metric");

		validateResults(results, "Filter", "metric", 6);
	}

	@Test
	public void percentFilterTest() throws IOException {
		String queryName = "percentFilter.dql";
		queryName = File.separator + "WhatIfTestfiles" + File.separator + "Filtertests" + File.separator + queryName;
		List<EntityMapping> results = executeQuery(queryName);

		if (WRITE_RESULTS)
			writeResults(results, "Filter", "percent");

		validateResults(results, "Filter", "percent", 3);
	}

	@Test
	public void zeroFilterTest() throws IOException {
		String queryName = "zeroFilter.dql";
		queryName = File.separator + "WhatIfTestfiles" + File.separator + "Filtertests" + File.separator + queryName;
		List<EntityMapping> results = executeQuery(queryName);

		if (WRITE_RESULTS)
			writeResults(results, "Filter", "zero");

		validateResults(results, "Filter", "zero", 2);
	}
}
