/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.types;

import java.awt.Color;

import org.jfree.chart.ChartFactory;
import org.jfree.chart.JFreeChart;
import org.jfree.chart.plot.XYPlot;
import org.jfree.data.xy.XYSeries;
import org.jfree.data.xy.XYSeriesCollection;

import tools.descartes.pavo.result.AbstractQuantitativeResult;
import tools.descartes.pavo.result.ResultContainerPavo;
import tools.descartes.pavo.result.SeriesResultPavo;
import tools.descartes.pavo.result.ValueResultPavo;
import tools.descartes.pavo.util.Point;

/**
 * Visualizer for a ScatterPlot. Does not do any configurations on the controls.
 * Every result consisting out of series and values can be visualised as a
 * ScatterPlot
 * 
 * @author Maximilian König <max.c.koenig@t-online.de>
 * @since 2016
 */
public class ScatterPlot extends AbstractVisualizationType implements IVisualizationType {

	public ScatterPlot(ResultContainerPavo resultN) {
		super(resultN);
	}

	@Override
	public JFreeChart visualize() {
		XYSeriesCollection dataset = new XYSeriesCollection();

		JFreeChart chart = ChartFactory.createScatterPlot("", this.getXDescription(), this.getYDescription(), dataset);
		for (AbstractQuantitativeResult r : this.getResult().getResults()) {
			if (r instanceof SeriesResultPavo) {
				XYSeries series1 = new XYSeries(((SeriesResultPavo) r).getSeriesName());
				for (Point p : ((SeriesResultPavo) r).getValues()) {
				series1.add(p.getX(), p.getY());
				}
				dataset.addSeries(series1);
			}
		}
		XYPlot plot = (XYPlot) chart.getPlot();
		plot.setBackgroundPaint(Color.white);
		plot.setRangeGridlinePaint(Color.lightGray);
		plot.setDomainGridlinePaint(Color.lightGray);

		return chart;

	}

	@Override
	public boolean canVisualize() {
		for (AbstractQuantitativeResult r : this.getResult().getResults()) {
			if (!(r instanceof ValueResultPavo) && !(r instanceof SeriesResultPavo)) {
				return false;
			}
		}
		return true;
	}

}