/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.util;

import java.util.List;

/**
 * Class providing simple math helper, such as minimum, maximum and mean for
 * lists of series points. 
 * 
 * @author Maximilian König <max.c.koenig@t-online.de>
 * @since 2016
 */
public class MathHelper {

	/**
	 * @param list
	 *            List of all points
	 * @return returns the minimum y value of all points
	 */
	public static double getMin(List<Point> list) {
		double min = list.get(0).getY();
		for (Point p : list) {
			if (p.getY() < min)
				min = p.getY();
		}
		return min;
	}

	/**
	 * @param list
	 *            List of all points
	 * @return returns the maximal y value of all points
	 */
	public static double getMax(List<Point> list) {
		double max = list.get(0).getY();
		for (Point p : list) {
			if (p.getY() > max)
				max = p.getY();
		}
		return max;
	}

	/**
	 * @param list
	 *            List of all points
	 * @return returns the mean y value of all points
	 */
	public static double getMean(List<Point> list) {
		double mean = 0;
		int counter = 0;
		for (Point p : list) {
			mean = mean + p.getY();
			counter++;
		}
		return mean / counter;
	}
}