/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.pavo.view;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.Box;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.SwingConstants;

public class ParameterizedZoom {
	JFrame frame;
	JPanel contentPane;
	JLabel title;
	JButton safe;
	
	JLabel labelxMin;
	JLabel labelxMax;
	JLabel labelyMin;
	JLabel labelyMax;
	JLabel error1 = new JLabel("An error with the minimal x value occurred!");
	JLabel error2 = new JLabel("An error with the maximal x value occurred!");
	JLabel error3 = new JLabel("An error with the minimal y value occurred!");
	JLabel error4 = new JLabel("An error with the maximal y value occurred!");
	JLabel error5 = new JLabel("An error with the x values occurred (range invalid)");
	JLabel error6 = new JLabel("An error with the y values occurred (range invalid)");
	JTextField textxMin;
	JTextField textxMax;
	JTextField textyMin;
	JTextField textyMax;
	double minX, maxX, minY, maxY;
	
	public ParameterizedZoom(double minX, double maxX, double minY, double maxY)
	{
		error1.setForeground(Color.RED);
		error2.setForeground(Color.RED);
		error3.setForeground(Color.RED);
		error4.setForeground(Color.RED);
		error5.setForeground(Color.RED);
		error6.setForeground(Color.RED);
		this.maxX = maxX;
		this.minX = minX;
		this.maxY = maxY;
		this.minY = minY;
		textxMin = new JTextField(new String("" + minX));
		textxMin.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				checkAllValues();

			}
		});
		textxMax = new JTextField(new String("" + maxX));
		textxMax.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				checkAllValues();

			}
		});
		textyMin = new JTextField(new String("" + minY));
		textyMin.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				checkAllValues();

			}
		});
		textyMax = new JTextField(new String("" + maxY));
		textyMax.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent e) {
				checkAllValues();

			}
		});
		labelxMin = new JLabel("Minimum x: ");
		labelxMax = new JLabel("Maximum x: ");
		labelyMin = new JLabel("Minimum y: ");
		labelyMax = new JLabel("Maximum y: ");
		frame = new JFrame("Parameterized Zoom");
		contentPane = new JPanel();
		safe = new JButton("safe settings");
		title = new JLabel("Choose the shown range of your diagram:");
		frame.setVisible(true);
		frame.setLocationRelativeTo(null);
		instantiateGUI();
		
	}
	
	public boolean checkAllValues() {

		boolean checked = true;
		error1.setVisible(false);
		error2.setVisible(false);
		error3.setVisible(false);
		error4.setVisible(false);
		double xmintest = minX, xmaxtest = maxX, ymintest = minY, ymaxtest = maxY;


		try {
			xmintest = new Double(textxMin.getText());
		} catch (Exception e) {
			error1.setVisible(true);
			frame.pack();
			checked = false;
		}

		try {
			xmaxtest = new Double(textxMax.getText());
		} catch (Exception e) {
			error2.setVisible(true);
			frame.pack();
			checked = false;
		}
		try {
			ymintest = new Double(textyMin.getText());
		} catch (Exception e) {
			error3.setVisible(true);
			frame.pack();
			checked = false;
		}
		try {
			ymaxtest = new Double(textyMax.getText());
		} catch (Exception e) {
			error4.setVisible(true);
			frame.pack();
			checked = false;
		}

		if (xmintest > xmaxtest)
		{
			error5.setVisible(true);
			frame.pack();
			checked = false;
		}
		if (ymintest > ymaxtest) {
			error6.setVisible(true);
			frame.pack();
			checked = false;
		}
		return checked;



	}


	public void instantiateGUI() {

		contentPane = new JPanel();
		contentPane.setLayout(new BorderLayout(0, 0));
		frame.setContentPane(contentPane);
		
		title.setHorizontalAlignment(SwingConstants.CENTER);
		contentPane.add(title, BorderLayout.NORTH);

		Box vbox = Box.createVerticalBox();
		contentPane.add(vbox, BorderLayout.CENTER);

		Box hbox1 = Box.createHorizontalBox();

		hbox1.add(labelxMin);
		hbox1.add(textxMin);

		Box hbox2 = Box.createHorizontalBox();
		hbox2.add(labelxMax);
		hbox2.add(textxMax);

		Box hbox3 = Box.createHorizontalBox();
		hbox3.add(labelyMin);
		hbox3.add(textyMin);

		Box hbox4 = Box.createHorizontalBox();
		hbox4.add(labelyMax);
		hbox4.add(textyMax);

		vbox.add(hbox1);
		vbox.add(hbox2);
		vbox.add(hbox3);
		vbox.add(hbox4);
		vbox.add(error1);
		vbox.add(error2);
		vbox.add(error3);
		vbox.add(error4);
		vbox.add(error5);
		vbox.add(error6);
		error1.setVisible(false);
		error2.setVisible(false);
		error3.setVisible(false);
		error4.setVisible(false);
		error5.setVisible(false);
		error6.setVisible(false);
		contentPane.add(safe, BorderLayout.SOUTH);
		frame.pack();
	}

	public JFrame getFrame() {
		return frame;
	}

	public void setFrame(JFrame frame) {
		this.frame = frame;
	}

	public JPanel getContentPane() {
		return contentPane;
	}

	public void setContentPane(JPanel contentPane) {
		this.contentPane = contentPane;
	}

	public JLabel getTitle() {
		return title;
	}

	public void setTitle(JLabel title) {
		this.title = title;
	}

	public JButton getSafe() {
		return safe;
	}

	public void setSafe(JButton safe) {
		this.safe = safe;
	}

	public JLabel getLabelxMin() {
		return labelxMin;
	}

	public void setLabelxMin(JLabel labelxMin) {
		this.labelxMin = labelxMin;
	}

	public JLabel getLabelxMax() {
		return labelxMax;
	}

	public void setLabelxMax(JLabel labelxMax) {
		this.labelxMax = labelxMax;
	}

	public JLabel getLabelyMin() {
		return labelyMin;
	}

	public void setLabelyMin(JLabel labelyMin) {
		this.labelyMin = labelyMin;
	}

	public JLabel getLabelyMax() {
		return labelyMax;
	}

	public void setLabelyMax(JLabel labelyMax) {
		this.labelyMax = labelyMax;
	}

	public JTextField getTextxMin() {
		return textxMin;
	}

	public void setTextxMin(JTextField textxMin) {
		this.textxMin = textxMin;
	}

	public JTextField getTextxMax() {
		return textxMax;
	}

	public void setTextxMax(JTextField textxMax) {
		this.textxMax = textxMax;
	}

	public JTextField getTextyMin() {
		return textyMin;
	}

	public void setTextyMin(JTextField textyMin) {
		this.textyMin = textyMin;
	}

	public JTextField getTextyMax() {
		return textyMax;
	}

	public void setTextyMax(JTextField textyMax) {
		this.textyMax = textyMax;
	}

	public double[] getRangeValues() {
		double[] range = new double[4];
		range[0] = new Double(textxMin.getText());
		range[1] = new Double(textxMax.getText());
		range[2] = new Double(textyMin.getText());
		range[3] = new Double(textyMax.getText());
		return range;
	}

}
