/**
 * ==============================================
 *  DQL : Descartes Query Language
 * ==============================================
 *
 * (c) Copyright 2014-2016, by Juergen Walter, Fabian Gorsler, Fabian Brosig and other contributors.
 *
 * Project Info:   http://descartes.tools/dql
 *
 * All rights reserved. This software is made available under the terms of the
 * Eclipse Public License (EPL) v1.0 as published by the Eclipse Foundation
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * This software is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the Eclipse Public License (EPL)
 * for more details.
 *
 * You should have received a copy of the Eclipse Public License (EPL)
 * along with this software; if not visit http://www.eclipse.org or write to
 * Eclipse Foundation, Inc., 308 SW First Avenue, Suite 110, Portland, 97204 USA
 * Email: license (at) eclipse.org
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc.
 * in the United States and other countries.]
 */
package tools.descartes.dql.lang.services;

import com.google.inject.Singleton;
import com.google.inject.Inject;

import java.util.List;

import org.eclipse.xtext.*;
import org.eclipse.xtext.service.GrammarProvider;
import org.eclipse.xtext.service.AbstractElementFinder.*;

import org.eclipse.xtext.common.services.TerminalsGrammarAccess;

@Singleton
public class DescartesQLGrammarAccess extends AbstractGrammarElementFinder {
	
	
	public class DescartesQLElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.DescartesQL");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cQueryAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Alternatives cQueryAlternatives_0_0 = (Alternatives)cQueryAssignment_0.eContents().get(0);
		private final RuleCall cQueryModelStructureQueryParserRuleCall_0_0_0 = (RuleCall)cQueryAlternatives_0_0.eContents().get(0);
		private final RuleCall cQueryPerformanceMetricsQueryParserRuleCall_0_0_1 = (RuleCall)cQueryAlternatives_0_0.eContents().get(1);
		private final RuleCall cQueryPerformanceIssueQueryParserRuleCall_0_0_2 = (RuleCall)cQueryAlternatives_0_0.eContents().get(2);
		private final RuleCall cQueryConnectorCapabilityQueryParserRuleCall_0_0_3 = (RuleCall)cQueryAlternatives_0_0.eContents().get(3);
		private final RuleCall cQueryWhatIfQueryParserRuleCall_0_0_4 = (RuleCall)cQueryAlternatives_0_0.eContents().get(4);
		private final RuleCall cQueryGoalParserRuleCall_0_0_5 = (RuleCall)cQueryAlternatives_0_0.eContents().get(5);
		private final Keyword cSemicolonKeyword_1 = (Keyword)cGroup.eContents().get(1);
		
		//// @THESIS
		//DescartesQL:
		//	query=(ModelStructureQuery | PerformanceMetricsQuery | PerformanceIssueQuery | ConnectorCapabilityQuery | WhatIfQuery
		//	| Goal)
		//	';';
		@Override public ParserRule getRule() { return rule; }

		//query=(ModelStructureQuery | PerformanceMetricsQuery | PerformanceIssueQuery | ConnectorCapabilityQuery | WhatIfQuery |
		//Goal) ';'
		public Group getGroup() { return cGroup; }

		//query=(ModelStructureQuery | PerformanceMetricsQuery | PerformanceIssueQuery | ConnectorCapabilityQuery | WhatIfQuery |
		//Goal)
		public Assignment getQueryAssignment_0() { return cQueryAssignment_0; }

		//(ModelStructureQuery | PerformanceMetricsQuery | PerformanceIssueQuery | ConnectorCapabilityQuery | WhatIfQuery | Goal)
		public Alternatives getQueryAlternatives_0_0() { return cQueryAlternatives_0_0; }

		//ModelStructureQuery
		public RuleCall getQueryModelStructureQueryParserRuleCall_0_0_0() { return cQueryModelStructureQueryParserRuleCall_0_0_0; }

		//PerformanceMetricsQuery
		public RuleCall getQueryPerformanceMetricsQueryParserRuleCall_0_0_1() { return cQueryPerformanceMetricsQueryParserRuleCall_0_0_1; }

		//PerformanceIssueQuery
		public RuleCall getQueryPerformanceIssueQueryParserRuleCall_0_0_2() { return cQueryPerformanceIssueQueryParserRuleCall_0_0_2; }

		//ConnectorCapabilityQuery
		public RuleCall getQueryConnectorCapabilityQueryParserRuleCall_0_0_3() { return cQueryConnectorCapabilityQueryParserRuleCall_0_0_3; }

		//WhatIfQuery
		public RuleCall getQueryWhatIfQueryParserRuleCall_0_0_4() { return cQueryWhatIfQueryParserRuleCall_0_0_4; }

		//Goal
		public RuleCall getQueryGoalParserRuleCall_0_0_5() { return cQueryGoalParserRuleCall_0_0_5; }

		//';'
		public Keyword getSemicolonKeyword_1() { return cSemicolonKeyword_1; }
	}

	public class GoalElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.Goal");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cQueryTypeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Alternatives cQueryTypeAlternatives_0_0 = (Alternatives)cQueryTypeAssignment_0.eContents().get(0);
		private final Keyword cQueryTypeENSUREKeyword_0_0_0 = (Keyword)cQueryTypeAlternatives_0_0.eContents().get(0);
		private final Keyword cQueryTypeMONITORKeyword_0_0_1 = (Keyword)cQueryTypeAlternatives_0_0.eContents().get(1);
		private final Assignment cSlaQueryAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cSlaQuerySlaQueryParserRuleCall_1_0 = (RuleCall)cSlaQueryAssignment_1.eContents().get(0);
		private final Assignment cSloQueryAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cSloQuerySloQueryParserRuleCall_2_0 = (RuleCall)cSloQueryAssignment_2.eContents().get(0);
		private final Assignment cConstraintClauseAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cConstraintClauseConstraintClauseParserRuleCall_3_0 = (RuleCall)cConstraintClauseAssignment_3.eContents().get(0);
		private final Assignment cDofClauseAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cDofClauseDoFClauseParserRuleCall_4_0 = (RuleCall)cDofClauseAssignment_4.eContents().get(0);
		private final Assignment cForClauseAssignment_5 = (Assignment)cGroup.eContents().get(5);
		private final RuleCall cForClauseForClauseParserRuleCall_5_0 = (RuleCall)cForClauseAssignment_5.eContents().get(0);
		private final Assignment cUsingClauseAssignment_6 = (Assignment)cGroup.eContents().get(6);
		private final RuleCall cUsingClauseUsingClauseParserRuleCall_6_0 = (RuleCall)cUsingClauseAssignment_6.eContents().get(0);
		
		//Goal:
		//	queryType=('ENSURE' | 'MONITOR') slaQuery=SlaQuery sloQuery=SloQuery constraintClause=ConstraintClause?
		//	dofClause=DoFClause? forClause=ForClause? usingClause=UsingClause;
		@Override public ParserRule getRule() { return rule; }

		//queryType=('ENSURE' | 'MONITOR') slaQuery=SlaQuery sloQuery=SloQuery constraintClause=ConstraintClause?
		//dofClause=DoFClause? forClause=ForClause? usingClause=UsingClause
		public Group getGroup() { return cGroup; }

		//queryType=('ENSURE' | 'MONITOR')
		public Assignment getQueryTypeAssignment_0() { return cQueryTypeAssignment_0; }

		//('ENSURE' | 'MONITOR')
		public Alternatives getQueryTypeAlternatives_0_0() { return cQueryTypeAlternatives_0_0; }

		//'ENSURE'
		public Keyword getQueryTypeENSUREKeyword_0_0_0() { return cQueryTypeENSUREKeyword_0_0_0; }

		//'MONITOR'
		public Keyword getQueryTypeMONITORKeyword_0_0_1() { return cQueryTypeMONITORKeyword_0_0_1; }

		//slaQuery=SlaQuery
		public Assignment getSlaQueryAssignment_1() { return cSlaQueryAssignment_1; }

		//SlaQuery
		public RuleCall getSlaQuerySlaQueryParserRuleCall_1_0() { return cSlaQuerySlaQueryParserRuleCall_1_0; }

		//sloQuery=SloQuery
		public Assignment getSloQueryAssignment_2() { return cSloQueryAssignment_2; }

		//SloQuery
		public RuleCall getSloQuerySloQueryParserRuleCall_2_0() { return cSloQuerySloQueryParserRuleCall_2_0; }

		//constraintClause=ConstraintClause?
		public Assignment getConstraintClauseAssignment_3() { return cConstraintClauseAssignment_3; }

		//ConstraintClause
		public RuleCall getConstraintClauseConstraintClauseParserRuleCall_3_0() { return cConstraintClauseConstraintClauseParserRuleCall_3_0; }

		//dofClause=DoFClause?
		public Assignment getDofClauseAssignment_4() { return cDofClauseAssignment_4; }

		//DoFClause
		public RuleCall getDofClauseDoFClauseParserRuleCall_4_0() { return cDofClauseDoFClauseParserRuleCall_4_0; }

		//forClause=ForClause?
		public Assignment getForClauseAssignment_5() { return cForClauseAssignment_5; }

		//ForClause
		public RuleCall getForClauseForClauseParserRuleCall_5_0() { return cForClauseForClauseParserRuleCall_5_0; }

		//usingClause=UsingClause
		public Assignment getUsingClauseAssignment_6() { return cUsingClauseAssignment_6; }

		//UsingClause
		public RuleCall getUsingClauseUsingClauseParserRuleCall_6_0() { return cUsingClauseUsingClauseParserRuleCall_6_0; }
	}

	public class SlaQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.SlaQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cTypeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cTypeAGREEMENTSKeyword_0_0 = (Keyword)cTypeAssignment_0.eContents().get(0);
		private final Assignment cSlasAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cSlasSlaParserRuleCall_1_0 = (RuleCall)cSlasAssignment_1.eContents().get(0);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cCommaKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cSlasAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cSlasSlaParserRuleCall_2_1_0 = (RuleCall)cSlasAssignment_2_1.eContents().get(0);
		
		//SlaQuery:
		//	type='AGREEMENTS' slas+=Sla (',' slas+=Sla)*;
		@Override public ParserRule getRule() { return rule; }

		//type='AGREEMENTS' slas+=Sla (',' slas+=Sla)*
		public Group getGroup() { return cGroup; }

		//type='AGREEMENTS'
		public Assignment getTypeAssignment_0() { return cTypeAssignment_0; }

		//'AGREEMENTS'
		public Keyword getTypeAGREEMENTSKeyword_0_0() { return cTypeAGREEMENTSKeyword_0_0; }

		//slas+=Sla
		public Assignment getSlasAssignment_1() { return cSlasAssignment_1; }

		//Sla
		public RuleCall getSlasSlaParserRuleCall_1_0() { return cSlasSlaParserRuleCall_1_0; }

		//(',' slas+=Sla)*
		public Group getGroup_2() { return cGroup_2; }

		//','
		public Keyword getCommaKeyword_2_0() { return cCommaKeyword_2_0; }

		//slas+=Sla
		public Assignment getSlasAssignment_2_1() { return cSlasAssignment_2_1; }

		//Sla
		public RuleCall getSlasSlaParserRuleCall_2_1_0() { return cSlasSlaParserRuleCall_2_1_0; }
	}

	public class SloQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.SloQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cTypeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cTypeGOALSKeyword_0_0 = (Keyword)cTypeAssignment_0.eContents().get(0);
		private final Assignment cSlosAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cSlosSloParserRuleCall_1_0 = (RuleCall)cSlosAssignment_1.eContents().get(0);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cCommaKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cSlosAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cSlosSloParserRuleCall_2_1_0 = (RuleCall)cSlosAssignment_2_1.eContents().get(0);
		
		//SloQuery:
		//	type='GOALS' slos+=Slo (',' slos+=Slo)*;
		@Override public ParserRule getRule() { return rule; }

		//type='GOALS' slos+=Slo (',' slos+=Slo)*
		public Group getGroup() { return cGroup; }

		//type='GOALS'
		public Assignment getTypeAssignment_0() { return cTypeAssignment_0; }

		//'GOALS'
		public Keyword getTypeGOALSKeyword_0_0() { return cTypeGOALSKeyword_0_0; }

		//slos+=Slo
		public Assignment getSlosAssignment_1() { return cSlosAssignment_1; }

		//Slo
		public RuleCall getSlosSloParserRuleCall_1_0() { return cSlosSloParserRuleCall_1_0; }

		//(',' slos+=Slo)*
		public Group getGroup_2() { return cGroup_2; }

		//','
		public Keyword getCommaKeyword_2_0() { return cCommaKeyword_2_0; }

		//slos+=Slo
		public Assignment getSlosAssignment_2_1() { return cSlosAssignment_2_1; }

		//Slo
		public RuleCall getSlosSloParserRuleCall_2_1_0() { return cSlosSloParserRuleCall_2_1_0; }
	}

	public class SlaElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.Sla");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cNameAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cNameIDTerminalRuleCall_0_0 = (RuleCall)cNameAssignment_0.eContents().get(0);
		private final Keyword cCONTAINSKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Keyword cLeftParenthesisKeyword_2 = (Keyword)cGroup.eContents().get(2);
		private final Assignment cWeightedSloAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cWeightedSloWeightedSloParserRuleCall_3_0 = (RuleCall)cWeightedSloAssignment_3.eContents().get(0);
		private final Group cGroup_4 = (Group)cGroup.eContents().get(4);
		private final Keyword cCommaKeyword_4_0 = (Keyword)cGroup_4.eContents().get(0);
		private final Assignment cWeightedSloAssignment_4_1 = (Assignment)cGroup_4.eContents().get(1);
		private final RuleCall cWeightedSloWeightedSloParserRuleCall_4_1_0 = (RuleCall)cWeightedSloAssignment_4_1.eContents().get(0);
		private final Keyword cRightParenthesisKeyword_5 = (Keyword)cGroup.eContents().get(5);
		
		//Sla:
		//	name=ID 'CONTAINS' '(' weightedSlo+=WeightedSlo (',' weightedSlo+=WeightedSlo)* ')';
		@Override public ParserRule getRule() { return rule; }

		//name=ID 'CONTAINS' '(' weightedSlo+=WeightedSlo (',' weightedSlo+=WeightedSlo)* ')'
		public Group getGroup() { return cGroup; }

		//name=ID
		public Assignment getNameAssignment_0() { return cNameAssignment_0; }

		//ID
		public RuleCall getNameIDTerminalRuleCall_0_0() { return cNameIDTerminalRuleCall_0_0; }

		//'CONTAINS'
		public Keyword getCONTAINSKeyword_1() { return cCONTAINSKeyword_1; }

		//'('
		public Keyword getLeftParenthesisKeyword_2() { return cLeftParenthesisKeyword_2; }

		//weightedSlo+=WeightedSlo
		public Assignment getWeightedSloAssignment_3() { return cWeightedSloAssignment_3; }

		//WeightedSlo
		public RuleCall getWeightedSloWeightedSloParserRuleCall_3_0() { return cWeightedSloWeightedSloParserRuleCall_3_0; }

		//(',' weightedSlo+=WeightedSlo)*
		public Group getGroup_4() { return cGroup_4; }

		//','
		public Keyword getCommaKeyword_4_0() { return cCommaKeyword_4_0; }

		//weightedSlo+=WeightedSlo
		public Assignment getWeightedSloAssignment_4_1() { return cWeightedSloAssignment_4_1; }

		//WeightedSlo
		public RuleCall getWeightedSloWeightedSloParserRuleCall_4_1_0() { return cWeightedSloWeightedSloParserRuleCall_4_1_0; }

		//')'
		public Keyword getRightParenthesisKeyword_5() { return cRightParenthesisKeyword_5; }
	}

	public class SloElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.Slo");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cNameAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cNameIDTerminalRuleCall_0_0 = (RuleCall)cNameAssignment_0.eContents().get(0);
		private final Keyword cColonKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cMetricClauseTypeAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cMetricClauseTypeMetricClauseTypeParserRuleCall_2_0 = (RuleCall)cMetricClauseTypeAssignment_2.eContents().get(0);
		private final Assignment cComparatorAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cComparatorComparatorEnumRuleCall_3_0 = (RuleCall)cComparatorAssignment_3.eContents().get(0);
		private final Assignment cValueAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cValueVariableValueParserRuleCall_4_0 = (RuleCall)cValueAssignment_4.eContents().get(0);
		private final Assignment cFuzAssignment_5 = (Assignment)cGroup.eContents().get(5);
		private final RuleCall cFuzFuzzinessParserRuleCall_5_0 = (RuleCall)cFuzAssignment_5.eContents().get(0);
		private final Assignment cPenAssignment_6 = (Assignment)cGroup.eContents().get(6);
		private final RuleCall cPenPenaltyParserRuleCall_6_0 = (RuleCall)cPenAssignment_6.eContents().get(0);
		
		//Slo:
		//	name=ID ':' metricClauseType=MetricClauseType comparator=Comparator value=VariableValue fuz=Fuzziness?
		//	pen=Penalty?;
		@Override public ParserRule getRule() { return rule; }

		//// CPU,Service,Memory... . Metric . statistic Type 
		//name=ID ':' metricClauseType=MetricClauseType comparator=Comparator value=VariableValue fuz=Fuzziness? pen=Penalty?
		public Group getGroup() { return cGroup; }

		//// CPU,Service,Memory... . Metric . statistic Type 
		//name=ID
		public Assignment getNameAssignment_0() { return cNameAssignment_0; }

		//ID
		public RuleCall getNameIDTerminalRuleCall_0_0() { return cNameIDTerminalRuleCall_0_0; }

		//':'
		public Keyword getColonKeyword_1() { return cColonKeyword_1; }

		//metricClauseType=MetricClauseType
		public Assignment getMetricClauseTypeAssignment_2() { return cMetricClauseTypeAssignment_2; }

		//MetricClauseType
		public RuleCall getMetricClauseTypeMetricClauseTypeParserRuleCall_2_0() { return cMetricClauseTypeMetricClauseTypeParserRuleCall_2_0; }

		//comparator=Comparator
		public Assignment getComparatorAssignment_3() { return cComparatorAssignment_3; }

		//Comparator
		public RuleCall getComparatorComparatorEnumRuleCall_3_0() { return cComparatorComparatorEnumRuleCall_3_0; }

		//value=VariableValue
		public Assignment getValueAssignment_4() { return cValueAssignment_4; }

		//VariableValue
		public RuleCall getValueVariableValueParserRuleCall_4_0() { return cValueVariableValueParserRuleCall_4_0; }

		//fuz=Fuzziness?
		public Assignment getFuzAssignment_5() { return cFuzAssignment_5; }

		//Fuzziness
		public RuleCall getFuzFuzzinessParserRuleCall_5_0() { return cFuzFuzzinessParserRuleCall_5_0; }

		//pen=Penalty?
		public Assignment getPenAssignment_6() { return cPenAssignment_6; }

		//Penalty
		public RuleCall getPenPenaltyParserRuleCall_6_0() { return cPenPenaltyParserRuleCall_6_0; }
	}

	public class WeightedSloElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.WeightedSlo");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cSloAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final CrossReference cSloSloCrossReference_0_0 = (CrossReference)cSloAssignment_0.eContents().get(0);
		private final RuleCall cSloSloIDTerminalRuleCall_0_0_1 = (RuleCall)cSloSloCrossReference_0_0.eContents().get(1);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Keyword cAsteriskKeyword_1_0 = (Keyword)cGroup_1.eContents().get(0);
		private final Assignment cWeightAssignment_1_1 = (Assignment)cGroup_1.eContents().get(1);
		private final RuleCall cWeightINTTerminalRuleCall_1_1_0 = (RuleCall)cWeightAssignment_1_1.eContents().get(0);
		
		//WeightedSlo:
		//	slo=[Slo] ('*' weight=INT)?;
		@Override public ParserRule getRule() { return rule; }

		//slo=[Slo] ('*' weight=INT)?
		public Group getGroup() { return cGroup; }

		//slo=[Slo]
		public Assignment getSloAssignment_0() { return cSloAssignment_0; }

		//[Slo]
		public CrossReference getSloSloCrossReference_0_0() { return cSloSloCrossReference_0_0; }

		//ID
		public RuleCall getSloSloIDTerminalRuleCall_0_0_1() { return cSloSloIDTerminalRuleCall_0_0_1; }

		//('*' weight=INT)?
		public Group getGroup_1() { return cGroup_1; }

		//'*'
		public Keyword getAsteriskKeyword_1_0() { return cAsteriskKeyword_1_0; }

		//weight=INT
		public Assignment getWeightAssignment_1_1() { return cWeightAssignment_1_1; }

		//INT
		public RuleCall getWeightINTTerminalRuleCall_1_1_0() { return cWeightINTTerminalRuleCall_1_1_0; }
	}

	public class FuzzinessElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.Fuzziness");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cTypeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cTypeFUZZINESSKeyword_0_0 = (Keyword)cTypeAssignment_0.eContents().get(0);
		private final Assignment cDeviationAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cDeviationVariableValueParserRuleCall_1_0 = (RuleCall)cDeviationAssignment_1.eContents().get(0);
		
		//Fuzziness:
		//	type='FUZZINESS' deviation=VariableValue;
		@Override public ParserRule getRule() { return rule; }

		//type='FUZZINESS' deviation=VariableValue
		public Group getGroup() { return cGroup; }

		//type='FUZZINESS'
		public Assignment getTypeAssignment_0() { return cTypeAssignment_0; }

		//'FUZZINESS'
		public Keyword getTypeFUZZINESSKeyword_0_0() { return cTypeFUZZINESSKeyword_0_0; }

		//deviation=VariableValue
		public Assignment getDeviationAssignment_1() { return cDeviationAssignment_1; }

		//VariableValue
		public RuleCall getDeviationVariableValueParserRuleCall_1_0() { return cDeviationVariableValueParserRuleCall_1_0; }
	}

	public class PenaltyElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.Penalty");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cTypeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cTypePENALTYKeyword_0_0 = (Keyword)cTypeAssignment_0.eContents().get(0);
		private final Assignment cValueAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cValueDOUBLETerminalRuleCall_1_0 = (RuleCall)cValueAssignment_1.eContents().get(0);
		private final Assignment cCurrencyAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cCurrencyCurrencyEnumRuleCall_2_0 = (RuleCall)cCurrencyAssignment_2.eContents().get(0);
		private final Assignment cViolationAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cViolationViolationParserRuleCall_3_0 = (RuleCall)cViolationAssignment_3.eContents().get(0);
		
		//Penalty:
		//	type='PENALTY' value=DOUBLE currency=Currency violation=Violation?;
		@Override public ParserRule getRule() { return rule; }

		//type='PENALTY' value=DOUBLE currency=Currency violation=Violation?
		public Group getGroup() { return cGroup; }

		//type='PENALTY'
		public Assignment getTypeAssignment_0() { return cTypeAssignment_0; }

		//'PENALTY'
		public Keyword getTypePENALTYKeyword_0_0() { return cTypePENALTYKeyword_0_0; }

		//value=DOUBLE
		public Assignment getValueAssignment_1() { return cValueAssignment_1; }

		//DOUBLE
		public RuleCall getValueDOUBLETerminalRuleCall_1_0() { return cValueDOUBLETerminalRuleCall_1_0; }

		//currency=Currency
		public Assignment getCurrencyAssignment_2() { return cCurrencyAssignment_2; }

		//Currency
		public RuleCall getCurrencyCurrencyEnumRuleCall_2_0() { return cCurrencyCurrencyEnumRuleCall_2_0; }

		//violation=Violation?
		public Assignment getViolationAssignment_3() { return cViolationAssignment_3; }

		//Violation
		public RuleCall getViolationViolationParserRuleCall_3_0() { return cViolationViolationParserRuleCall_3_0; }
	}

	public class ViolationElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.Violation");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cPERKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cAmountAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cAmountINTTerminalRuleCall_1_0 = (RuleCall)cAmountAssignment_1.eContents().get(0);
		private final Keyword cVIOLATIONSKeyword_2 = (Keyword)cGroup.eContents().get(2);
		
		//Violation:
		//	'PER' amount=INT 'VIOLATIONS';
		@Override public ParserRule getRule() { return rule; }

		//'PER' amount=INT 'VIOLATIONS'
		public Group getGroup() { return cGroup; }

		//'PER'
		public Keyword getPERKeyword_0() { return cPERKeyword_0; }

		//amount=INT
		public Assignment getAmountAssignment_1() { return cAmountAssignment_1; }

		//INT
		public RuleCall getAmountINTTerminalRuleCall_1_0() { return cAmountINTTerminalRuleCall_1_0; }

		//'VIOLATIONS'
		public Keyword getVIOLATIONSKeyword_2() { return cVIOLATIONSKeyword_2; }
	}

	public class ModelStructureQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ModelStructureQuery");
		private final RuleCall cListQueryParserRuleCall = (RuleCall)rule.eContents().get(1);
		
		//// @THESIS
		//ModelStructureQuery:
		//	ListQuery;
		@Override public ParserRule getRule() { return rule; }

		//ListQuery
		public RuleCall getListQueryParserRuleCall() { return cListQueryParserRuleCall; }
	}

	public class PerformanceMetricsQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.PerformanceMetricsQuery");
		private final RuleCall cSelectQueryParserRuleCall = (RuleCall)rule.eContents().get(1);
		
		//// @THESIS
		//PerformanceMetricsQuery:
		//	SelectQuery;
		@Override public ParserRule getRule() { return rule; }

		//SelectQuery
		public RuleCall getSelectQueryParserRuleCall() { return cSelectQueryParserRuleCall; }
	}

	public class PerformanceIssueQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.PerformanceIssueQuery");
		private final RuleCall cDetectQueryParserRuleCall = (RuleCall)rule.eContents().get(1);
		
		//// @THESIS
		//PerformanceIssueQuery:
		//	DetectQuery;
		@Override public ParserRule getRule() { return rule; }

		//DetectQuery
		public RuleCall getDetectQueryParserRuleCall() { return cDetectQueryParserRuleCall; }
	}

	public class ConnectorCapabilityQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ConnectorCapabilityQuery");
		private final RuleCall cGetQueryParserRuleCall = (RuleCall)rule.eContents().get(1);
		
		//ConnectorCapabilityQuery:
		//	GetQuery;
		@Override public ParserRule getRule() { return rule; }

		//// TODO: Queries from this class are not yet implemented. The intention of this class is to expose connector-dependent information through the query interface, e.g. for documentation purposes. 
		//GetQuery
		public RuleCall getGetQueryParserRuleCall() { return cGetQueryParserRuleCall; }
	}

	public class ListQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ListQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cLISTKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cQueryTypeAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final Alternatives cQueryTypeAlternatives_1_0 = (Alternatives)cQueryTypeAssignment_1.eContents().get(0);
		private final RuleCall cQueryTypeListEntitiesQueryParserRuleCall_1_0_0 = (RuleCall)cQueryTypeAlternatives_1_0.eContents().get(0);
		private final RuleCall cQueryTypeListMetricsQueryParserRuleCall_1_0_1 = (RuleCall)cQueryTypeAlternatives_1_0.eContents().get(1);
		private final RuleCall cQueryTypeListDoFQueryParserRuleCall_1_0_2 = (RuleCall)cQueryTypeAlternatives_1_0.eContents().get(2);
		private final Assignment cFilterClauseAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cFilterClauseFilterClauseParserRuleCall_2_0 = (RuleCall)cFilterClauseAssignment_2.eContents().get(0);
		private final Assignment cUsingClauseAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cUsingClauseUsingClauseParserRuleCall_3_0 = (RuleCall)cUsingClauseAssignment_3.eContents().get(0);
		
		//// @THESIS
		//ListQuery:
		//	'LIST' queryType=(ListEntitiesQuery | ListMetricsQuery | ListDoFQuery) filterClause=FilterClause?
		//	usingClause=UsingClause;
		@Override public ParserRule getRule() { return rule; }

		//'LIST' queryType=(ListEntitiesQuery | ListMetricsQuery | ListDoFQuery) filterClause=FilterClause?
		//usingClause=UsingClause
		public Group getGroup() { return cGroup; }

		//'LIST'
		public Keyword getLISTKeyword_0() { return cLISTKeyword_0; }

		//queryType=(ListEntitiesQuery | ListMetricsQuery | ListDoFQuery)
		public Assignment getQueryTypeAssignment_1() { return cQueryTypeAssignment_1; }

		//(ListEntitiesQuery | ListMetricsQuery | ListDoFQuery)
		public Alternatives getQueryTypeAlternatives_1_0() { return cQueryTypeAlternatives_1_0; }

		//ListEntitiesQuery
		public RuleCall getQueryTypeListEntitiesQueryParserRuleCall_1_0_0() { return cQueryTypeListEntitiesQueryParserRuleCall_1_0_0; }

		//ListMetricsQuery
		public RuleCall getQueryTypeListMetricsQueryParserRuleCall_1_0_1() { return cQueryTypeListMetricsQueryParserRuleCall_1_0_1; }

		//ListDoFQuery
		public RuleCall getQueryTypeListDoFQueryParserRuleCall_1_0_2() { return cQueryTypeListDoFQueryParserRuleCall_1_0_2; }

		//filterClause=FilterClause?
		public Assignment getFilterClauseAssignment_2() { return cFilterClauseAssignment_2; }

		//FilterClause
		public RuleCall getFilterClauseFilterClauseParserRuleCall_2_0() { return cFilterClauseFilterClauseParserRuleCall_2_0; }

		//usingClause=UsingClause
		public Assignment getUsingClauseAssignment_3() { return cUsingClauseAssignment_3; }

		//UsingClause
		public RuleCall getUsingClauseUsingClauseParserRuleCall_3_0() { return cUsingClauseUsingClauseParserRuleCall_3_0; }
	}

	public class GetQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.GetQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cGETKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cQueryTapeAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final Alternatives cQueryTapeAlternatives_1_0 = (Alternatives)cQueryTapeAssignment_1.eContents().get(0);
		private final RuleCall cQueryTapeGetExplorationStrategiesQueryParserRuleCall_1_0_0 = (RuleCall)cQueryTapeAlternatives_1_0.eContents().get(0);
		private final RuleCall cQueryTapeGetTimeUnitsQueryParserRuleCall_1_0_1 = (RuleCall)cQueryTapeAlternatives_1_0.eContents().get(1);
		private final RuleCall cQueryTapeGetConstraintsQueryParserRuleCall_1_0_2 = (RuleCall)cQueryTapeAlternatives_1_0.eContents().get(2);
		private final Assignment cUsingClauseAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cUsingClauseUsingClauseParserRuleCall_2_0 = (RuleCall)cUsingClauseAssignment_2.eContents().get(0);
		
		//GetQuery:
		//	'GET' queryTape=(GetExplorationStrategiesQuery | GetTimeUnitsQuery | GetConstraintsQuery) usingClause=UsingClause;
		@Override public ParserRule getRule() { return rule; }

		//'GET' queryTape=(GetExplorationStrategiesQuery | GetTimeUnitsQuery | GetConstraintsQuery) usingClause=UsingClause
		public Group getGroup() { return cGroup; }

		//'GET'
		public Keyword getGETKeyword_0() { return cGETKeyword_0; }

		//queryTape=(GetExplorationStrategiesQuery | GetTimeUnitsQuery | GetConstraintsQuery)
		public Assignment getQueryTapeAssignment_1() { return cQueryTapeAssignment_1; }

		//(GetExplorationStrategiesQuery | GetTimeUnitsQuery | GetConstraintsQuery)
		public Alternatives getQueryTapeAlternatives_1_0() { return cQueryTapeAlternatives_1_0; }

		//GetExplorationStrategiesQuery
		public RuleCall getQueryTapeGetExplorationStrategiesQueryParserRuleCall_1_0_0() { return cQueryTapeGetExplorationStrategiesQueryParserRuleCall_1_0_0; }

		//GetTimeUnitsQuery
		public RuleCall getQueryTapeGetTimeUnitsQueryParserRuleCall_1_0_1() { return cQueryTapeGetTimeUnitsQueryParserRuleCall_1_0_1; }

		//GetConstraintsQuery
		public RuleCall getQueryTapeGetConstraintsQueryParserRuleCall_1_0_2() { return cQueryTapeGetConstraintsQueryParserRuleCall_1_0_2; }

		//usingClause=UsingClause
		public Assignment getUsingClauseAssignment_2() { return cUsingClauseAssignment_2; }

		//UsingClause
		public RuleCall getUsingClauseUsingClauseParserRuleCall_2_0() { return cUsingClauseUsingClauseParserRuleCall_2_0; }
	}

	public class GetConstraintsQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.GetConstraintsQuery");
		private final Assignment cModeAssignment = (Assignment)rule.eContents().get(1);
		private final Keyword cModeCONSTRAINTSKeyword_0 = (Keyword)cModeAssignment.eContents().get(0);
		
		//GetConstraintsQuery:
		//	mode="CONSTRAINTS";
		@Override public ParserRule getRule() { return rule; }

		//mode="CONSTRAINTS"
		public Assignment getModeAssignment() { return cModeAssignment; }

		//"CONSTRAINTS"
		public Keyword getModeCONSTRAINTSKeyword_0() { return cModeCONSTRAINTSKeyword_0; }
	}

	public class GetExplorationStrategiesQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.GetExplorationStrategiesQuery");
		private final Assignment cModeAssignment = (Assignment)rule.eContents().get(1);
		private final Keyword cModeEXPLORATIONSTRATEGIESKeyword_0 = (Keyword)cModeAssignment.eContents().get(0);
		
		//GetExplorationStrategiesQuery:
		//	mode="EXPLORATION STRATEGIES";
		@Override public ParserRule getRule() { return rule; }

		//mode="EXPLORATION STRATEGIES"
		public Assignment getModeAssignment() { return cModeAssignment; }

		//"EXPLORATION STRATEGIES"
		public Keyword getModeEXPLORATIONSTRATEGIESKeyword_0() { return cModeEXPLORATIONSTRATEGIESKeyword_0; }
	}

	public class GetTimeUnitsQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.GetTimeUnitsQuery");
		private final Assignment cModeAssignment = (Assignment)rule.eContents().get(1);
		private final Keyword cModeTIMEUNITSKeyword_0 = (Keyword)cModeAssignment.eContents().get(0);
		
		//GetTimeUnitsQuery:
		//	mode="TIME UNITS";
		@Override public ParserRule getRule() { return rule; }

		//mode="TIME UNITS"
		public Assignment getModeAssignment() { return cModeAssignment; }

		//"TIME UNITS"
		public Keyword getModeTIMEUNITSKeyword_0() { return cModeTIMEUNITSKeyword_0; }
	}

	public class ListDoFQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ListDoFQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeDOFKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cWithClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cWithClauseWithClauseParserRuleCall_1_0 = (RuleCall)cWithClauseAssignment_1.eContents().get(0);
		
		//// @THESIS
		//ListDoFQuery:
		//	mode="DOF" withClause=WithClause?;
		@Override public ParserRule getRule() { return rule; }

		//mode="DOF" withClause=WithClause?
		public Group getGroup() { return cGroup; }

		//mode="DOF"
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//"DOF"
		public Keyword getModeDOFKeyword_0_0() { return cModeDOFKeyword_0_0; }

		//withClause=WithClause?
		public Assignment getWithClauseAssignment_1() { return cWithClauseAssignment_1; }

		//WithClause
		public RuleCall getWithClauseWithClauseParserRuleCall_1_0() { return cWithClauseWithClauseParserRuleCall_1_0; }
	}

	public class ListEntitiesQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ListEntitiesQuery");
		private final Assignment cModeAssignment = (Assignment)rule.eContents().get(1);
		private final Keyword cModeENTITIESKeyword_0 = (Keyword)cModeAssignment.eContents().get(0);
		
		//// @THESIS
		//ListEntitiesQuery:
		//	mode='ENTITIES';
		@Override public ParserRule getRule() { return rule; }

		//mode='ENTITIES'
		public Assignment getModeAssignment() { return cModeAssignment; }

		//'ENTITIES'
		public Keyword getModeENTITIESKeyword_0() { return cModeENTITIESKeyword_0; }
	}

	public class ListMetricsQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ListMetricsQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeMETRICSKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Keyword cLeftParenthesisKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cEntityReferenceClauseAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cEntityReferenceClauseEntityReferenceClauseParserRuleCall_2_0 = (RuleCall)cEntityReferenceClauseAssignment_2.eContents().get(0);
		private final Keyword cRightParenthesisKeyword_3 = (Keyword)cGroup.eContents().get(3);
		
		//// @THESIS
		//ListMetricsQuery:
		//	mode='METRICS' '(' entityReferenceClause=EntityReferenceClause ')';
		@Override public ParserRule getRule() { return rule; }

		//mode='METRICS' '(' entityReferenceClause=EntityReferenceClause ')'
		public Group getGroup() { return cGroup; }

		//mode='METRICS'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'METRICS'
		public Keyword getModeMETRICSKeyword_0_0() { return cModeMETRICSKeyword_0_0; }

		//'('
		public Keyword getLeftParenthesisKeyword_1() { return cLeftParenthesisKeyword_1; }

		//entityReferenceClause=EntityReferenceClause
		public Assignment getEntityReferenceClauseAssignment_2() { return cEntityReferenceClauseAssignment_2; }

		//EntityReferenceClause
		public RuleCall getEntityReferenceClauseEntityReferenceClauseParserRuleCall_2_0() { return cEntityReferenceClauseEntityReferenceClauseParserRuleCall_2_0; }

		//')'
		public Keyword getRightParenthesisKeyword_3() { return cRightParenthesisKeyword_3; }
	}

	public class SelectQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.SelectQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cSELECTKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cMetricReferenceClausesAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cMetricReferenceClausesMetricReferenceClausesParserRuleCall_1_0 = (RuleCall)cMetricReferenceClausesAssignment_1.eContents().get(0);
		private final Assignment cConstraintClauseAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cConstraintClauseConstraintClauseParserRuleCall_2_0 = (RuleCall)cConstraintClauseAssignment_2.eContents().get(0);
		private final Assignment cDofClauseAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cDofClauseDoFClauseParserRuleCall_3_0 = (RuleCall)cDofClauseAssignment_3.eContents().get(0);
		private final Assignment cForClauseAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cForClauseForClauseParserRuleCall_4_0 = (RuleCall)cForClauseAssignment_4.eContents().get(0);
		private final Assignment cUsingClauseAssignment_5 = (Assignment)cGroup.eContents().get(5);
		private final RuleCall cUsingClauseUsingClauseParserRuleCall_5_0 = (RuleCall)cUsingClauseAssignment_5.eContents().get(0);
		private final Assignment cObserveClauseAssignment_6 = (Assignment)cGroup.eContents().get(6);
		private final RuleCall cObserveClauseObserveClauseParserRuleCall_6_0 = (RuleCall)cObserveClauseAssignment_6.eContents().get(0);
		
		//// @THESIS
		//SelectQuery:
		//	'SELECT' metricReferenceClauses=MetricReferenceClauses constraintClause=ConstraintClause? dofClause=DoFClause?
		//	forClause=ForClause usingClause=UsingClause observeClause=ObserveClause?;
		@Override public ParserRule getRule() { return rule; }

		//'SELECT' metricReferenceClauses=MetricReferenceClauses constraintClause=ConstraintClause? dofClause=DoFClause?
		//forClause=ForClause usingClause=UsingClause observeClause=ObserveClause?
		public Group getGroup() { return cGroup; }

		//'SELECT'
		public Keyword getSELECTKeyword_0() { return cSELECTKeyword_0; }

		//metricReferenceClauses=MetricReferenceClauses
		public Assignment getMetricReferenceClausesAssignment_1() { return cMetricReferenceClausesAssignment_1; }

		//MetricReferenceClauses
		public RuleCall getMetricReferenceClausesMetricReferenceClausesParserRuleCall_1_0() { return cMetricReferenceClausesMetricReferenceClausesParserRuleCall_1_0; }

		//constraintClause=ConstraintClause?
		public Assignment getConstraintClauseAssignment_2() { return cConstraintClauseAssignment_2; }

		//ConstraintClause
		public RuleCall getConstraintClauseConstraintClauseParserRuleCall_2_0() { return cConstraintClauseConstraintClauseParserRuleCall_2_0; }

		//dofClause=DoFClause?
		public Assignment getDofClauseAssignment_3() { return cDofClauseAssignment_3; }

		//DoFClause
		public RuleCall getDofClauseDoFClauseParserRuleCall_3_0() { return cDofClauseDoFClauseParserRuleCall_3_0; }

		//forClause=ForClause
		public Assignment getForClauseAssignment_4() { return cForClauseAssignment_4; }

		//ForClause
		public RuleCall getForClauseForClauseParserRuleCall_4_0() { return cForClauseForClauseParserRuleCall_4_0; }

		//usingClause=UsingClause
		public Assignment getUsingClauseAssignment_5() { return cUsingClauseAssignment_5; }

		//UsingClause
		public RuleCall getUsingClauseUsingClauseParserRuleCall_5_0() { return cUsingClauseUsingClauseParserRuleCall_5_0; }

		//observeClause=ObserveClause?
		public Assignment getObserveClauseAssignment_6() { return cObserveClauseAssignment_6; }

		//ObserveClause
		public RuleCall getObserveClauseObserveClauseParserRuleCall_6_0() { return cObserveClauseObserveClauseParserRuleCall_6_0; }
	}

	public class MetricReferenceClausesElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.MetricReferenceClauses");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cMetricClauseTypesAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cMetricClauseTypesMetricClauseTypeParserRuleCall_0_0 = (RuleCall)cMetricClauseTypesAssignment_0.eContents().get(0);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Keyword cCommaKeyword_1_0 = (Keyword)cGroup_1.eContents().get(0);
		private final Assignment cMetricClauseTypesAssignment_1_1 = (Assignment)cGroup_1.eContents().get(1);
		private final RuleCall cMetricClauseTypesMetricClauseTypeParserRuleCall_1_1_0 = (RuleCall)cMetricClauseTypesAssignment_1_1.eContents().get(0);
		
		//// @THESIS
		//MetricReferenceClauses:
		//	metricClauseTypes+=MetricClauseType (',' metricClauseTypes+=MetricClauseType)*;
		@Override public ParserRule getRule() { return rule; }

		//metricClauseTypes+=MetricClauseType (',' metricClauseTypes+=MetricClauseType)*
		public Group getGroup() { return cGroup; }

		//metricClauseTypes+=MetricClauseType
		public Assignment getMetricClauseTypesAssignment_0() { return cMetricClauseTypesAssignment_0; }

		//MetricClauseType
		public RuleCall getMetricClauseTypesMetricClauseTypeParserRuleCall_0_0() { return cMetricClauseTypesMetricClauseTypeParserRuleCall_0_0; }

		//(',' metricClauseTypes+=MetricClauseType)*
		public Group getGroup_1() { return cGroup_1; }

		//','
		public Keyword getCommaKeyword_1_0() { return cCommaKeyword_1_0; }

		//metricClauseTypes+=MetricClauseType
		public Assignment getMetricClauseTypesAssignment_1_1() { return cMetricClauseTypesAssignment_1_1; }

		//MetricClauseType
		public RuleCall getMetricClauseTypesMetricClauseTypeParserRuleCall_1_1_0() { return cMetricClauseTypesMetricClauseTypeParserRuleCall_1_1_0; }
	}

	public class MetricClauseTypeElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.MetricClauseType");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cMetricClauseParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cAggregateMetricClauseParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		
		//// @THESIS
		//MetricClauseType:
		//	MetricClause | AggregateMetricClause;
		@Override public ParserRule getRule() { return rule; }

		//MetricClause | AggregateMetricClause
		public Alternatives getAlternatives() { return cAlternatives; }

		//MetricClause
		public RuleCall getMetricClauseParserRuleCall_0() { return cMetricClauseParserRuleCall_0; }

		//AggregateMetricClause
		public RuleCall getAggregateMetricClauseParserRuleCall_1() { return cAggregateMetricClauseParserRuleCall_1; }
	}

	public class DetectQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.DetectQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cDETECTKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cQueryTypeAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cQueryTypeDetectBottlenecksQueryParserRuleCall_1_0 = (RuleCall)cQueryTypeAssignment_1.eContents().get(0);
		
		//// @THESIS
		//DetectQuery:
		//	'DETECT' queryType=DetectBottlenecksQuery;
		@Override public ParserRule getRule() { return rule; }

		//'DETECT' queryType=DetectBottlenecksQuery
		public Group getGroup() { return cGroup; }

		//'DETECT'
		public Keyword getDETECTKeyword_0() { return cDETECTKeyword_0; }

		//queryType=DetectBottlenecksQuery
		public Assignment getQueryTypeAssignment_1() { return cQueryTypeAssignment_1; }

		//DetectBottlenecksQuery
		public RuleCall getQueryTypeDetectBottlenecksQueryParserRuleCall_1_0() { return cQueryTypeDetectBottlenecksQueryParserRuleCall_1_0; }
	}

	public class DetectBottlenecksQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.DetectBottlenecksQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cBOTTLENECKSKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cDofClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cDofClauseDoFClauseParserRuleCall_1_0 = (RuleCall)cDofClauseAssignment_1.eContents().get(0);
		private final Assignment cUsingClauseAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cUsingClauseUsingClauseParserRuleCall_2_0 = (RuleCall)cUsingClauseAssignment_2.eContents().get(0);
		
		//// @THESIS
		//DetectBottlenecksQuery:
		//	'BOTTLENECKS' dofClause=DoFClause usingClause=UsingClause;
		@Override public ParserRule getRule() { return rule; }

		//'BOTTLENECKS' dofClause=DoFClause usingClause=UsingClause
		public Group getGroup() { return cGroup; }

		//'BOTTLENECKS'
		public Keyword getBOTTLENECKSKeyword_0() { return cBOTTLENECKSKeyword_0; }

		//dofClause=DoFClause
		public Assignment getDofClauseAssignment_1() { return cDofClauseAssignment_1; }

		//DoFClause
		public RuleCall getDofClauseDoFClauseParserRuleCall_1_0() { return cDofClauseDoFClauseParserRuleCall_1_0; }

		//usingClause=UsingClause
		public Assignment getUsingClauseAssignment_2() { return cUsingClauseAssignment_2; }

		//UsingClause
		public RuleCall getUsingClauseUsingClauseParserRuleCall_2_0() { return cUsingClauseUsingClauseParserRuleCall_2_0; }
	}

	public class ConstraintClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ConstraintClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cCONSTRAINEDASKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cTypeAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cTypeSTRINGTerminalRuleCall_1_0 = (RuleCall)cTypeAssignment_1.eContents().get(0);
		
		/// *
		// * Clause to specify a constraint on the model solver
		// * / // @THESIS
		//ConstraintClause:
		//	'CONSTRAINED AS' type=STRING;
		@Override public ParserRule getRule() { return rule; }

		//'CONSTRAINED AS' type=STRING
		public Group getGroup() { return cGroup; }

		//'CONSTRAINED AS'
		public Keyword getCONSTRAINEDASKeyword_0() { return cCONSTRAINEDASKeyword_0; }

		//type=STRING
		public Assignment getTypeAssignment_1() { return cTypeAssignment_1; }

		//STRING
		public RuleCall getTypeSTRINGTerminalRuleCall_1_0() { return cTypeSTRINGTerminalRuleCall_1_0; }
	}

	public class DoFClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.DoFClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeEVALUATEDOFKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cVaryingClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cVaryingClauseVaryingClauseParserRuleCall_1_0 = (RuleCall)cVaryingClauseAssignment_1.eContents().get(0);
		private final Assignment cExplorationStrategyAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cExplorationStrategyExplorationStrategyClauseParserRuleCall_2_0 = (RuleCall)cExplorationStrategyAssignment_2.eContents().get(0);
		private final Assignment cConstraintClauseAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cConstraintClauseConstraintClauseParserRuleCall_3_0 = (RuleCall)cConstraintClauseAssignment_3.eContents().get(0);
		private final Assignment cWithClauseAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cWithClauseWithClauseParserRuleCall_4_0 = (RuleCall)cWithClauseAssignment_4.eContents().get(0);
		
		/// *
		// * Clause for expressing DoF 
		// * / // @THESIS
		//DoFClause:
		//	mode='EVALUATE DOF' varyingClause=VaryingClause? explorationStrategy=ExplorationStrategyClause?
		//	constraintClause=ConstraintClause? withClause=WithClause?;
		@Override public ParserRule getRule() { return rule; }

		//mode='EVALUATE DOF' varyingClause=VaryingClause? explorationStrategy=ExplorationStrategyClause?
		//constraintClause=ConstraintClause? withClause=WithClause?
		public Group getGroup() { return cGroup; }

		//mode='EVALUATE DOF'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'EVALUATE DOF'
		public Keyword getModeEVALUATEDOFKeyword_0_0() { return cModeEVALUATEDOFKeyword_0_0; }

		//varyingClause=VaryingClause?
		public Assignment getVaryingClauseAssignment_1() { return cVaryingClauseAssignment_1; }

		//VaryingClause
		public RuleCall getVaryingClauseVaryingClauseParserRuleCall_1_0() { return cVaryingClauseVaryingClauseParserRuleCall_1_0; }

		//explorationStrategy=ExplorationStrategyClause?
		public Assignment getExplorationStrategyAssignment_2() { return cExplorationStrategyAssignment_2; }

		//ExplorationStrategyClause
		public RuleCall getExplorationStrategyExplorationStrategyClauseParserRuleCall_2_0() { return cExplorationStrategyExplorationStrategyClauseParserRuleCall_2_0; }

		//constraintClause=ConstraintClause?
		public Assignment getConstraintClauseAssignment_3() { return cConstraintClauseAssignment_3; }

		//ConstraintClause
		public RuleCall getConstraintClauseConstraintClauseParserRuleCall_3_0() { return cConstraintClauseConstraintClauseParserRuleCall_3_0; }

		//withClause=WithClause?
		public Assignment getWithClauseAssignment_4() { return cWithClauseAssignment_4; }

		//WithClause
		public RuleCall getWithClauseWithClauseParserRuleCall_4_0() { return cWithClauseWithClauseParserRuleCall_4_0; }
	}

	public class ExplorationStrategyClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ExplorationStrategyClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeGUIDEDBYKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cNameAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cNameSTRINGTerminalRuleCall_1_0 = (RuleCall)cNameAssignment_1.eContents().get(0);
		private final Assignment cParameterClauseAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cParameterClauseConfigurationPropertiesClauseParserRuleCall_2_0 = (RuleCall)cParameterClauseAssignment_2.eContents().get(0);
		
		/// *
		// * Rule to specify an exploration strategy
		// * / // @THESIS
		//ExplorationStrategyClause:
		//	mode='GUIDED BY' name=STRING parameterClause=ConfigurationPropertiesClause?;
		@Override public ParserRule getRule() { return rule; }

		//mode='GUIDED BY' name=STRING parameterClause=ConfigurationPropertiesClause?
		public Group getGroup() { return cGroup; }

		//mode='GUIDED BY'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'GUIDED BY'
		public Keyword getModeGUIDEDBYKeyword_0_0() { return cModeGUIDEDBYKeyword_0_0; }

		//name=STRING
		public Assignment getNameAssignment_1() { return cNameAssignment_1; }

		//STRING
		public RuleCall getNameSTRINGTerminalRuleCall_1_0() { return cNameSTRINGTerminalRuleCall_1_0; }

		//parameterClause=ConfigurationPropertiesClause?
		public Assignment getParameterClauseAssignment_2() { return cParameterClauseAssignment_2; }

		//ConfigurationPropertiesClause
		public RuleCall getParameterClauseConfigurationPropertiesClauseParserRuleCall_2_0() { return cParameterClauseConfigurationPropertiesClauseParserRuleCall_2_0; }
	}

	public class ConfigurationPropertiesClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ConfigurationPropertiesClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cMode1Assignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cMode1LeftSquareBracketKeyword_0_0 = (Keyword)cMode1Assignment_0.eContents().get(0);
		private final Assignment cPropertiesAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cPropertiesConfigurationPropertyClauseParserRuleCall_1_0 = (RuleCall)cPropertiesAssignment_1.eContents().get(0);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cCommaKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cPropertiesAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cPropertiesConfigurationPropertyClauseParserRuleCall_2_1_0 = (RuleCall)cPropertiesAssignment_2_1.eContents().get(0);
		private final Assignment cMode2Assignment_3 = (Assignment)cGroup.eContents().get(3);
		private final Keyword cMode2RightSquareBracketKeyword_3_0 = (Keyword)cMode2Assignment_3.eContents().get(0);
		
		//// @THESIS
		//ConfigurationPropertiesClause:
		//	mode1='[' properties+=ConfigurationPropertyClause (',' properties+=ConfigurationPropertyClause)* mode2=']';
		@Override public ParserRule getRule() { return rule; }

		//mode1='[' properties+=ConfigurationPropertyClause (',' properties+=ConfigurationPropertyClause)* mode2=']'
		public Group getGroup() { return cGroup; }

		//mode1='['
		public Assignment getMode1Assignment_0() { return cMode1Assignment_0; }

		//'['
		public Keyword getMode1LeftSquareBracketKeyword_0_0() { return cMode1LeftSquareBracketKeyword_0_0; }

		//properties+=ConfigurationPropertyClause
		public Assignment getPropertiesAssignment_1() { return cPropertiesAssignment_1; }

		//ConfigurationPropertyClause
		public RuleCall getPropertiesConfigurationPropertyClauseParserRuleCall_1_0() { return cPropertiesConfigurationPropertyClauseParserRuleCall_1_0; }

		//(',' properties+=ConfigurationPropertyClause)*
		public Group getGroup_2() { return cGroup_2; }

		//','
		public Keyword getCommaKeyword_2_0() { return cCommaKeyword_2_0; }

		//properties+=ConfigurationPropertyClause
		public Assignment getPropertiesAssignment_2_1() { return cPropertiesAssignment_2_1; }

		//ConfigurationPropertyClause
		public RuleCall getPropertiesConfigurationPropertyClauseParserRuleCall_2_1_0() { return cPropertiesConfigurationPropertyClauseParserRuleCall_2_1_0; }

		//mode2=']'
		public Assignment getMode2Assignment_3() { return cMode2Assignment_3; }

		//']'
		public Keyword getMode2RightSquareBracketKeyword_3_0() { return cMode2RightSquareBracketKeyword_3_0; }
	}

	public class ConfigurationPropertyClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ConfigurationPropertyClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cKeyAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cKeyIDTerminalRuleCall_0_0 = (RuleCall)cKeyAssignment_0.eContents().get(0);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Keyword cFullStopKeyword_1_0 = (Keyword)cGroup_1.eContents().get(0);
		private final Assignment cKeyAssignment_1_1 = (Assignment)cGroup_1.eContents().get(1);
		private final RuleCall cKeyIDTerminalRuleCall_1_1_0 = (RuleCall)cKeyAssignment_1_1.eContents().get(0);
		private final Keyword cEqualsSignKeyword_2 = (Keyword)cGroup.eContents().get(2);
		private final Assignment cValueAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cValueSTRINGTerminalRuleCall_3_0 = (RuleCall)cValueAssignment_3.eContents().get(0);
		
		//// @THESIS
		//ConfigurationPropertyClause:
		//	key+=ID ('.' key+=ID)* '=' value=STRING;
		@Override public ParserRule getRule() { return rule; }

		//key+=ID ('.' key+=ID)* '=' value=STRING
		public Group getGroup() { return cGroup; }

		//key+=ID
		public Assignment getKeyAssignment_0() { return cKeyAssignment_0; }

		//ID
		public RuleCall getKeyIDTerminalRuleCall_0_0() { return cKeyIDTerminalRuleCall_0_0; }

		//('.' key+=ID)*
		public Group getGroup_1() { return cGroup_1; }

		//'.'
		public Keyword getFullStopKeyword_1_0() { return cFullStopKeyword_1_0; }

		//key+=ID
		public Assignment getKeyAssignment_1_1() { return cKeyAssignment_1_1; }

		//ID
		public RuleCall getKeyIDTerminalRuleCall_1_1_0() { return cKeyIDTerminalRuleCall_1_1_0; }

		//'='
		public Keyword getEqualsSignKeyword_2() { return cEqualsSignKeyword_2; }

		//value=STRING
		public Assignment getValueAssignment_3() { return cValueAssignment_3; }

		//STRING
		public RuleCall getValueSTRINGTerminalRuleCall_3_0() { return cValueSTRINGTerminalRuleCall_3_0; }
	}

	public class DoFVariationClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.DoFVariationClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cMode1Assignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cMode1LessThanSignKeyword_0_0 = (Keyword)cMode1Assignment_0.eContents().get(0);
		private final Assignment cVariationAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final Alternatives cVariationAlternatives_1_0 = (Alternatives)cVariationAssignment_1.eContents().get(0);
		private final RuleCall cVariationIntervalVariationClauseParserRuleCall_1_0_0 = (RuleCall)cVariationAlternatives_1_0.eContents().get(0);
		private final RuleCall cVariationValueVariationClauseParserRuleCall_1_0_1 = (RuleCall)cVariationAlternatives_1_0.eContents().get(1);
		private final Assignment cMode2Assignment_2 = (Assignment)cGroup.eContents().get(2);
		private final Keyword cMode2GreaterThanSignKeyword_2_0 = (Keyword)cMode2Assignment_2.eContents().get(0);
		
		//// @THESIS
		//DoFVariationClause:
		//	mode1='<' variation=(IntervalVariationClause | ValueVariationClause) mode2='>';
		@Override public ParserRule getRule() { return rule; }

		//mode1='<' variation=(IntervalVariationClause | ValueVariationClause) mode2='>'
		public Group getGroup() { return cGroup; }

		//mode1='<'
		public Assignment getMode1Assignment_0() { return cMode1Assignment_0; }

		//'<'
		public Keyword getMode1LessThanSignKeyword_0_0() { return cMode1LessThanSignKeyword_0_0; }

		//variation=(IntervalVariationClause | ValueVariationClause)
		public Assignment getVariationAssignment_1() { return cVariationAssignment_1; }

		//(IntervalVariationClause | ValueVariationClause)
		public Alternatives getVariationAlternatives_1_0() { return cVariationAlternatives_1_0; }

		//IntervalVariationClause
		public RuleCall getVariationIntervalVariationClauseParserRuleCall_1_0_0() { return cVariationIntervalVariationClauseParserRuleCall_1_0_0; }

		//ValueVariationClause
		public RuleCall getVariationValueVariationClauseParserRuleCall_1_0_1() { return cVariationValueVariationClauseParserRuleCall_1_0_1; }

		//mode2='>'
		public Assignment getMode2Assignment_2() { return cMode2Assignment_2; }

		//'>'
		public Keyword getMode2GreaterThanSignKeyword_2_0() { return cMode2GreaterThanSignKeyword_2_0; }
	}

	public class ValueVariationClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ValueVariationClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cValueAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cValueINTTerminalRuleCall_0_0 = (RuleCall)cValueAssignment_0.eContents().get(0);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Keyword cCommaKeyword_1_0 = (Keyword)cGroup_1.eContents().get(0);
		private final Assignment cValueAssignment_1_1 = (Assignment)cGroup_1.eContents().get(1);
		private final RuleCall cValueINTTerminalRuleCall_1_1_0 = (RuleCall)cValueAssignment_1_1.eContents().get(0);
		
		//// @THESIS
		//ValueVariationClause:
		//	value+=INT (',' value+=INT)*;
		@Override public ParserRule getRule() { return rule; }

		//value+=INT (',' value+=INT)*
		public Group getGroup() { return cGroup; }

		//value+=INT
		public Assignment getValueAssignment_0() { return cValueAssignment_0; }

		//INT
		public RuleCall getValueINTTerminalRuleCall_0_0() { return cValueINTTerminalRuleCall_0_0; }

		//(',' value+=INT)*
		public Group getGroup_1() { return cGroup_1; }

		//','
		public Keyword getCommaKeyword_1_0() { return cCommaKeyword_1_0; }

		//value+=INT
		public Assignment getValueAssignment_1_1() { return cValueAssignment_1_1; }

		//INT
		public RuleCall getValueINTTerminalRuleCall_1_1_0() { return cValueINTTerminalRuleCall_1_1_0; }
	}

	public class IntervalVariationClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.IntervalVariationClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cStartAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cStartINTTerminalRuleCall_0_0 = (RuleCall)cStartAssignment_0.eContents().get(0);
		private final Keyword cFullStopFullStopKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cEndAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cEndINTTerminalRuleCall_2_0 = (RuleCall)cEndAssignment_2.eContents().get(0);
		private final Keyword cBYKeyword_3 = (Keyword)cGroup.eContents().get(3);
		private final Assignment cStepAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cStepINTTerminalRuleCall_4_0 = (RuleCall)cStepAssignment_4.eContents().get(0);
		
		//// @THESIS
		//IntervalVariationClause:
		//	start=INT '..' end=INT 'BY' step=INT;
		@Override public ParserRule getRule() { return rule; }

		//start=INT '..' end=INT 'BY' step=INT
		public Group getGroup() { return cGroup; }

		//start=INT
		public Assignment getStartAssignment_0() { return cStartAssignment_0; }

		//INT
		public RuleCall getStartINTTerminalRuleCall_0_0() { return cStartINTTerminalRuleCall_0_0; }

		//'..'
		public Keyword getFullStopFullStopKeyword_1() { return cFullStopFullStopKeyword_1; }

		//end=INT
		public Assignment getEndAssignment_2() { return cEndAssignment_2; }

		//INT
		public RuleCall getEndINTTerminalRuleCall_2_0() { return cEndINTTerminalRuleCall_2_0; }

		//'BY'
		public Keyword getBYKeyword_3() { return cBYKeyword_3; }

		//step=INT
		public Assignment getStepAssignment_4() { return cStepAssignment_4; }

		//INT
		public RuleCall getStepINTTerminalRuleCall_4_0() { return cStepINTTerminalRuleCall_4_0; }
	}

	public class VaryingClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.VaryingClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeVARYINGKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cDofReferencesAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cDofReferencesDoFReferenceParserRuleCall_1_0 = (RuleCall)cDofReferencesAssignment_1.eContents().get(0);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cCommaKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cDofReferencesAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cDofReferencesDoFReferenceParserRuleCall_2_1_0 = (RuleCall)cDofReferencesAssignment_2_1.eContents().get(0);
		
		/// *
		// * Clause to define which DoF to vary
		// * / // @THESIS
		//VaryingClause:
		//	mode='VARYING' dofReferences+=DoFReference (',' dofReferences+=DoFReference)*;
		@Override public ParserRule getRule() { return rule; }

		//mode='VARYING' dofReferences+=DoFReference (',' dofReferences+=DoFReference)*
		public Group getGroup() { return cGroup; }

		//mode='VARYING'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'VARYING'
		public Keyword getModeVARYINGKeyword_0_0() { return cModeVARYINGKeyword_0_0; }

		//dofReferences+=DoFReference
		public Assignment getDofReferencesAssignment_1() { return cDofReferencesAssignment_1; }

		//DoFReference
		public RuleCall getDofReferencesDoFReferenceParserRuleCall_1_0() { return cDofReferencesDoFReferenceParserRuleCall_1_0; }

		//(',' dofReferences+=DoFReference)*
		public Group getGroup_2() { return cGroup_2; }

		//','
		public Keyword getCommaKeyword_2_0() { return cCommaKeyword_2_0; }

		//dofReferences+=DoFReference
		public Assignment getDofReferencesAssignment_2_1() { return cDofReferencesAssignment_2_1; }

		//DoFReference
		public RuleCall getDofReferencesDoFReferenceParserRuleCall_2_1_0() { return cDofReferencesDoFReferenceParserRuleCall_2_1_0; }
	}

	public class DoFReferenceElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.DoFReference");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cDoFIdentifierAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cDoFIdentifierSTRINGTerminalRuleCall_0_0 = (RuleCall)cDoFIdentifierAssignment_0.eContents().get(0);
		private final Assignment cDoFAliasClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cDoFAliasClauseAliasClauseParserRuleCall_1_0 = (RuleCall)cDoFAliasClauseAssignment_1.eContents().get(0);
		private final Assignment cDoFVariationClauseAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final Alternatives cDoFVariationClauseAlternatives_2_0 = (Alternatives)cDoFVariationClauseAssignment_2.eContents().get(0);
		private final RuleCall cDoFVariationClauseConfigurationPropertiesClauseParserRuleCall_2_0_0 = (RuleCall)cDoFVariationClauseAlternatives_2_0.eContents().get(0);
		private final RuleCall cDoFVariationClauseDoFVariationClauseParserRuleCall_2_0_1 = (RuleCall)cDoFVariationClauseAlternatives_2_0.eContents().get(1);
		
		/// * 
		// * Rule to reference DoF model entities
		// * / // @THESIS
		//DoFReference:
		//	doFIdentifier=STRING doFAliasClause=AliasClause? doFVariationClause=(ConfigurationPropertiesClause |
		//	DoFVariationClause)?;
		@Override public ParserRule getRule() { return rule; }

		//doFIdentifier=STRING doFAliasClause=AliasClause? doFVariationClause=(ConfigurationPropertiesClause |
		//DoFVariationClause)?
		public Group getGroup() { return cGroup; }

		//doFIdentifier=STRING
		public Assignment getDoFIdentifierAssignment_0() { return cDoFIdentifierAssignment_0; }

		//STRING
		public RuleCall getDoFIdentifierSTRINGTerminalRuleCall_0_0() { return cDoFIdentifierSTRINGTerminalRuleCall_0_0; }

		//doFAliasClause=AliasClause?
		public Assignment getDoFAliasClauseAssignment_1() { return cDoFAliasClauseAssignment_1; }

		//AliasClause
		public RuleCall getDoFAliasClauseAliasClauseParserRuleCall_1_0() { return cDoFAliasClauseAliasClauseParserRuleCall_1_0; }

		//doFVariationClause=(ConfigurationPropertiesClause | DoFVariationClause)?
		public Assignment getDoFVariationClauseAssignment_2() { return cDoFVariationClauseAssignment_2; }

		//(ConfigurationPropertiesClause | DoFVariationClause)
		public Alternatives getDoFVariationClauseAlternatives_2_0() { return cDoFVariationClauseAlternatives_2_0; }

		//ConfigurationPropertiesClause
		public RuleCall getDoFVariationClauseConfigurationPropertiesClauseParserRuleCall_2_0_0() { return cDoFVariationClauseConfigurationPropertiesClauseParserRuleCall_2_0_0; }

		//DoFVariationClause
		public RuleCall getDoFVariationClauseDoFVariationClauseParserRuleCall_2_0_1() { return cDoFVariationClauseDoFVariationClauseParserRuleCall_2_0_1; }
	}

	public class MetricClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.MetricClause");
		private final Assignment cMetricReferenceAssignment = (Assignment)rule.eContents().get(1);
		private final RuleCall cMetricReferenceMetricReferenceParserRuleCall_0 = (RuleCall)cMetricReferenceAssignment.eContents().get(0);
		
		/// *
		// * Clause to reference multiple metrics
		// * / // @THESIS
		//MetricClause:
		//	metricReference=MetricReference;
		@Override public ParserRule getRule() { return rule; }

		//metricReference=MetricReference
		public Assignment getMetricReferenceAssignment() { return cMetricReferenceAssignment; }

		//MetricReference
		public RuleCall getMetricReferenceMetricReferenceParserRuleCall_0() { return cMetricReferenceMetricReferenceParserRuleCall_0; }
	}

	public class AggregateMetricClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.AggregateMetricClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cFunctionAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cFunctionStatisticalAggregateTypeEnumRuleCall_0_0 = (RuleCall)cFunctionAssignment_0.eContents().get(0);
		private final Keyword cLeftParenthesisKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cMetricsAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final Alternatives cMetricsAlternatives_2_0 = (Alternatives)cMetricsAssignment_2.eContents().get(0);
		private final RuleCall cMetricsMetricStarClauseParserRuleCall_2_0_0 = (RuleCall)cMetricsAlternatives_2_0.eContents().get(0);
		private final RuleCall cMetricsMetricClausesParserRuleCall_2_0_1 = (RuleCall)cMetricsAlternatives_2_0.eContents().get(1);
		private final Keyword cRightParenthesisKeyword_3 = (Keyword)cGroup.eContents().get(3);
		private final Assignment cPropertiesAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cPropertiesConfigurationPropertiesClauseParserRuleCall_4_0 = (RuleCall)cPropertiesAssignment_4.eContents().get(0);
		
		//// @THESIS
		//AggregateMetricClause:
		//	function=StatisticalAggregateType '(' metrics=(MetricStarClause | MetricClauses) ')'
		//	properties=ConfigurationPropertiesClause?;
		@Override public ParserRule getRule() { return rule; }

		//function=StatisticalAggregateType '(' metrics=(MetricStarClause | MetricClauses) ')'
		//properties=ConfigurationPropertiesClause?
		public Group getGroup() { return cGroup; }

		//function=StatisticalAggregateType
		public Assignment getFunctionAssignment_0() { return cFunctionAssignment_0; }

		//StatisticalAggregateType
		public RuleCall getFunctionStatisticalAggregateTypeEnumRuleCall_0_0() { return cFunctionStatisticalAggregateTypeEnumRuleCall_0_0; }

		//'('
		public Keyword getLeftParenthesisKeyword_1() { return cLeftParenthesisKeyword_1; }

		//metrics=(MetricStarClause | MetricClauses)
		public Assignment getMetricsAssignment_2() { return cMetricsAssignment_2; }

		//(MetricStarClause | MetricClauses)
		public Alternatives getMetricsAlternatives_2_0() { return cMetricsAlternatives_2_0; }

		//MetricStarClause
		public RuleCall getMetricsMetricStarClauseParserRuleCall_2_0_0() { return cMetricsMetricStarClauseParserRuleCall_2_0_0; }

		//MetricClauses
		public RuleCall getMetricsMetricClausesParserRuleCall_2_0_1() { return cMetricsMetricClausesParserRuleCall_2_0_1; }

		//')'
		public Keyword getRightParenthesisKeyword_3() { return cRightParenthesisKeyword_3; }

		//properties=ConfigurationPropertiesClause?
		public Assignment getPropertiesAssignment_4() { return cPropertiesAssignment_4; }

		//ConfigurationPropertiesClause
		public RuleCall getPropertiesConfigurationPropertiesClauseParserRuleCall_4_0() { return cPropertiesConfigurationPropertiesClauseParserRuleCall_4_0; }
	}

	public class MetricClausesElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.MetricClauses");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cMetricsAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cMetricsMetricClauseParserRuleCall_0_0 = (RuleCall)cMetricsAssignment_0.eContents().get(0);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Keyword cCommaKeyword_1_0 = (Keyword)cGroup_1.eContents().get(0);
		private final Assignment cMetricsAssignment_1_1 = (Assignment)cGroup_1.eContents().get(1);
		private final RuleCall cMetricsMetricClauseParserRuleCall_1_1_0 = (RuleCall)cMetricsAssignment_1_1.eContents().get(0);
		
		//// @THESIS
		//MetricClauses:
		//	metrics+=MetricClause (',' metrics+=MetricClause)*;
		@Override public ParserRule getRule() { return rule; }

		//metrics+=MetricClause (',' metrics+=MetricClause)*
		public Group getGroup() { return cGroup; }

		//metrics+=MetricClause
		public Assignment getMetricsAssignment_0() { return cMetricsAssignment_0; }

		//MetricClause
		public RuleCall getMetricsMetricClauseParserRuleCall_0_0() { return cMetricsMetricClauseParserRuleCall_0_0; }

		//(',' metrics+=MetricClause)*
		public Group getGroup_1() { return cGroup_1; }

		//','
		public Keyword getCommaKeyword_1_0() { return cCommaKeyword_1_0; }

		//metrics+=MetricClause
		public Assignment getMetricsAssignment_1_1() { return cMetricsAssignment_1_1; }

		//MetricClause
		public RuleCall getMetricsMetricClauseParserRuleCall_1_1_0() { return cMetricsMetricClauseParserRuleCall_1_1_0; }
	}

	public class MetricStarClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.MetricStarClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cAsteriskFullStopKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cMetricNameAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cMetricNameIDTerminalRuleCall_1_0 = (RuleCall)cMetricNameAssignment_1.eContents().get(0);
		
		//// @THESIS
		//MetricStarClause:
		//	'*.' metricName=ID;
		@Override public ParserRule getRule() { return rule; }

		//'*.' metricName=ID
		public Group getGroup() { return cGroup; }

		//'*.'
		public Keyword getAsteriskFullStopKeyword_0() { return cAsteriskFullStopKeyword_0; }

		//metricName=ID
		public Assignment getMetricNameAssignment_1() { return cMetricNameAssignment_1; }

		//ID
		public RuleCall getMetricNameIDTerminalRuleCall_1_0() { return cMetricNameIDTerminalRuleCall_1_0; }
	}

	public class MetricReferenceElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.MetricReference");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cEntityReferenceAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cEntityReferenceIDTerminalRuleCall_0_0 = (RuleCall)cEntityReferenceAssignment_0.eContents().get(0);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Assignment cSeperatornAssignment_1_0 = (Assignment)cGroup_1.eContents().get(0);
		private final Keyword cSeperatornFullStopKeyword_1_0_0 = (Keyword)cSeperatornAssignment_1_0.eContents().get(0);
		private final Assignment cNavigationClauseAssignment_1_1 = (Assignment)cGroup_1.eContents().get(1);
		private final RuleCall cNavigationClauseNavigationClauseParserRuleCall_1_1_0 = (RuleCall)cNavigationClauseAssignment_1_1.eContents().get(0);
		private final Assignment cSeparatorAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final Keyword cSeparatorFullStopKeyword_2_0 = (Keyword)cSeparatorAssignment_2.eContents().get(0);
		private final Assignment cMetricReferenceAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cMetricReferenceIDTerminalRuleCall_3_0 = (RuleCall)cMetricReferenceAssignment_3.eContents().get(0);
		private final Group cGroup_4 = (Group)cGroup.eContents().get(4);
		private final Assignment cSeparatorvAssignment_4_0 = (Assignment)cGroup_4.eContents().get(0);
		private final Keyword cSeparatorvFullStopKeyword_4_0_0 = (Keyword)cSeparatorvAssignment_4_0.eContents().get(0);
		private final Assignment cStatTypeReferenceAssignment_4_1 = (Assignment)cGroup_4.eContents().get(1);
		private final RuleCall cStatTypeReferenceIDTerminalRuleCall_4_1_0 = (RuleCall)cStatTypeReferenceAssignment_4_1.eContents().get(0);
		
		/// *
		// * Rule for referencing metrics bound to entities
		// * / // @THESIS
		//MetricReference:
		//	entityReference=ID (seperatorn="." navigationClause=NavigationClause)? separator='.' metricReference=ID
		//	(separatorv="." statTypeReference=ID)?;
		@Override public ParserRule getRule() { return rule; }

		//entityReference=ID (seperatorn="." navigationClause=NavigationClause)? separator='.' metricReference=ID (separatorv="."
		//statTypeReference=ID)?
		public Group getGroup() { return cGroup; }

		//entityReference=ID
		public Assignment getEntityReferenceAssignment_0() { return cEntityReferenceAssignment_0; }

		//ID
		public RuleCall getEntityReferenceIDTerminalRuleCall_0_0() { return cEntityReferenceIDTerminalRuleCall_0_0; }

		//(seperatorn="." navigationClause=NavigationClause)?
		public Group getGroup_1() { return cGroup_1; }

		//seperatorn="."
		public Assignment getSeperatornAssignment_1_0() { return cSeperatornAssignment_1_0; }

		//"."
		public Keyword getSeperatornFullStopKeyword_1_0_0() { return cSeperatornFullStopKeyword_1_0_0; }

		//navigationClause=NavigationClause
		public Assignment getNavigationClauseAssignment_1_1() { return cNavigationClauseAssignment_1_1; }

		//NavigationClause
		public RuleCall getNavigationClauseNavigationClauseParserRuleCall_1_1_0() { return cNavigationClauseNavigationClauseParserRuleCall_1_1_0; }

		//separator='.'
		public Assignment getSeparatorAssignment_2() { return cSeparatorAssignment_2; }

		//'.'
		public Keyword getSeparatorFullStopKeyword_2_0() { return cSeparatorFullStopKeyword_2_0; }

		//metricReference=ID
		public Assignment getMetricReferenceAssignment_3() { return cMetricReferenceAssignment_3; }

		//ID
		public RuleCall getMetricReferenceIDTerminalRuleCall_3_0() { return cMetricReferenceIDTerminalRuleCall_3_0; }

		//(separatorv="." statTypeReference=ID)?
		public Group getGroup_4() { return cGroup_4; }

		//separatorv="."
		public Assignment getSeparatorvAssignment_4_0() { return cSeparatorvAssignment_4_0; }

		//"."
		public Keyword getSeparatorvFullStopKeyword_4_0_0() { return cSeparatorvFullStopKeyword_4_0_0; }

		//statTypeReference=ID
		public Assignment getStatTypeReferenceAssignment_4_1() { return cStatTypeReferenceAssignment_4_1; }

		//ID
		public RuleCall getStatTypeReferenceIDTerminalRuleCall_4_1_0() { return cStatTypeReferenceIDTerminalRuleCall_4_1_0; }
	}

	public class NavigationClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.NavigationClause");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cParentClauseParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cChildrenClauseParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		private final RuleCall cFindClauseParserRuleCall_2 = (RuleCall)cAlternatives.eContents().get(2);
		
		//NavigationClause:
		//	ParentClause | ChildrenClause | FindClause;
		@Override public ParserRule getRule() { return rule; }

		//ParentClause | ChildrenClause | FindClause
		public Alternatives getAlternatives() { return cAlternatives; }

		//ParentClause
		public RuleCall getParentClauseParserRuleCall_0() { return cParentClauseParserRuleCall_0; }

		//ChildrenClause
		public RuleCall getChildrenClauseParserRuleCall_1() { return cChildrenClauseParserRuleCall_1; }

		//FindClause
		public RuleCall getFindClauseParserRuleCall_2() { return cFindClauseParserRuleCall_2; }
	}

	public class ChildrenClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ChildrenClause");
		private final Assignment cContentAssignment = (Assignment)rule.eContents().get(1);
		private final Keyword cContentChildrenKeyword_0 = (Keyword)cContentAssignment.eContents().get(0);
		
		//ChildrenClause:
		//	content='children';
		@Override public ParserRule getRule() { return rule; }

		//content='children'
		public Assignment getContentAssignment() { return cContentAssignment; }

		//'children'
		public Keyword getContentChildrenKeyword_0() { return cContentChildrenKeyword_0; }
	}

	public class ParentClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ParentClause");
		private final Assignment cContentAssignment = (Assignment)rule.eContents().get(1);
		private final Keyword cContentParentKeyword_0 = (Keyword)cContentAssignment.eContents().get(0);
		
		//ParentClause:
		//	content='parent';
		@Override public ParserRule getRule() { return rule; }

		//content='parent'
		public Assignment getContentAssignment() { return cContentAssignment; }

		//'parent'
		public Keyword getContentParentKeyword_0() { return cContentParentKeyword_0; }
	}

	public class FindClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.FindClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cStartAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cStartFindKeyword_0_0 = (Keyword)cStartAssignment_0.eContents().get(0);
		private final Assignment cChildNameAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cChildNameSTRINGTerminalRuleCall_1_0 = (RuleCall)cChildNameAssignment_1.eContents().get(0);
		private final Assignment cEndAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final Keyword cEndRightParenthesisKeyword_2_0 = (Keyword)cEndAssignment_2.eContents().get(0);
		
		//FindClause:
		//	start='find(' childName=STRING end=')';
		@Override public ParserRule getRule() { return rule; }

		//start='find(' childName=STRING end=')'
		public Group getGroup() { return cGroup; }

		//start='find('
		public Assignment getStartAssignment_0() { return cStartAssignment_0; }

		//'find('
		public Keyword getStartFindKeyword_0_0() { return cStartFindKeyword_0_0; }

		//childName=STRING
		public Assignment getChildNameAssignment_1() { return cChildNameAssignment_1; }

		//STRING
		public RuleCall getChildNameSTRINGTerminalRuleCall_1_0() { return cChildNameSTRINGTerminalRuleCall_1_0; }

		//end=')'
		public Assignment getEndAssignment_2() { return cEndAssignment_2; }

		//')'
		public Keyword getEndRightParenthesisKeyword_2_0() { return cEndRightParenthesisKeyword_2_0; }
	}

	public class ForClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ForClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeFORKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cEntityReferenceClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cEntityReferenceClauseEntityReferenceClauseParserRuleCall_1_0 = (RuleCall)cEntityReferenceClauseAssignment_1.eContents().get(0);
		
		/// *
		// * Clauses to build entity references in a query
		// * / // @THESIS
		//ForClause:
		//	mode='FOR' entityReferenceClause=EntityReferenceClause;
		@Override public ParserRule getRule() { return rule; }

		//mode='FOR' entityReferenceClause=EntityReferenceClause
		public Group getGroup() { return cGroup; }

		//mode='FOR'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'FOR'
		public Keyword getModeFORKeyword_0_0() { return cModeFORKeyword_0_0; }

		//entityReferenceClause=EntityReferenceClause
		public Assignment getEntityReferenceClauseAssignment_1() { return cEntityReferenceClauseAssignment_1; }

		//EntityReferenceClause
		public RuleCall getEntityReferenceClauseEntityReferenceClauseParserRuleCall_1_0() { return cEntityReferenceClauseEntityReferenceClauseParserRuleCall_1_0; }
	}

	public class EntityReferenceClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.EntityReferenceClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cEntityReferencesAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cEntityReferencesEntityReferenceParserRuleCall_0_0 = (RuleCall)cEntityReferencesAssignment_0.eContents().get(0);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Keyword cCommaKeyword_1_0 = (Keyword)cGroup_1.eContents().get(0);
		private final Assignment cEntityReferencesAssignment_1_1 = (Assignment)cGroup_1.eContents().get(1);
		private final RuleCall cEntityReferencesEntityReferenceParserRuleCall_1_1_0 = (RuleCall)cEntityReferencesAssignment_1_1.eContents().get(0);
		
		//// @THESIS
		//EntityReferenceClause:
		//	entityReferences+=EntityReference (',' entityReferences+=EntityReference)*;
		@Override public ParserRule getRule() { return rule; }

		//entityReferences+=EntityReference (',' entityReferences+=EntityReference)*
		public Group getGroup() { return cGroup; }

		//entityReferences+=EntityReference
		public Assignment getEntityReferencesAssignment_0() { return cEntityReferencesAssignment_0; }

		//EntityReference
		public RuleCall getEntityReferencesEntityReferenceParserRuleCall_0_0() { return cEntityReferencesEntityReferenceParserRuleCall_0_0; }

		//(',' entityReferences+=EntityReference)*
		public Group getGroup_1() { return cGroup_1; }

		//','
		public Keyword getCommaKeyword_1_0() { return cCommaKeyword_1_0; }

		//entityReferences+=EntityReference
		public Assignment getEntityReferencesAssignment_1_1() { return cEntityReferencesAssignment_1_1; }

		//EntityReference
		public RuleCall getEntityReferencesEntityReferenceParserRuleCall_1_1_0() { return cEntityReferencesEntityReferenceParserRuleCall_1_1_0; }
	}

	public class EntityReferenceElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.EntityReference");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cTypeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cTypeIDTerminalRuleCall_0_0 = (RuleCall)cTypeAssignment_0.eContents().get(0);
		private final Assignment cIdentifierAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cIdentifierSTRINGTerminalRuleCall_1_0 = (RuleCall)cIdentifierAssignment_1.eContents().get(0);
		private final Assignment cAliasAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cAliasAliasClauseParserRuleCall_2_0 = (RuleCall)cAliasAssignment_2.eContents().get(0);
		
		/// *
		// * Rules for referencing entities
		// * / // @THESIS
		//EntityReference:
		//	type=ID? identifier=STRING alias=AliasClause?;
		@Override public ParserRule getRule() { return rule; }

		//type=ID? identifier=STRING alias=AliasClause?
		public Group getGroup() { return cGroup; }

		//type=ID?
		public Assignment getTypeAssignment_0() { return cTypeAssignment_0; }

		//ID
		public RuleCall getTypeIDTerminalRuleCall_0_0() { return cTypeIDTerminalRuleCall_0_0; }

		//identifier=STRING
		public Assignment getIdentifierAssignment_1() { return cIdentifierAssignment_1; }

		//STRING
		public RuleCall getIdentifierSTRINGTerminalRuleCall_1_0() { return cIdentifierSTRINGTerminalRuleCall_1_0; }

		//alias=AliasClause?
		public Assignment getAliasAssignment_2() { return cAliasAssignment_2; }

		//AliasClause
		public RuleCall getAliasAliasClauseParserRuleCall_2_0() { return cAliasAliasClauseParserRuleCall_2_0; }
	}

	public class AliasClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.AliasClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeASKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cAliasAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cAliasIDTerminalRuleCall_1_0 = (RuleCall)cAliasAssignment_1.eContents().get(0);
		
		//// @THESIS
		//AliasClause:
		//	mode='AS' alias=ID;
		@Override public ParserRule getRule() { return rule; }

		//mode='AS' alias=ID
		public Group getGroup() { return cGroup; }

		//mode='AS'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'AS'
		public Keyword getModeASKeyword_0_0() { return cModeASKeyword_0_0; }

		//alias=ID
		public Assignment getAliasAssignment_1() { return cAliasAssignment_1; }

		//ID
		public RuleCall getAliasIDTerminalRuleCall_1_0() { return cAliasIDTerminalRuleCall_1_0; }
	}

	public class UsingClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.UsingClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeUSINGKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cModelReferenceAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cModelReferenceModelReferenceClauseParserRuleCall_1_0 = (RuleCall)cModelReferenceAssignment_1.eContents().get(0);
		
		/// * 
		// * Clauses used for referencing model instances
		// * / // @THESIS
		//UsingClause:
		//	mode='USING' modelReference=ModelReferenceClause;
		@Override public ParserRule getRule() { return rule; }

		//mode='USING' modelReference=ModelReferenceClause
		public Group getGroup() { return cGroup; }

		//mode='USING'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'USING'
		public Keyword getModeUSINGKeyword_0_0() { return cModeUSINGKeyword_0_0; }

		//modelReference=ModelReferenceClause
		public Assignment getModelReferenceAssignment_1() { return cModelReferenceAssignment_1; }

		//ModelReferenceClause
		public RuleCall getModelReferenceModelReferenceClauseParserRuleCall_1_0() { return cModelReferenceModelReferenceClauseParserRuleCall_1_0; }
	}

	public class WithClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.WithClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeWITHKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cModelReferenceAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cModelReferenceModelReferenceClauseParserRuleCall_1_0 = (RuleCall)cModelReferenceAssignment_1.eContents().get(0);
		
		//// @THESIS
		//WithClause:
		//	mode='WITH' modelReference=ModelReferenceClause;
		@Override public ParserRule getRule() { return rule; }

		//mode='WITH' modelReference=ModelReferenceClause
		public Group getGroup() { return cGroup; }

		//mode='WITH'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'WITH'
		public Keyword getModeWITHKeyword_0_0() { return cModeWITHKeyword_0_0; }

		//modelReference=ModelReferenceClause
		public Assignment getModelReferenceAssignment_1() { return cModelReferenceAssignment_1; }

		//ModelReferenceClause
		public RuleCall getModelReferenceModelReferenceClauseParserRuleCall_1_0() { return cModelReferenceModelReferenceClauseParserRuleCall_1_0; }
	}

	public class ModelReferenceClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ModelReferenceClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cFamilyAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cFamilyModelFamilyParserRuleCall_0_0 = (RuleCall)cFamilyAssignment_0.eContents().get(0);
		private final Keyword cCommercialAtKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cModelAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cModelModelLocationParserRuleCall_2_0 = (RuleCall)cModelAssignment_2.eContents().get(0);
		
		/// *
		// * Rules for referencing a model instances
		// * / // @THESIS 
		//ModelReferenceClause:
		//	family=ModelFamily '@' model=ModelLocation;
		@Override public ParserRule getRule() { return rule; }

		//family=ModelFamily '@' model=ModelLocation
		public Group getGroup() { return cGroup; }

		//family=ModelFamily
		public Assignment getFamilyAssignment_0() { return cFamilyAssignment_0; }

		//ModelFamily
		public RuleCall getFamilyModelFamilyParserRuleCall_0_0() { return cFamilyModelFamilyParserRuleCall_0_0; }

		//'@'
		public Keyword getCommercialAtKeyword_1() { return cCommercialAtKeyword_1; }

		//model=ModelLocation
		public Assignment getModelAssignment_2() { return cModelAssignment_2; }

		//ModelLocation
		public RuleCall getModelModelLocationParserRuleCall_2_0() { return cModelModelLocationParserRuleCall_2_0; }
	}

	public class ModelFamilyElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ModelFamily");
		private final Assignment cFamilyAssignment = (Assignment)rule.eContents().get(1);
		private final RuleCall cFamilyIDTerminalRuleCall_0 = (RuleCall)cFamilyAssignment.eContents().get(0);
		
		//// @THESIS
		//ModelFamily:
		//	family=ID;
		@Override public ParserRule getRule() { return rule; }

		//family=ID
		public Assignment getFamilyAssignment() { return cFamilyAssignment; }

		//ID
		public RuleCall getFamilyIDTerminalRuleCall_0() { return cFamilyIDTerminalRuleCall_0; }
	}

	public class ModelLocationElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ModelLocation");
		private final Assignment cLocationAssignment = (Assignment)rule.eContents().get(1);
		private final RuleCall cLocationSTRINGTerminalRuleCall_0 = (RuleCall)cLocationAssignment.eContents().get(0);
		
		//// @THESIS
		//ModelLocation:
		//	location=STRING;
		@Override public ParserRule getRule() { return rule; }

		//location=STRING
		public Assignment getLocationAssignment() { return cLocationAssignment; }

		//STRING
		public RuleCall getLocationSTRINGTerminalRuleCall_0() { return cLocationSTRINGTerminalRuleCall_0; }
	}

	public class FilterClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.FilterClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeFILTEREDBYKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cFilterConditionsAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cFilterConditionsFilterConditionClauseParserRuleCall_1_0 = (RuleCall)cFilterConditionsAssignment_1.eContents().get(0);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Assignment cFilterConjunctionsAssignment_2_0 = (Assignment)cGroup_2.eContents().get(0);
		private final RuleCall cFilterConjunctionsFilterConjunctionEnumRuleCall_2_0_0 = (RuleCall)cFilterConjunctionsAssignment_2_0.eContents().get(0);
		private final Assignment cFilterConditionsAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cFilterConditionsFilterConditionClauseParserRuleCall_2_1_0 = (RuleCall)cFilterConditionsAssignment_2_1.eContents().get(0);
		
		/// *
		// * Rules for defining filters in ListQuery
		// * / FilterClause:
		//	mode='FILTERED BY'
		//	filterConditions+=FilterConditionClause (filterConjunctions+=FilterConjunction
		//	filterConditions+=FilterConditionClause)*;
		@Override public ParserRule getRule() { return rule; }

		//mode='FILTERED BY' filterConditions+=FilterConditionClause (filterConjunctions+=FilterConjunction
		//filterConditions+=FilterConditionClause)*
		public Group getGroup() { return cGroup; }

		//mode='FILTERED BY'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'FILTERED BY'
		public Keyword getModeFILTEREDBYKeyword_0_0() { return cModeFILTEREDBYKeyword_0_0; }

		//filterConditions+=FilterConditionClause
		public Assignment getFilterConditionsAssignment_1() { return cFilterConditionsAssignment_1; }

		//FilterConditionClause
		public RuleCall getFilterConditionsFilterConditionClauseParserRuleCall_1_0() { return cFilterConditionsFilterConditionClauseParserRuleCall_1_0; }

		//(filterConjunctions+=FilterConjunction filterConditions+=FilterConditionClause)*
		public Group getGroup_2() { return cGroup_2; }

		//filterConjunctions+=FilterConjunction
		public Assignment getFilterConjunctionsAssignment_2_0() { return cFilterConjunctionsAssignment_2_0; }

		//FilterConjunction
		public RuleCall getFilterConjunctionsFilterConjunctionEnumRuleCall_2_0_0() { return cFilterConjunctionsFilterConjunctionEnumRuleCall_2_0_0; }

		//filterConditions+=FilterConditionClause
		public Assignment getFilterConditionsAssignment_2_1() { return cFilterConditionsAssignment_2_1; }

		//FilterConditionClause
		public RuleCall getFilterConditionsFilterConditionClauseParserRuleCall_2_1_0() { return cFilterConditionsFilterConditionClauseParserRuleCall_2_1_0; }
	}

	public class FilterConditionClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.FilterConditionClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeCONDITIONKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Keyword cLeftParenthesisKeyword_1 = (Keyword)cGroup.eContents().get(1);
		private final Assignment cConditionAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cConditionFilterConditionTypeEnumRuleCall_2_0 = (RuleCall)cConditionAssignment_2.eContents().get(0);
		private final Keyword cCommaKeyword_3 = (Keyword)cGroup.eContents().get(3);
		private final Assignment cValueAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cValueFilterConditionValueParserRuleCall_4_0 = (RuleCall)cValueAssignment_4.eContents().get(0);
		private final Keyword cRightParenthesisKeyword_5 = (Keyword)cGroup.eContents().get(5);
		
		//FilterConditionClause:
		//	mode='CONDITION' '(' condition=FilterConditionType ',' value=FilterConditionValue ')';
		@Override public ParserRule getRule() { return rule; }

		//mode='CONDITION' '(' condition=FilterConditionType ',' value=FilterConditionValue ')'
		public Group getGroup() { return cGroup; }

		//mode='CONDITION'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'CONDITION'
		public Keyword getModeCONDITIONKeyword_0_0() { return cModeCONDITIONKeyword_0_0; }

		//'('
		public Keyword getLeftParenthesisKeyword_1() { return cLeftParenthesisKeyword_1; }

		//condition=FilterConditionType
		public Assignment getConditionAssignment_2() { return cConditionAssignment_2; }

		//FilterConditionType
		public RuleCall getConditionFilterConditionTypeEnumRuleCall_2_0() { return cConditionFilterConditionTypeEnumRuleCall_2_0; }

		//','
		public Keyword getCommaKeyword_3() { return cCommaKeyword_3; }

		//value=FilterConditionValue
		public Assignment getValueAssignment_4() { return cValueAssignment_4; }

		//FilterConditionValue
		public RuleCall getValueFilterConditionValueParserRuleCall_4_0() { return cValueFilterConditionValueParserRuleCall_4_0; }

		//')'
		public Keyword getRightParenthesisKeyword_5() { return cRightParenthesisKeyword_5; }
	}

	public class FilterConditionValueElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.FilterConditionValue");
		private final Assignment cValueAssignment = (Assignment)rule.eContents().get(1);
		private final RuleCall cValueSTRINGTerminalRuleCall_0 = (RuleCall)cValueAssignment.eContents().get(0);
		
		//FilterConditionValue:
		//	value=STRING;
		@Override public ParserRule getRule() { return rule; }

		//value=STRING
		public Assignment getValueAssignment() { return cValueAssignment; }

		//STRING
		public RuleCall getValueSTRINGTerminalRuleCall_0() { return cValueSTRINGTerminalRuleCall_0; }
	}

	public class ObserveClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ObserveClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeOBSERVEKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cObservationAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cObservationObservationClauseParserRuleCall_1_0 = (RuleCall)cObservationAssignment_1.eContents().get(0);
		private final Assignment cSampleClauseAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cSampleClauseSampleClauseParserRuleCall_2_0 = (RuleCall)cSampleClauseAssignment_2.eContents().get(0);
		
		//// @THESIS
		//ObserveClause:
		//	mode='OBSERVE' observation=ObservationClause sampleClause=SampleClause?;
		@Override public ParserRule getRule() { return rule; }

		//mode='OBSERVE' observation=ObservationClause sampleClause=SampleClause?
		public Group getGroup() { return cGroup; }

		//mode='OBSERVE'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'OBSERVE'
		public Keyword getModeOBSERVEKeyword_0_0() { return cModeOBSERVEKeyword_0_0; }

		//observation=ObservationClause
		public Assignment getObservationAssignment_1() { return cObservationAssignment_1; }

		//ObservationClause
		public RuleCall getObservationObservationClauseParserRuleCall_1_0() { return cObservationObservationClauseParserRuleCall_1_0; }

		//sampleClause=SampleClause?
		public Assignment getSampleClauseAssignment_2() { return cSampleClauseAssignment_2; }

		//SampleClause
		public RuleCall getSampleClauseSampleClauseParserRuleCall_2_0() { return cSampleClauseSampleClauseParserRuleCall_2_0; }
	}

	public class ObservationClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ObservationClause");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cConnectorTimeUnitClauseParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cConnectorInstanceReferenceClauseParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		private final RuleCall cObserveRelativeClauseParserRuleCall_2 = (RuleCall)cAlternatives.eContents().get(2);
		private final RuleCall cObserveBetweenClauseParserRuleCall_3 = (RuleCall)cAlternatives.eContents().get(3);
		
		//// @THESIS
		//ObservationClause:
		//	ConnectorTimeUnitClause | ConnectorInstanceReferenceClause | ObserveRelativeClause | ObserveBetweenClause;
		@Override public ParserRule getRule() { return rule; }

		//ConnectorTimeUnitClause | ConnectorInstanceReferenceClause | ObserveRelativeClause | ObserveBetweenClause
		public Alternatives getAlternatives() { return cAlternatives; }

		//ConnectorTimeUnitClause
		public RuleCall getConnectorTimeUnitClauseParserRuleCall_0() { return cConnectorTimeUnitClauseParserRuleCall_0; }

		//ConnectorInstanceReferenceClause
		public RuleCall getConnectorInstanceReferenceClauseParserRuleCall_1() { return cConnectorInstanceReferenceClauseParserRuleCall_1; }

		//ObserveRelativeClause
		public RuleCall getObserveRelativeClauseParserRuleCall_2() { return cObserveRelativeClauseParserRuleCall_2; }

		//ObserveBetweenClause
		public RuleCall getObserveBetweenClauseParserRuleCall_3() { return cObserveBetweenClauseParserRuleCall_3; }
	}

	public class SampleClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.SampleClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cModeSAMPLEDBYKeyword_0_0 = (Keyword)cModeAssignment_0.eContents().get(0);
		private final Assignment cDurationClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cDurationClauseRelativeTimeDurationClauseParserRuleCall_1_0 = (RuleCall)cDurationClauseAssignment_1.eContents().get(0);
		private final Assignment cDurationClauseAssignment_2 = (Assignment)cGroup.eContents().get(2);
		private final RuleCall cDurationClauseRelativeTimeDurationClauseParserRuleCall_2_0 = (RuleCall)cDurationClauseAssignment_2.eContents().get(0);
		
		/// * Connector-dependent aggregation of values * / // @THESIS
		//SampleClause:
		//	mode='SAMPLED BY' durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*;
		@Override public ParserRule getRule() { return rule; }

		//mode='SAMPLED BY' durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*
		public Group getGroup() { return cGroup; }

		//mode='SAMPLED BY'
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//'SAMPLED BY'
		public Keyword getModeSAMPLEDBYKeyword_0_0() { return cModeSAMPLEDBYKeyword_0_0; }

		//durationClause+=RelativeTimeDurationClause
		public Assignment getDurationClauseAssignment_1() { return cDurationClauseAssignment_1; }

		//RelativeTimeDurationClause
		public RuleCall getDurationClauseRelativeTimeDurationClauseParserRuleCall_1_0() { return cDurationClauseRelativeTimeDurationClauseParserRuleCall_1_0; }

		//durationClause+=RelativeTimeDurationClause*
		public Assignment getDurationClauseAssignment_2() { return cDurationClauseAssignment_2; }

		//RelativeTimeDurationClause
		public RuleCall getDurationClauseRelativeTimeDurationClauseParserRuleCall_2_0() { return cDurationClauseRelativeTimeDurationClauseParserRuleCall_2_0; }
	}

	public class ConnectorTimeUnitClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ConnectorTimeUnitClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cCountAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cCountINTTerminalRuleCall_0_0 = (RuleCall)cCountAssignment_0.eContents().get(0);
		private final Assignment cTimeIndicatorAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cTimeIndicatorIDTerminalRuleCall_1_0 = (RuleCall)cTimeIndicatorAssignment_1.eContents().get(0);
		
		/// * Connector-dependent * / // @THESIS
		//ConnectorTimeUnitClause:
		//	count=INT timeIndicator=ID;
		@Override public ParserRule getRule() { return rule; }

		//count=INT timeIndicator=ID
		public Group getGroup() { return cGroup; }

		//count=INT
		public Assignment getCountAssignment_0() { return cCountAssignment_0; }

		//INT
		public RuleCall getCountINTTerminalRuleCall_0_0() { return cCountINTTerminalRuleCall_0_0; }

		//timeIndicator=ID
		public Assignment getTimeIndicatorAssignment_1() { return cTimeIndicatorAssignment_1; }

		//ID
		public RuleCall getTimeIndicatorIDTerminalRuleCall_1_0() { return cTimeIndicatorIDTerminalRuleCall_1_0; }
	}

	public class ConnectorInstanceReferenceClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ConnectorInstanceReferenceClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cTypeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cTypeIDTerminalRuleCall_0_0 = (RuleCall)cTypeAssignment_0.eContents().get(0);
		private final Assignment cIdentifierAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cIdentifierSTRINGTerminalRuleCall_1_0 = (RuleCall)cIdentifierAssignment_1.eContents().get(0);
		
		//// @THESIS
		//ConnectorInstanceReferenceClause:
		//	type=ID identifier=STRING;
		@Override public ParserRule getRule() { return rule; }

		//type=ID identifier=STRING
		public Group getGroup() { return cGroup; }

		//type=ID
		public Assignment getTypeAssignment_0() { return cTypeAssignment_0; }

		//ID
		public RuleCall getTypeIDTerminalRuleCall_0_0() { return cTypeIDTerminalRuleCall_0_0; }

		//identifier=STRING
		public Assignment getIdentifierAssignment_1() { return cIdentifierAssignment_1; }

		//STRING
		public RuleCall getIdentifierSTRINGTerminalRuleCall_1_0() { return cIdentifierSTRINGTerminalRuleCall_1_0; }
	}

	public class ObserveRelativeClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ObserveRelativeClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cDirectionAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cDirectionObserveRelativeDirectionTypeEnumRuleCall_0_0 = (RuleCall)cDirectionAssignment_0.eContents().get(0);
		private final Assignment cTimeTargetAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final Alternatives cTimeTargetAlternatives_1_0 = (Alternatives)cTimeTargetAssignment_1.eContents().get(0);
		private final RuleCall cTimeTargetAbsoluteTimeClauseParserRuleCall_1_0_0 = (RuleCall)cTimeTargetAlternatives_1_0.eContents().get(0);
		private final RuleCall cTimeTargetRelativeTimeClauseParserRuleCall_1_0_1 = (RuleCall)cTimeTargetAlternatives_1_0.eContents().get(1);
		
		/// * Specialization of BETWEEN * / // @THESIS
		//ObserveRelativeClause:
		//	direction=ObserveRelativeDirectionType timeTarget=(AbsoluteTimeClause | RelativeTimeClause);
		@Override public ParserRule getRule() { return rule; }

		//direction=ObserveRelativeDirectionType timeTarget=(AbsoluteTimeClause | RelativeTimeClause)
		public Group getGroup() { return cGroup; }

		//direction=ObserveRelativeDirectionType
		public Assignment getDirectionAssignment_0() { return cDirectionAssignment_0; }

		//ObserveRelativeDirectionType
		public RuleCall getDirectionObserveRelativeDirectionTypeEnumRuleCall_0_0() { return cDirectionObserveRelativeDirectionTypeEnumRuleCall_0_0; }

		//timeTarget=(AbsoluteTimeClause | RelativeTimeClause)
		public Assignment getTimeTargetAssignment_1() { return cTimeTargetAssignment_1; }

		//(AbsoluteTimeClause | RelativeTimeClause)
		public Alternatives getTimeTargetAlternatives_1_0() { return cTimeTargetAlternatives_1_0; }

		//AbsoluteTimeClause
		public RuleCall getTimeTargetAbsoluteTimeClauseParserRuleCall_1_0_0() { return cTimeTargetAbsoluteTimeClauseParserRuleCall_1_0_0; }

		//RelativeTimeClause
		public RuleCall getTimeTargetRelativeTimeClauseParserRuleCall_1_0_1() { return cTimeTargetRelativeTimeClauseParserRuleCall_1_0_1; }
	}

	public class ObserveBetweenClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ObserveBetweenClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cMode1Assignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Keyword cMode1BETWEENKeyword_0_0 = (Keyword)cMode1Assignment_0.eContents().get(0);
		private final Assignment cStartingTimeAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final Alternatives cStartingTimeAlternatives_1_0 = (Alternatives)cStartingTimeAssignment_1.eContents().get(0);
		private final RuleCall cStartingTimeAbsoluteTimeClauseParserRuleCall_1_0_0 = (RuleCall)cStartingTimeAlternatives_1_0.eContents().get(0);
		private final RuleCall cStartingTimeRelativeTimeWithSignClauseParserRuleCall_1_0_1 = (RuleCall)cStartingTimeAlternatives_1_0.eContents().get(1);
		private final Assignment cMode2Assignment_2 = (Assignment)cGroup.eContents().get(2);
		private final Keyword cMode2ANDKeyword_2_0 = (Keyword)cMode2Assignment_2.eContents().get(0);
		private final Assignment cEndingTimeAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final Alternatives cEndingTimeAlternatives_3_0 = (Alternatives)cEndingTimeAssignment_3.eContents().get(0);
		private final RuleCall cEndingTimeAbsoluteTimeClauseParserRuleCall_3_0_0 = (RuleCall)cEndingTimeAlternatives_3_0.eContents().get(0);
		private final RuleCall cEndingTimeRelativeTimeWithSignClauseParserRuleCall_3_0_1 = (RuleCall)cEndingTimeAlternatives_3_0.eContents().get(1);
		
		/// * Time-dependent (defined by DQL) * / // @THESIS
		//ObserveBetweenClause:
		//	mode1='BETWEEN' startingTime=(AbsoluteTimeClause | RelativeTimeWithSignClause) mode2='AND'
		//	endingTime=(AbsoluteTimeClause | RelativeTimeWithSignClause);
		@Override public ParserRule getRule() { return rule; }

		//mode1='BETWEEN' startingTime=(AbsoluteTimeClause | RelativeTimeWithSignClause) mode2='AND'
		//endingTime=(AbsoluteTimeClause | RelativeTimeWithSignClause)
		public Group getGroup() { return cGroup; }

		//mode1='BETWEEN'
		public Assignment getMode1Assignment_0() { return cMode1Assignment_0; }

		//'BETWEEN'
		public Keyword getMode1BETWEENKeyword_0_0() { return cMode1BETWEENKeyword_0_0; }

		//startingTime=(AbsoluteTimeClause | RelativeTimeWithSignClause)
		public Assignment getStartingTimeAssignment_1() { return cStartingTimeAssignment_1; }

		//(AbsoluteTimeClause | RelativeTimeWithSignClause)
		public Alternatives getStartingTimeAlternatives_1_0() { return cStartingTimeAlternatives_1_0; }

		//AbsoluteTimeClause
		public RuleCall getStartingTimeAbsoluteTimeClauseParserRuleCall_1_0_0() { return cStartingTimeAbsoluteTimeClauseParserRuleCall_1_0_0; }

		//RelativeTimeWithSignClause
		public RuleCall getStartingTimeRelativeTimeWithSignClauseParserRuleCall_1_0_1() { return cStartingTimeRelativeTimeWithSignClauseParserRuleCall_1_0_1; }

		//mode2='AND'
		public Assignment getMode2Assignment_2() { return cMode2Assignment_2; }

		//'AND'
		public Keyword getMode2ANDKeyword_2_0() { return cMode2ANDKeyword_2_0; }

		//endingTime=(AbsoluteTimeClause | RelativeTimeWithSignClause)
		public Assignment getEndingTimeAssignment_3() { return cEndingTimeAssignment_3; }

		//(AbsoluteTimeClause | RelativeTimeWithSignClause)
		public Alternatives getEndingTimeAlternatives_3_0() { return cEndingTimeAlternatives_3_0; }

		//AbsoluteTimeClause
		public RuleCall getEndingTimeAbsoluteTimeClauseParserRuleCall_3_0_0() { return cEndingTimeAbsoluteTimeClauseParserRuleCall_3_0_0; }

		//RelativeTimeWithSignClause
		public RuleCall getEndingTimeRelativeTimeWithSignClauseParserRuleCall_3_0_1() { return cEndingTimeRelativeTimeWithSignClauseParserRuleCall_3_0_1; }
	}

	public class RelativeTimeWithSignClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.RelativeTimeWithSignClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cSignAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cSignRelativeTimeSignTypeEnumRuleCall_0_0 = (RuleCall)cSignAssignment_0.eContents().get(0);
		private final Assignment cTimeClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cTimeClauseRelativeTimeClauseParserRuleCall_1_0 = (RuleCall)cTimeClauseAssignment_1.eContents().get(0);
		
		//// @THESIS
		//RelativeTimeWithSignClause:
		//	sign=RelativeTimeSignType timeClause=RelativeTimeClause;
		@Override public ParserRule getRule() { return rule; }

		//sign=RelativeTimeSignType timeClause=RelativeTimeClause
		public Group getGroup() { return cGroup; }

		//sign=RelativeTimeSignType
		public Assignment getSignAssignment_0() { return cSignAssignment_0; }

		//RelativeTimeSignType
		public RuleCall getSignRelativeTimeSignTypeEnumRuleCall_0_0() { return cSignRelativeTimeSignTypeEnumRuleCall_0_0; }

		//timeClause=RelativeTimeClause
		public Assignment getTimeClauseAssignment_1() { return cTimeClauseAssignment_1; }

		//RelativeTimeClause
		public RuleCall getTimeClauseRelativeTimeClauseParserRuleCall_1_0() { return cTimeClauseRelativeTimeClauseParserRuleCall_1_0; }
	}

	public class BetweenTimeClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.BetweenTimeClause");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cAbsoluteTimeClauseParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cRelativeTimeWithSignClauseParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		
		//BetweenTimeClause:
		//	AbsoluteTimeClause | RelativeTimeWithSignClause;
		@Override public ParserRule getRule() { return rule; }

		//AbsoluteTimeClause | RelativeTimeWithSignClause
		public Alternatives getAlternatives() { return cAlternatives; }

		//AbsoluteTimeClause
		public RuleCall getAbsoluteTimeClauseParserRuleCall_0() { return cAbsoluteTimeClauseParserRuleCall_0; }

		//RelativeTimeWithSignClause
		public RuleCall getRelativeTimeWithSignClauseParserRuleCall_1() { return cRelativeTimeWithSignClauseParserRuleCall_1; }
	}

	public class TimeClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.TimeClause");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final RuleCall cAbsoluteTimeClauseParserRuleCall_0 = (RuleCall)cAlternatives.eContents().get(0);
		private final RuleCall cRelativeTimeClauseParserRuleCall_1 = (RuleCall)cAlternatives.eContents().get(1);
		
		//TimeClause:
		//	AbsoluteTimeClause | RelativeTimeClause;
		@Override public ParserRule getRule() { return rule; }

		//AbsoluteTimeClause | RelativeTimeClause
		public Alternatives getAlternatives() { return cAlternatives; }

		//AbsoluteTimeClause
		public RuleCall getAbsoluteTimeClauseParserRuleCall_0() { return cAbsoluteTimeClauseParserRuleCall_0; }

		//RelativeTimeClause
		public RuleCall getRelativeTimeClauseParserRuleCall_1() { return cRelativeTimeClauseParserRuleCall_1; }
	}

	public class AbsoluteTimeClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.AbsoluteTimeClause");
		private final Assignment cTimeSpecAssignment = (Assignment)rule.eContents().get(1);
		private final RuleCall cTimeSpecSTRINGTerminalRuleCall_0 = (RuleCall)cTimeSpecAssignment.eContents().get(0);
		
		//// @THESIS
		//AbsoluteTimeClause:
		//	timeSpec=STRING;
		@Override public ParserRule getRule() { return rule; }

		//timeSpec=STRING
		public Assignment getTimeSpecAssignment() { return cTimeSpecAssignment; }

		//STRING
		public RuleCall getTimeSpecSTRINGTerminalRuleCall_0() { return cTimeSpecSTRINGTerminalRuleCall_0; }
	}

	public class RelativeTimeClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.RelativeTimeClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cDurationClauseAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cDurationClauseRelativeTimeDurationClauseParserRuleCall_0_0 = (RuleCall)cDurationClauseAssignment_0.eContents().get(0);
		private final Assignment cDurationClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cDurationClauseRelativeTimeDurationClauseParserRuleCall_1_0 = (RuleCall)cDurationClauseAssignment_1.eContents().get(0);
		
		//// @THESIS
		//RelativeTimeClause:
		//	durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*;
		@Override public ParserRule getRule() { return rule; }

		//durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*
		public Group getGroup() { return cGroup; }

		//durationClause+=RelativeTimeDurationClause
		public Assignment getDurationClauseAssignment_0() { return cDurationClauseAssignment_0; }

		//RelativeTimeDurationClause
		public RuleCall getDurationClauseRelativeTimeDurationClauseParserRuleCall_0_0() { return cDurationClauseRelativeTimeDurationClauseParserRuleCall_0_0; }

		//durationClause+=RelativeTimeDurationClause*
		public Assignment getDurationClauseAssignment_1() { return cDurationClauseAssignment_1; }

		//RelativeTimeDurationClause
		public RuleCall getDurationClauseRelativeTimeDurationClauseParserRuleCall_1_0() { return cDurationClauseRelativeTimeDurationClauseParserRuleCall_1_0; }
	}

	public class RelativeTimeDurationClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.RelativeTimeDurationClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cDurationAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cDurationINTTerminalRuleCall_0_0 = (RuleCall)cDurationAssignment_0.eContents().get(0);
		private final Assignment cTimeModifierAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cTimeModifierTimeModifierTypeEnumRuleCall_1_0 = (RuleCall)cTimeModifierAssignment_1.eContents().get(0);
		
		//// @THESIS
		//RelativeTimeDurationClause:
		//	duration=INT timeModifier=TimeModifierType;
		@Override public ParserRule getRule() { return rule; }

		//duration=INT timeModifier=TimeModifierType
		public Group getGroup() { return cGroup; }

		//duration=INT
		public Assignment getDurationAssignment_0() { return cDurationAssignment_0; }

		//INT
		public RuleCall getDurationINTTerminalRuleCall_0_0() { return cDurationINTTerminalRuleCall_0_0; }

		//timeModifier=TimeModifierType
		public Assignment getTimeModifierAssignment_1() { return cTimeModifierAssignment_1; }

		//TimeModifierType
		public RuleCall getTimeModifierTimeModifierTypeEnumRuleCall_1_0() { return cTimeModifierTimeModifierTypeEnumRuleCall_1_0; }
	}

	public class WhatIfQueryElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.WhatIfQuery");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cWHATIFKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cWhatIfVariationAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cWhatIfVariationWhatIfVariationParserRuleCall_1_0 = (RuleCall)cWhatIfVariationAssignment_1.eContents().get(0);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cSELECTKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cMetricReferenceClausesAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cMetricReferenceClausesMetricReferenceClausesParserRuleCall_2_1_0 = (RuleCall)cMetricReferenceClausesAssignment_2_1.eContents().get(0);
		private final Assignment cForClauseAssignment_2_2 = (Assignment)cGroup_2.eContents().get(2);
		private final RuleCall cForClauseForClauseParserRuleCall_2_2_0 = (RuleCall)cForClauseAssignment_2_2.eContents().get(0);
		private final Assignment cFilteringClauseAssignment_3 = (Assignment)cGroup.eContents().get(3);
		private final RuleCall cFilteringClauseFilteringClauseParserRuleCall_3_0 = (RuleCall)cFilteringClauseAssignment_3.eContents().get(0);
		private final Assignment cDeltaClauseAssignment_4 = (Assignment)cGroup.eContents().get(4);
		private final RuleCall cDeltaClauseDeltaClauseParserRuleCall_4_0 = (RuleCall)cDeltaClauseAssignment_4.eContents().get(0);
		private final Assignment cUsingClauseAssignment_5 = (Assignment)cGroup.eContents().get(5);
		private final RuleCall cUsingClauseUsingClauseParserRuleCall_5_0 = (RuleCall)cUsingClauseAssignment_5.eContents().get(0);
		
		/// **
		// * Following lines of code are added during the Bachelor Thesis of Andreas Knapp at the University of Wuerzburg (Germany) to extend DQL with a "What if...?" feature
		// * / // @BachelorThesis_AndreasKnapp
		//WhatIfQuery:
		//	'WHAT IF' whatIfVariation=WhatIfVariation ('SELECT'
		//	metricReferenceClauses=MetricReferenceClauses forClause=ForClause)?
		//	filteringClause=FilteringClause? deltaClause=DeltaClause? usingClause=UsingClause;
		@Override public ParserRule getRule() { return rule; }

		//'WHAT IF' whatIfVariation=WhatIfVariation ('SELECT' metricReferenceClauses=MetricReferenceClauses forClause=ForClause)?
		//filteringClause=FilteringClause? deltaClause=DeltaClause? usingClause=UsingClause
		public Group getGroup() { return cGroup; }

		//'WHAT IF'
		public Keyword getWHATIFKeyword_0() { return cWHATIFKeyword_0; }

		//whatIfVariation=WhatIfVariation
		public Assignment getWhatIfVariationAssignment_1() { return cWhatIfVariationAssignment_1; }

		//WhatIfVariation
		public RuleCall getWhatIfVariationWhatIfVariationParserRuleCall_1_0() { return cWhatIfVariationWhatIfVariationParserRuleCall_1_0; }

		//('SELECT' metricReferenceClauses=MetricReferenceClauses forClause=ForClause)?
		public Group getGroup_2() { return cGroup_2; }

		//'SELECT'
		public Keyword getSELECTKeyword_2_0() { return cSELECTKeyword_2_0; }

		//metricReferenceClauses=MetricReferenceClauses
		public Assignment getMetricReferenceClausesAssignment_2_1() { return cMetricReferenceClausesAssignment_2_1; }

		//MetricReferenceClauses
		public RuleCall getMetricReferenceClausesMetricReferenceClausesParserRuleCall_2_1_0() { return cMetricReferenceClausesMetricReferenceClausesParserRuleCall_2_1_0; }

		//forClause=ForClause
		public Assignment getForClauseAssignment_2_2() { return cForClauseAssignment_2_2; }

		//ForClause
		public RuleCall getForClauseForClauseParserRuleCall_2_2_0() { return cForClauseForClauseParserRuleCall_2_2_0; }

		//filteringClause=FilteringClause?
		public Assignment getFilteringClauseAssignment_3() { return cFilteringClauseAssignment_3; }

		//FilteringClause
		public RuleCall getFilteringClauseFilteringClauseParserRuleCall_3_0() { return cFilteringClauseFilteringClauseParserRuleCall_3_0; }

		//deltaClause=DeltaClause?
		public Assignment getDeltaClauseAssignment_4() { return cDeltaClauseAssignment_4; }

		//DeltaClause
		public RuleCall getDeltaClauseDeltaClauseParserRuleCall_4_0() { return cDeltaClauseDeltaClauseParserRuleCall_4_0; }

		//usingClause=UsingClause
		public Assignment getUsingClauseAssignment_5() { return cUsingClauseAssignment_5; }

		//UsingClause
		public RuleCall getUsingClauseUsingClauseParserRuleCall_5_0() { return cUsingClauseUsingClauseParserRuleCall_5_0; }
	}

	public class DeltaClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.DeltaClause");
		private final Keyword cDELTAKeyword = (Keyword)rule.eContents().get(1);
		
		//DeltaClause:
		//	'DELTA';
		@Override public ParserRule getRule() { return rule; }

		//'DELTA'
		public Keyword getDELTAKeyword() { return cDELTAKeyword; }
	}

	public class WhatIfVariationElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.WhatIfVariation");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cWhatIfVariationClauseAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cWhatIfVariationClauseWhatIfVariationClauseParserRuleCall_0_0 = (RuleCall)cWhatIfVariationClauseAssignment_0.eContents().get(0);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Keyword cCommaKeyword_1_0 = (Keyword)cGroup_1.eContents().get(0);
		private final Assignment cWhatIfVariationClauseAssignment_1_1 = (Assignment)cGroup_1.eContents().get(1);
		private final RuleCall cWhatIfVariationClauseWhatIfVariationClauseParserRuleCall_1_1_0 = (RuleCall)cWhatIfVariationClauseAssignment_1_1.eContents().get(0);
		
		//WhatIfVariation:
		//	whatIfVariationClause+=WhatIfVariationClause (',' whatIfVariationClause+=WhatIfVariationClause)*;
		@Override public ParserRule getRule() { return rule; }

		//whatIfVariationClause+=WhatIfVariationClause (',' whatIfVariationClause+=WhatIfVariationClause)*
		public Group getGroup() { return cGroup; }

		//whatIfVariationClause+=WhatIfVariationClause
		public Assignment getWhatIfVariationClauseAssignment_0() { return cWhatIfVariationClauseAssignment_0; }

		//WhatIfVariationClause
		public RuleCall getWhatIfVariationClauseWhatIfVariationClauseParserRuleCall_0_0() { return cWhatIfVariationClauseWhatIfVariationClauseParserRuleCall_0_0; }

		//(',' whatIfVariationClause+=WhatIfVariationClause)*
		public Group getGroup_1() { return cGroup_1; }

		//','
		public Keyword getCommaKeyword_1_0() { return cCommaKeyword_1_0; }

		//whatIfVariationClause+=WhatIfVariationClause
		public Assignment getWhatIfVariationClauseAssignment_1_1() { return cWhatIfVariationClauseAssignment_1_1; }

		//WhatIfVariationClause
		public RuleCall getWhatIfVariationClauseWhatIfVariationClauseParserRuleCall_1_1_0() { return cWhatIfVariationClauseWhatIfVariationClauseParserRuleCall_1_1_0; }
	}

	public class FilteringClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.FilteringClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cFILTERINGKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Alternatives cAlternatives_1 = (Alternatives)cGroup.eContents().get(1);
		private final Assignment cFilteringRuleAssignment_1_0 = (Assignment)cAlternatives_1.eContents().get(0);
		private final RuleCall cFilteringRuleFilteringRuleParserRuleCall_1_0_0 = (RuleCall)cFilteringRuleAssignment_1_0.eContents().get(0);
		private final Assignment cFilteringStrategyAssignment_1_1 = (Assignment)cAlternatives_1.eContents().get(1);
		private final RuleCall cFilteringStrategyFilteringStrategyParserRuleCall_1_1_0 = (RuleCall)cFilteringStrategyAssignment_1_1.eContents().get(0);
		
		//// Filtering Clause for WhatIfQuery, filtering Values (other filtering then filtering for lists)
		//FilteringClause:
		//	'FILTERING' (filteringRule=FilteringRule | filteringStrategy=FilteringStrategy);
		@Override public ParserRule getRule() { return rule; }

		//'FILTERING' (filteringRule=FilteringRule | filteringStrategy=FilteringStrategy)
		public Group getGroup() { return cGroup; }

		//'FILTERING'
		public Keyword getFILTERINGKeyword_0() { return cFILTERINGKeyword_0; }

		//(filteringRule=FilteringRule | filteringStrategy=FilteringStrategy)
		public Alternatives getAlternatives_1() { return cAlternatives_1; }

		//filteringRule=FilteringRule
		public Assignment getFilteringRuleAssignment_1_0() { return cFilteringRuleAssignment_1_0; }

		//FilteringRule
		public RuleCall getFilteringRuleFilteringRuleParserRuleCall_1_0_0() { return cFilteringRuleFilteringRuleParserRuleCall_1_0_0; }

		//filteringStrategy=FilteringStrategy
		public Assignment getFilteringStrategyAssignment_1_1() { return cFilteringStrategyAssignment_1_1; }

		//FilteringStrategy
		public RuleCall getFilteringStrategyFilteringStrategyParserRuleCall_1_1_0() { return cFilteringStrategyFilteringStrategyParserRuleCall_1_1_0; }
	}

	public class FilteringStrategyElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.FilteringStrategy");
		private final Assignment cFilteringStrategyAssignment = (Assignment)rule.eContents().get(1);
		private final RuleCall cFilteringStrategySTRINGTerminalRuleCall_0 = (RuleCall)cFilteringStrategyAssignment.eContents().get(0);
		
		////Mögliche Erweiterung mit "Filter-Subqueries"
		//// Connectorimplemented filtering strategy
		//FilteringStrategy:
		//	filteringStrategy=STRING;
		@Override public ParserRule getRule() { return rule; }

		//filteringStrategy=STRING
		public Assignment getFilteringStrategyAssignment() { return cFilteringStrategyAssignment; }

		//STRING
		public RuleCall getFilteringStrategySTRINGTerminalRuleCall_0() { return cFilteringStrategySTRINGTerminalRuleCall_0; }
	}

	public class FilteringRuleElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.FilteringRule");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cFilteringValueAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cFilteringValueVariableValueParserRuleCall_0_0 = (RuleCall)cFilteringValueAssignment_0.eContents().get(0);
		private final Assignment cModifierAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final Keyword cModifierPercentSignKeyword_1_0 = (Keyword)cModifierAssignment_1.eContents().get(0);
		
		//// User-defined ignoring for values. If % used, relativ value less then "value" are ignored, else absolut values
		//FilteringRule:
		//	filteringValue=VariableValue modifier='%'?;
		@Override public ParserRule getRule() { return rule; }

		//filteringValue=VariableValue modifier='%'?
		public Group getGroup() { return cGroup; }

		//filteringValue=VariableValue
		public Assignment getFilteringValueAssignment_0() { return cFilteringValueAssignment_0; }

		//VariableValue
		public RuleCall getFilteringValueVariableValueParserRuleCall_0_0() { return cFilteringValueVariableValueParserRuleCall_0_0; }

		//modifier='%'?
		public Assignment getModifierAssignment_1() { return cModifierAssignment_1; }

		//'%'
		public Keyword getModifierPercentSignKeyword_1_0() { return cModifierPercentSignKeyword_1_0; }
	}

	public class WhatIfVariationClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.WhatIfVariationClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cVariationPointAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cVariationPointSTRINGTerminalRuleCall_0_0 = (RuleCall)cVariationPointAssignment_0.eContents().get(0);
		private final Assignment cValuesAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cValuesWhatIfValueVariationClauseParserRuleCall_1_0 = (RuleCall)cValuesAssignment_1.eContents().get(0);
		
		//// changeable values for WhatIfQuery
		//WhatIfVariationClause:
		//	variationPoint=STRING values=WhatIfValueVariationClause;
		@Override public ParserRule getRule() { return rule; }

		//variationPoint=STRING values=WhatIfValueVariationClause
		public Group getGroup() { return cGroup; }

		//variationPoint=STRING
		public Assignment getVariationPointAssignment_0() { return cVariationPointAssignment_0; }

		//STRING
		public RuleCall getVariationPointSTRINGTerminalRuleCall_0_0() { return cVariationPointSTRINGTerminalRuleCall_0_0; }

		//values=WhatIfValueVariationClause
		public Assignment getValuesAssignment_1() { return cValuesAssignment_1; }

		//WhatIfValueVariationClause
		public RuleCall getValuesWhatIfValueVariationClauseParserRuleCall_1_0() { return cValuesWhatIfValueVariationClauseParserRuleCall_1_0; }
	}

	public class WhatIfValueVariationClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.WhatIfValueVariationClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cLessThanSignKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cVariationClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final Alternatives cVariationClauseAlternatives_1_0 = (Alternatives)cVariationClauseAssignment_1.eContents().get(0);
		private final RuleCall cVariationClauseIntervalVariationClauseParserRuleCall_1_0_0 = (RuleCall)cVariationClauseAlternatives_1_0.eContents().get(0);
		private final RuleCall cVariationClauseValueVariationClauseParserRuleCall_1_0_1 = (RuleCall)cVariationClauseAlternatives_1_0.eContents().get(1);
		private final RuleCall cVariationClauseArithmeticClauseParserRuleCall_1_0_2 = (RuleCall)cVariationClauseAlternatives_1_0.eContents().get(2);
		private final RuleCall cVariationClauseVariationInstructionParserRuleCall_1_0_3 = (RuleCall)cVariationClauseAlternatives_1_0.eContents().get(3);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cCommaKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cVariationClauseAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final Alternatives cVariationClauseAlternatives_2_1_0 = (Alternatives)cVariationClauseAssignment_2_1.eContents().get(0);
		private final RuleCall cVariationClauseIntervalVariationClauseParserRuleCall_2_1_0_0 = (RuleCall)cVariationClauseAlternatives_2_1_0.eContents().get(0);
		private final RuleCall cVariationClauseValueVariationClauseParserRuleCall_2_1_0_1 = (RuleCall)cVariationClauseAlternatives_2_1_0.eContents().get(1);
		private final RuleCall cVariationClauseArithmeticClauseParserRuleCall_2_1_0_2 = (RuleCall)cVariationClauseAlternatives_2_1_0.eContents().get(2);
		private final RuleCall cVariationClauseVariationInstructionParserRuleCall_2_1_0_3 = (RuleCall)cVariationClauseAlternatives_2_1_0.eContents().get(3);
		private final Keyword cGreaterThanSignKeyword_3 = (Keyword)cGroup.eContents().get(3);
		
		//// Values can change like DoFVariationClauses (already exists) or like new ArithmeticClauses
		//WhatIfValueVariationClause:
		//	'<' variationClause+=(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction) (','
		//	variationClause+=(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction)+)*
		//	'>'
		//	// DoFVariationClause already existing
		//;
		@Override public ParserRule getRule() { return rule; }

		//'<' variationClause+=(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction) (','
		//variationClause+=(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction)+)* '>'
		public Group getGroup() { return cGroup; }

		//'<'
		public Keyword getLessThanSignKeyword_0() { return cLessThanSignKeyword_0; }

		//variationClause+=(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction)
		public Assignment getVariationClauseAssignment_1() { return cVariationClauseAssignment_1; }

		//(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction)
		public Alternatives getVariationClauseAlternatives_1_0() { return cVariationClauseAlternatives_1_0; }

		//IntervalVariationClause
		public RuleCall getVariationClauseIntervalVariationClauseParserRuleCall_1_0_0() { return cVariationClauseIntervalVariationClauseParserRuleCall_1_0_0; }

		//ValueVariationClause
		public RuleCall getVariationClauseValueVariationClauseParserRuleCall_1_0_1() { return cVariationClauseValueVariationClauseParserRuleCall_1_0_1; }

		//ArithmeticClause
		public RuleCall getVariationClauseArithmeticClauseParserRuleCall_1_0_2() { return cVariationClauseArithmeticClauseParserRuleCall_1_0_2; }

		//VariationInstruction
		public RuleCall getVariationClauseVariationInstructionParserRuleCall_1_0_3() { return cVariationClauseVariationInstructionParserRuleCall_1_0_3; }

		//(',' variationClause+=(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction)+)*
		public Group getGroup_2() { return cGroup_2; }

		//','
		public Keyword getCommaKeyword_2_0() { return cCommaKeyword_2_0; }

		//variationClause+=(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction)+
		public Assignment getVariationClauseAssignment_2_1() { return cVariationClauseAssignment_2_1; }

		//(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction)
		public Alternatives getVariationClauseAlternatives_2_1_0() { return cVariationClauseAlternatives_2_1_0; }

		//IntervalVariationClause
		public RuleCall getVariationClauseIntervalVariationClauseParserRuleCall_2_1_0_0() { return cVariationClauseIntervalVariationClauseParserRuleCall_2_1_0_0; }

		//ValueVariationClause
		public RuleCall getVariationClauseValueVariationClauseParserRuleCall_2_1_0_1() { return cVariationClauseValueVariationClauseParserRuleCall_2_1_0_1; }

		//ArithmeticClause
		public RuleCall getVariationClauseArithmeticClauseParserRuleCall_2_1_0_2() { return cVariationClauseArithmeticClauseParserRuleCall_2_1_0_2; }

		//VariationInstruction
		public RuleCall getVariationClauseVariationInstructionParserRuleCall_2_1_0_3() { return cVariationClauseVariationInstructionParserRuleCall_2_1_0_3; }

		//'>'
		public Keyword getGreaterThanSignKeyword_3() { return cGreaterThanSignKeyword_3; }
	}

	public class MultipleVariationInstructionElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.MultipleVariationInstruction");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cLessThanSignKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cMultiVariationAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cMultiVariationVariationInstructionParserRuleCall_1_0 = (RuleCall)cMultiVariationAssignment_1.eContents().get(0);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cCommaKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cMultiVariationAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cMultiVariationVariationInstructionParserRuleCall_2_1_0 = (RuleCall)cMultiVariationAssignment_2_1.eContents().get(0);
		private final Keyword cGreaterThanSignKeyword_3 = (Keyword)cGroup.eContents().get(3);
		
		//MultipleVariationInstruction:
		//	'<' multiVariation+=VariationInstruction (',' multiVariation+=VariationInstruction)* '>';
		@Override public ParserRule getRule() { return rule; }

		//'<' multiVariation+=VariationInstruction (',' multiVariation+=VariationInstruction)* '>'
		public Group getGroup() { return cGroup; }

		//'<'
		public Keyword getLessThanSignKeyword_0() { return cLessThanSignKeyword_0; }

		//multiVariation+=VariationInstruction
		public Assignment getMultiVariationAssignment_1() { return cMultiVariationAssignment_1; }

		//VariationInstruction
		public RuleCall getMultiVariationVariationInstructionParserRuleCall_1_0() { return cMultiVariationVariationInstructionParserRuleCall_1_0; }

		//(',' multiVariation+=VariationInstruction)*
		public Group getGroup_2() { return cGroup_2; }

		//','
		public Keyword getCommaKeyword_2_0() { return cCommaKeyword_2_0; }

		//multiVariation+=VariationInstruction
		public Assignment getMultiVariationAssignment_2_1() { return cMultiVariationAssignment_2_1; }

		//VariationInstruction
		public RuleCall getMultiVariationVariationInstructionParserRuleCall_2_1_0() { return cMultiVariationVariationInstructionParserRuleCall_2_1_0; }

		//'>'
		public Keyword getGreaterThanSignKeyword_3() { return cGreaterThanSignKeyword_3; }
	}

	public class VariationInstructionElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.VariationInstruction");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cVariationAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final RuleCall cVariationIDTerminalRuleCall_0_0 = (RuleCall)cVariationAssignment_0.eContents().get(0);
		private final Group cGroup_1 = (Group)cGroup.eContents().get(1);
		private final Keyword cLeftParenthesisKeyword_1_0 = (Keyword)cGroup_1.eContents().get(0);
		private final Assignment cArgumentAssignment_1_1 = (Assignment)cGroup_1.eContents().get(1);
		private final RuleCall cArgumentSTRINGTerminalRuleCall_1_1_0 = (RuleCall)cArgumentAssignment_1_1.eContents().get(0);
		private final Keyword cRightParenthesisKeyword_1_2 = (Keyword)cGroup_1.eContents().get(2);
		
		//VariationInstruction:
		//	variation=ID ('(' argument=STRING ')');
		@Override public ParserRule getRule() { return rule; }

		//variation=ID ('(' argument=STRING ')')
		public Group getGroup() { return cGroup; }

		//variation=ID
		public Assignment getVariationAssignment_0() { return cVariationAssignment_0; }

		//ID
		public RuleCall getVariationIDTerminalRuleCall_0_0() { return cVariationIDTerminalRuleCall_0_0; }

		//('(' argument=STRING ')')
		public Group getGroup_1() { return cGroup_1; }

		//'('
		public Keyword getLeftParenthesisKeyword_1_0() { return cLeftParenthesisKeyword_1_0; }

		//argument=STRING
		public Assignment getArgumentAssignment_1_1() { return cArgumentAssignment_1_1; }

		//STRING
		public RuleCall getArgumentSTRINGTerminalRuleCall_1_1_0() { return cArgumentSTRINGTerminalRuleCall_1_1_0; }

		//')'
		public Keyword getRightParenthesisKeyword_1_2() { return cRightParenthesisKeyword_1_2; }
	}

	public class MultipleArithmeticClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.MultipleArithmeticClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Keyword cLessThanSignKeyword_0 = (Keyword)cGroup.eContents().get(0);
		private final Assignment cMultiClauseAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cMultiClauseArithmeticClauseParserRuleCall_1_0 = (RuleCall)cMultiClauseAssignment_1.eContents().get(0);
		private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
		private final Keyword cCommaKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
		private final Assignment cMultiClauseAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
		private final RuleCall cMultiClauseArithmeticClauseParserRuleCall_2_1_0 = (RuleCall)cMultiClauseAssignment_2_1.eContents().get(0);
		private final Keyword cGreaterThanSignKeyword_3 = (Keyword)cGroup.eContents().get(3);
		
		//// To enable things like 'var1' <ADD 10, ADD 10>
		//MultipleArithmeticClause:
		//	'<' multiClause+=ArithmeticClause (',' multiClause+=ArithmeticClause)* '>';
		@Override public ParserRule getRule() { return rule; }

		//'<' multiClause+=ArithmeticClause (',' multiClause+=ArithmeticClause)* '>'
		public Group getGroup() { return cGroup; }

		//'<'
		public Keyword getLessThanSignKeyword_0() { return cLessThanSignKeyword_0; }

		//multiClause+=ArithmeticClause
		public Assignment getMultiClauseAssignment_1() { return cMultiClauseAssignment_1; }

		//ArithmeticClause
		public RuleCall getMultiClauseArithmeticClauseParserRuleCall_1_0() { return cMultiClauseArithmeticClauseParserRuleCall_1_0; }

		//(',' multiClause+=ArithmeticClause)*
		public Group getGroup_2() { return cGroup_2; }

		//','
		public Keyword getCommaKeyword_2_0() { return cCommaKeyword_2_0; }

		//multiClause+=ArithmeticClause
		public Assignment getMultiClauseAssignment_2_1() { return cMultiClauseAssignment_2_1; }

		//ArithmeticClause
		public RuleCall getMultiClauseArithmeticClauseParserRuleCall_2_1_0() { return cMultiClauseArithmeticClauseParserRuleCall_2_1_0; }

		//'>'
		public Keyword getGreaterThanSignKeyword_3() { return cGreaterThanSignKeyword_3; }
	}

	public class ArithmeticClauseElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ArithmeticClause");
		private final Group cGroup = (Group)rule.eContents().get(1);
		private final Assignment cModeAssignment_0 = (Assignment)cGroup.eContents().get(0);
		private final Alternatives cModeAlternatives_0_0 = (Alternatives)cModeAssignment_0.eContents().get(0);
		private final Keyword cModeADDKeyword_0_0_0 = (Keyword)cModeAlternatives_0_0.eContents().get(0);
		private final Keyword cModeSUBKeyword_0_0_1 = (Keyword)cModeAlternatives_0_0.eContents().get(1);
		private final Keyword cModeMULTIPLYKeyword_0_0_2 = (Keyword)cModeAlternatives_0_0.eContents().get(2);
		private final Assignment cValueAssignment_1 = (Assignment)cGroup.eContents().get(1);
		private final RuleCall cValueVariableValueParserRuleCall_1_0 = (RuleCall)cValueAssignment_1.eContents().get(0);
		
		//// To add Valuechangeing like "MULTIPLY 2" for example double usercount on a server
		//ArithmeticClause:
		//	mode=('ADD' | 'SUB' | 'MULTIPLY') value=VariableValue;
		@Override public ParserRule getRule() { return rule; }

		//mode=('ADD' | 'SUB' | 'MULTIPLY') value=VariableValue
		public Group getGroup() { return cGroup; }

		//mode=('ADD' | 'SUB' | 'MULTIPLY')
		public Assignment getModeAssignment_0() { return cModeAssignment_0; }

		//('ADD' | 'SUB' | 'MULTIPLY')
		public Alternatives getModeAlternatives_0_0() { return cModeAlternatives_0_0; }

		//'ADD'
		public Keyword getModeADDKeyword_0_0_0() { return cModeADDKeyword_0_0_0; }

		//'SUB'
		public Keyword getModeSUBKeyword_0_0_1() { return cModeSUBKeyword_0_0_1; }

		//'MULTIPLY'
		public Keyword getModeMULTIPLYKeyword_0_0_2() { return cModeMULTIPLYKeyword_0_0_2; }

		//value=VariableValue
		public Assignment getValueAssignment_1() { return cValueAssignment_1; }

		//VariableValue
		public RuleCall getValueVariableValueParserRuleCall_1_0() { return cValueVariableValueParserRuleCall_1_0; }
	}

	public class VariableValueElements extends AbstractParserRuleElementFinder {
		private final ParserRule rule = (ParserRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.VariableValue");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final Assignment cIntValueAssignment_0 = (Assignment)cAlternatives.eContents().get(0);
		private final RuleCall cIntValueINTTerminalRuleCall_0_0 = (RuleCall)cIntValueAssignment_0.eContents().get(0);
		private final Assignment cDoubleValueAssignment_1 = (Assignment)cAlternatives.eContents().get(1);
		private final RuleCall cDoubleValueDOUBLETerminalRuleCall_1_0 = (RuleCall)cDoubleValueAssignment_1.eContents().get(0);
		
		//// To Enable Integer and Double Values
		//VariableValue:
		//	intValue=INT | doubleValue=DOUBLE;
		@Override public ParserRule getRule() { return rule; }

		//intValue=INT | doubleValue=DOUBLE
		public Alternatives getAlternatives() { return cAlternatives; }

		//intValue=INT
		public Assignment getIntValueAssignment_0() { return cIntValueAssignment_0; }

		//INT
		public RuleCall getIntValueINTTerminalRuleCall_0_0() { return cIntValueINTTerminalRuleCall_0_0; }

		//doubleValue=DOUBLE
		public Assignment getDoubleValueAssignment_1() { return cDoubleValueAssignment_1; }

		//DOUBLE
		public RuleCall getDoubleValueDOUBLETerminalRuleCall_1_0() { return cDoubleValueDOUBLETerminalRuleCall_1_0; }
	}
	
	
	public class ComparatorElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.Comparator");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cLessEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cLessLessThanSignKeyword_0_0 = (Keyword)cLessEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cLessEqualEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cLessEqualLessThanSignEqualsSignKeyword_1_0 = (Keyword)cLessEqualEnumLiteralDeclaration_1.eContents().get(0);
		private final EnumLiteralDeclaration cGreaterEnumLiteralDeclaration_2 = (EnumLiteralDeclaration)cAlternatives.eContents().get(2);
		private final Keyword cGreaterGreaterThanSignKeyword_2_0 = (Keyword)cGreaterEnumLiteralDeclaration_2.eContents().get(0);
		private final EnumLiteralDeclaration cGreaterEqualEnumLiteralDeclaration_3 = (EnumLiteralDeclaration)cAlternatives.eContents().get(3);
		private final Keyword cGreaterEqualGreaterThanSignEqualsSignKeyword_3_0 = (Keyword)cGreaterEqualEnumLiteralDeclaration_3.eContents().get(0);
		private final EnumLiteralDeclaration cEqualEnumLiteralDeclaration_4 = (EnumLiteralDeclaration)cAlternatives.eContents().get(4);
		private final Keyword cEqualEqualsSignEqualsSignKeyword_4_0 = (Keyword)cEqualEnumLiteralDeclaration_4.eContents().get(0);
		
		//enum Comparator:
		//	less='<' | lessEqual='<=' | greater='>' | greaterEqual='>=' | equal='==';
		public EnumRule getRule() { return rule; }

		//less='<' | lessEqual='<=' | greater='>' | greaterEqual='>=' | equal='=='
		public Alternatives getAlternatives() { return cAlternatives; }

		//less='<'
		public EnumLiteralDeclaration getLessEnumLiteralDeclaration_0() { return cLessEnumLiteralDeclaration_0; }

		//'<'
		public Keyword getLessLessThanSignKeyword_0_0() { return cLessLessThanSignKeyword_0_0; }

		//lessEqual='<='
		public EnumLiteralDeclaration getLessEqualEnumLiteralDeclaration_1() { return cLessEqualEnumLiteralDeclaration_1; }

		//'<='
		public Keyword getLessEqualLessThanSignEqualsSignKeyword_1_0() { return cLessEqualLessThanSignEqualsSignKeyword_1_0; }

		//greater='>'
		public EnumLiteralDeclaration getGreaterEnumLiteralDeclaration_2() { return cGreaterEnumLiteralDeclaration_2; }

		//'>'
		public Keyword getGreaterGreaterThanSignKeyword_2_0() { return cGreaterGreaterThanSignKeyword_2_0; }

		//greaterEqual='>='
		public EnumLiteralDeclaration getGreaterEqualEnumLiteralDeclaration_3() { return cGreaterEqualEnumLiteralDeclaration_3; }

		//'>='
		public Keyword getGreaterEqualGreaterThanSignEqualsSignKeyword_3_0() { return cGreaterEqualGreaterThanSignEqualsSignKeyword_3_0; }

		//equal='=='
		public EnumLiteralDeclaration getEqualEnumLiteralDeclaration_4() { return cEqualEnumLiteralDeclaration_4; }

		//'=='
		public Keyword getEqualEqualsSignEqualsSignKeyword_4_0() { return cEqualEqualsSignEqualsSignKeyword_4_0; }
	}

	public class CurrencyElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.Currency");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cEuroEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cEuroEURKeyword_0_0 = (Keyword)cEuroEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cUsDollarEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cUsDollarUSDKeyword_1_0 = (Keyword)cUsDollarEnumLiteralDeclaration_1.eContents().get(0);
		
		//enum Currency:
		//	euro='EUR' | usDollar='USD';
		public EnumRule getRule() { return rule; }

		//euro='EUR' | usDollar='USD'
		public Alternatives getAlternatives() { return cAlternatives; }

		//euro='EUR'
		public EnumLiteralDeclaration getEuroEnumLiteralDeclaration_0() { return cEuroEnumLiteralDeclaration_0; }

		//'EUR'
		public Keyword getEuroEURKeyword_0_0() { return cEuroEURKeyword_0_0; }

		//usDollar='USD'
		public EnumLiteralDeclaration getUsDollarEnumLiteralDeclaration_1() { return cUsDollarEnumLiteralDeclaration_1; }

		//'USD'
		public Keyword getUsDollarUSDKeyword_1_0() { return cUsDollarUSDKeyword_1_0; }
	}

	public class FilterConjunctionElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.FilterConjunction");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cANDEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cANDANDKeyword_0_0 = (Keyword)cANDEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cXOREnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cXORXORKeyword_1_0 = (Keyword)cXOREnumLiteralDeclaration_1.eContents().get(0);
		private final EnumLiteralDeclaration cOREnumLiteralDeclaration_2 = (EnumLiteralDeclaration)cAlternatives.eContents().get(2);
		private final Keyword cORORKeyword_2_0 = (Keyword)cOREnumLiteralDeclaration_2.eContents().get(0);
		
		//enum FilterConjunction:
		//	AND | XOR | OR;
		public EnumRule getRule() { return rule; }

		//AND | XOR | OR
		public Alternatives getAlternatives() { return cAlternatives; }

		//AND
		public EnumLiteralDeclaration getANDEnumLiteralDeclaration_0() { return cANDEnumLiteralDeclaration_0; }

		//'AND'
		public Keyword getANDANDKeyword_0_0() { return cANDANDKeyword_0_0; }

		//XOR
		public EnumLiteralDeclaration getXOREnumLiteralDeclaration_1() { return cXOREnumLiteralDeclaration_1; }

		//'XOR'
		public Keyword getXORXORKeyword_1_0() { return cXORXORKeyword_1_0; }

		//OR
		public EnumLiteralDeclaration getOREnumLiteralDeclaration_2() { return cOREnumLiteralDeclaration_2; }

		//'OR'
		public Keyword getORORKeyword_2_0() { return cORORKeyword_2_0; }
	}

	public class FilterConditionTypeElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.FilterConditionType");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cINSTANCEOFEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cINSTANCEOFINSTANCEOFKeyword_0_0 = (Keyword)cINSTANCEOFEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cCLASSREGEXEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cCLASSREGEXCLASSREGEXKeyword_1_0 = (Keyword)cCLASSREGEXEnumLiteralDeclaration_1.eContents().get(0);
		
		//enum FilterConditionType:
		//	INSTANCEOF | CLASSREGEX;
		public EnumRule getRule() { return rule; }

		//INSTANCEOF | CLASSREGEX
		public Alternatives getAlternatives() { return cAlternatives; }

		//INSTANCEOF
		public EnumLiteralDeclaration getINSTANCEOFEnumLiteralDeclaration_0() { return cINSTANCEOFEnumLiteralDeclaration_0; }

		//'INSTANCEOF'
		public Keyword getINSTANCEOFINSTANCEOFKeyword_0_0() { return cINSTANCEOFINSTANCEOFKeyword_0_0; }

		//CLASSREGEX
		public EnumLiteralDeclaration getCLASSREGEXEnumLiteralDeclaration_1() { return cCLASSREGEXEnumLiteralDeclaration_1; }

		//'CLASSREGEX'
		public Keyword getCLASSREGEXCLASSREGEXKeyword_1_0() { return cCLASSREGEXCLASSREGEXKeyword_1_0; }
	}

	public class ObserveRelativeDirectionTypeElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.ObserveRelativeDirectionType");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cSINCEEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cSINCESINCEKeyword_0_0 = (Keyword)cSINCEEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cNEXTEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cNEXTNEXTKeyword_1_0 = (Keyword)cNEXTEnumLiteralDeclaration_1.eContents().get(0);
		
		//enum ObserveRelativeDirectionType:
		//	SINCE | NEXT;
		public EnumRule getRule() { return rule; }

		//SINCE | NEXT
		public Alternatives getAlternatives() { return cAlternatives; }

		//SINCE
		public EnumLiteralDeclaration getSINCEEnumLiteralDeclaration_0() { return cSINCEEnumLiteralDeclaration_0; }

		//'SINCE'
		public Keyword getSINCESINCEKeyword_0_0() { return cSINCESINCEKeyword_0_0; }

		//NEXT
		public EnumLiteralDeclaration getNEXTEnumLiteralDeclaration_1() { return cNEXTEnumLiteralDeclaration_1; }

		//'NEXT'
		public Keyword getNEXTNEXTKeyword_1_0() { return cNEXTNEXTKeyword_1_0; }
	}

	public class RelativeTimeSignTypeElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.RelativeTimeSignType");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cMINUSEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cMINUSHyphenMinusKeyword_0_0 = (Keyword)cMINUSEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cPLUSEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cPLUSPlusSignKeyword_1_0 = (Keyword)cPLUSEnumLiteralDeclaration_1.eContents().get(0);
		
		//enum RelativeTimeSignType:
		//	MINUS='-' | PLUS='+';
		public EnumRule getRule() { return rule; }

		//MINUS='-' | PLUS='+'
		public Alternatives getAlternatives() { return cAlternatives; }

		//MINUS='-'
		public EnumLiteralDeclaration getMINUSEnumLiteralDeclaration_0() { return cMINUSEnumLiteralDeclaration_0; }

		//'-'
		public Keyword getMINUSHyphenMinusKeyword_0_0() { return cMINUSHyphenMinusKeyword_0_0; }

		//PLUS='+'
		public EnumLiteralDeclaration getPLUSEnumLiteralDeclaration_1() { return cPLUSEnumLiteralDeclaration_1; }

		//'+'
		public Keyword getPLUSPlusSignKeyword_1_0() { return cPLUSPlusSignKeyword_1_0; }
	}

	public class TimeModifierTypeElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.TimeModifierType");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cYEAREnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cYEARYKeyword_0_0 = (Keyword)cYEAREnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cMONTHEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cMONTHMKeyword_1_0 = (Keyword)cMONTHEnumLiteralDeclaration_1.eContents().get(0);
		private final EnumLiteralDeclaration cWEEKEnumLiteralDeclaration_2 = (EnumLiteralDeclaration)cAlternatives.eContents().get(2);
		private final Keyword cWEEKWKeyword_2_0 = (Keyword)cWEEKEnumLiteralDeclaration_2.eContents().get(0);
		private final EnumLiteralDeclaration cDAYEnumLiteralDeclaration_3 = (EnumLiteralDeclaration)cAlternatives.eContents().get(3);
		private final Keyword cDAYDKeyword_3_0 = (Keyword)cDAYEnumLiteralDeclaration_3.eContents().get(0);
		private final EnumLiteralDeclaration cHOUREnumLiteralDeclaration_4 = (EnumLiteralDeclaration)cAlternatives.eContents().get(4);
		private final Keyword cHOURHKeyword_4_0 = (Keyword)cHOUREnumLiteralDeclaration_4.eContents().get(0);
		private final EnumLiteralDeclaration cMINUTEEnumLiteralDeclaration_5 = (EnumLiteralDeclaration)cAlternatives.eContents().get(5);
		private final Keyword cMINUTEMKeyword_5_0 = (Keyword)cMINUTEEnumLiteralDeclaration_5.eContents().get(0);
		private final EnumLiteralDeclaration cSECONDEnumLiteralDeclaration_6 = (EnumLiteralDeclaration)cAlternatives.eContents().get(6);
		private final Keyword cSECONDSKeyword_6_0 = (Keyword)cSECONDEnumLiteralDeclaration_6.eContents().get(0);
		private final EnumLiteralDeclaration cMILLISECONDEnumLiteralDeclaration_7 = (EnumLiteralDeclaration)cAlternatives.eContents().get(7);
		private final Keyword cMILLISECONDSKeyword_7_0 = (Keyword)cMILLISECONDEnumLiteralDeclaration_7.eContents().get(0);
		
		//enum TimeModifierType:
		//	YEAR='y' | MONTH='m' | WEEK='w' | DAY='d' | HOUR='h' | MINUTE='M' | SECOND='s' | MILLISECOND='S';
		public EnumRule getRule() { return rule; }

		//YEAR='y' | MONTH='m' | WEEK='w' | DAY='d' | HOUR='h' | MINUTE='M' | SECOND='s' | MILLISECOND='S'
		public Alternatives getAlternatives() { return cAlternatives; }

		//YEAR='y'
		public EnumLiteralDeclaration getYEAREnumLiteralDeclaration_0() { return cYEAREnumLiteralDeclaration_0; }

		//'y'
		public Keyword getYEARYKeyword_0_0() { return cYEARYKeyword_0_0; }

		//MONTH='m'
		public EnumLiteralDeclaration getMONTHEnumLiteralDeclaration_1() { return cMONTHEnumLiteralDeclaration_1; }

		//'m'
		public Keyword getMONTHMKeyword_1_0() { return cMONTHMKeyword_1_0; }

		//WEEK='w'
		public EnumLiteralDeclaration getWEEKEnumLiteralDeclaration_2() { return cWEEKEnumLiteralDeclaration_2; }

		//'w'
		public Keyword getWEEKWKeyword_2_0() { return cWEEKWKeyword_2_0; }

		//DAY='d'
		public EnumLiteralDeclaration getDAYEnumLiteralDeclaration_3() { return cDAYEnumLiteralDeclaration_3; }

		//'d'
		public Keyword getDAYDKeyword_3_0() { return cDAYDKeyword_3_0; }

		//HOUR='h'
		public EnumLiteralDeclaration getHOUREnumLiteralDeclaration_4() { return cHOUREnumLiteralDeclaration_4; }

		//'h'
		public Keyword getHOURHKeyword_4_0() { return cHOURHKeyword_4_0; }

		//MINUTE='M'
		public EnumLiteralDeclaration getMINUTEEnumLiteralDeclaration_5() { return cMINUTEEnumLiteralDeclaration_5; }

		//'M'
		public Keyword getMINUTEMKeyword_5_0() { return cMINUTEMKeyword_5_0; }

		//SECOND='s'
		public EnumLiteralDeclaration getSECONDEnumLiteralDeclaration_6() { return cSECONDEnumLiteralDeclaration_6; }

		//'s'
		public Keyword getSECONDSKeyword_6_0() { return cSECONDSKeyword_6_0; }

		//MILLISECOND='S'
		public EnumLiteralDeclaration getMILLISECONDEnumLiteralDeclaration_7() { return cMILLISECONDEnumLiteralDeclaration_7; }

		//'S'
		public Keyword getMILLISECONDSKeyword_7_0() { return cMILLISECONDSKeyword_7_0; }
	}

	public class StatisticalAggregateTypeElements extends AbstractEnumRuleElementFinder {
		private final EnumRule rule = (EnumRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.StatisticalAggregateType");
		private final Alternatives cAlternatives = (Alternatives)rule.eContents().get(1);
		private final EnumLiteralDeclaration cMINEnumLiteralDeclaration_0 = (EnumLiteralDeclaration)cAlternatives.eContents().get(0);
		private final Keyword cMINMINKeyword_0_0 = (Keyword)cMINEnumLiteralDeclaration_0.eContents().get(0);
		private final EnumLiteralDeclaration cMAXEnumLiteralDeclaration_1 = (EnumLiteralDeclaration)cAlternatives.eContents().get(1);
		private final Keyword cMAXMAXKeyword_1_0 = (Keyword)cMAXEnumLiteralDeclaration_1.eContents().get(0);
		private final EnumLiteralDeclaration cGEOMEANEnumLiteralDeclaration_2 = (EnumLiteralDeclaration)cAlternatives.eContents().get(2);
		private final Keyword cGEOMEANGEOMEANKeyword_2_0 = (Keyword)cGEOMEANEnumLiteralDeclaration_2.eContents().get(0);
		private final EnumLiteralDeclaration cNEnumLiteralDeclaration_3 = (EnumLiteralDeclaration)cAlternatives.eContents().get(3);
		private final Keyword cNNKeyword_3_0 = (Keyword)cNEnumLiteralDeclaration_3.eContents().get(0);
		private final EnumLiteralDeclaration cSUMEnumLiteralDeclaration_4 = (EnumLiteralDeclaration)cAlternatives.eContents().get(4);
		private final Keyword cSUMSUMKeyword_4_0 = (Keyword)cSUMEnumLiteralDeclaration_4.eContents().get(0);
		private final EnumLiteralDeclaration cSUMOFSQUARESEnumLiteralDeclaration_5 = (EnumLiteralDeclaration)cAlternatives.eContents().get(5);
		private final Keyword cSUMOFSQUARESSUMOFSQUARESKeyword_5_0 = (Keyword)cSUMOFSQUARESEnumLiteralDeclaration_5.eContents().get(0);
		private final EnumLiteralDeclaration cSTDDEVEnumLiteralDeclaration_6 = (EnumLiteralDeclaration)cAlternatives.eContents().get(6);
		private final Keyword cSTDDEVSTDDEVKeyword_6_0 = (Keyword)cSTDDEVEnumLiteralDeclaration_6.eContents().get(0);
		private final EnumLiteralDeclaration cVAREnumLiteralDeclaration_7 = (EnumLiteralDeclaration)cAlternatives.eContents().get(7);
		private final Keyword cVARVARKeyword_7_0 = (Keyword)cVAREnumLiteralDeclaration_7.eContents().get(0);
		private final EnumLiteralDeclaration cPERCENTILEEnumLiteralDeclaration_8 = (EnumLiteralDeclaration)cAlternatives.eContents().get(8);
		private final Keyword cPERCENTILEPERCENTILEKeyword_8_0 = (Keyword)cPERCENTILEEnumLiteralDeclaration_8.eContents().get(0);
		private final EnumLiteralDeclaration cMEANEnumLiteralDeclaration_9 = (EnumLiteralDeclaration)cAlternatives.eContents().get(9);
		private final Keyword cMEANMEANKeyword_9_0 = (Keyword)cMEANEnumLiteralDeclaration_9.eContents().get(0);
		
		//enum StatisticalAggregateType:
		//	MIN | MAX | GEOMEAN | N | SUM | SUMOFSQUARES | STDDEV |
		//	VAR | PERCENTILE | MEAN;
		public EnumRule getRule() { return rule; }

		//MIN | MAX | GEOMEAN | N | SUM | SUMOFSQUARES | STDDEV | VAR | PERCENTILE | MEAN
		public Alternatives getAlternatives() { return cAlternatives; }

		//MIN
		public EnumLiteralDeclaration getMINEnumLiteralDeclaration_0() { return cMINEnumLiteralDeclaration_0; }

		//'MIN'
		public Keyword getMINMINKeyword_0_0() { return cMINMINKeyword_0_0; }

		//MAX
		public EnumLiteralDeclaration getMAXEnumLiteralDeclaration_1() { return cMAXEnumLiteralDeclaration_1; }

		//'MAX'
		public Keyword getMAXMAXKeyword_1_0() { return cMAXMAXKeyword_1_0; }

		//GEOMEAN
		public EnumLiteralDeclaration getGEOMEANEnumLiteralDeclaration_2() { return cGEOMEANEnumLiteralDeclaration_2; }

		//'GEOMEAN'
		public Keyword getGEOMEANGEOMEANKeyword_2_0() { return cGEOMEANGEOMEANKeyword_2_0; }

		//N
		public EnumLiteralDeclaration getNEnumLiteralDeclaration_3() { return cNEnumLiteralDeclaration_3; }

		//'N'
		public Keyword getNNKeyword_3_0() { return cNNKeyword_3_0; }

		//SUM
		public EnumLiteralDeclaration getSUMEnumLiteralDeclaration_4() { return cSUMEnumLiteralDeclaration_4; }

		//'SUM'
		public Keyword getSUMSUMKeyword_4_0() { return cSUMSUMKeyword_4_0; }

		//SUMOFSQUARES
		public EnumLiteralDeclaration getSUMOFSQUARESEnumLiteralDeclaration_5() { return cSUMOFSQUARESEnumLiteralDeclaration_5; }

		//'SUMOFSQUARES'
		public Keyword getSUMOFSQUARESSUMOFSQUARESKeyword_5_0() { return cSUMOFSQUARESSUMOFSQUARESKeyword_5_0; }

		//STDDEV
		public EnumLiteralDeclaration getSTDDEVEnumLiteralDeclaration_6() { return cSTDDEVEnumLiteralDeclaration_6; }

		//'STDDEV'
		public Keyword getSTDDEVSTDDEVKeyword_6_0() { return cSTDDEVSTDDEVKeyword_6_0; }

		//VAR
		public EnumLiteralDeclaration getVAREnumLiteralDeclaration_7() { return cVAREnumLiteralDeclaration_7; }

		//'VAR'
		public Keyword getVARVARKeyword_7_0() { return cVARVARKeyword_7_0; }

		//PERCENTILE
		public EnumLiteralDeclaration getPERCENTILEEnumLiteralDeclaration_8() { return cPERCENTILEEnumLiteralDeclaration_8; }

		//'PERCENTILE'
		public Keyword getPERCENTILEPERCENTILEKeyword_8_0() { return cPERCENTILEPERCENTILEKeyword_8_0; }

		//MEAN
		public EnumLiteralDeclaration getMEANEnumLiteralDeclaration_9() { return cMEANEnumLiteralDeclaration_9; }

		//'MEAN'
		public Keyword getMEANMEANKeyword_9_0() { return cMEANMEANKeyword_9_0; }
	}
	
	private final DescartesQLElements pDescartesQL;
	private final GoalElements pGoal;
	private final SlaQueryElements pSlaQuery;
	private final SloQueryElements pSloQuery;
	private final SlaElements pSla;
	private final SloElements pSlo;
	private final WeightedSloElements pWeightedSlo;
	private final FuzzinessElements pFuzziness;
	private final PenaltyElements pPenalty;
	private final ViolationElements pViolation;
	private final ComparatorElements eComparator;
	private final CurrencyElements eCurrency;
	private final ModelStructureQueryElements pModelStructureQuery;
	private final PerformanceMetricsQueryElements pPerformanceMetricsQuery;
	private final PerformanceIssueQueryElements pPerformanceIssueQuery;
	private final ConnectorCapabilityQueryElements pConnectorCapabilityQuery;
	private final ListQueryElements pListQuery;
	private final GetQueryElements pGetQuery;
	private final GetConstraintsQueryElements pGetConstraintsQuery;
	private final GetExplorationStrategiesQueryElements pGetExplorationStrategiesQuery;
	private final GetTimeUnitsQueryElements pGetTimeUnitsQuery;
	private final ListDoFQueryElements pListDoFQuery;
	private final ListEntitiesQueryElements pListEntitiesQuery;
	private final ListMetricsQueryElements pListMetricsQuery;
	private final SelectQueryElements pSelectQuery;
	private final MetricReferenceClausesElements pMetricReferenceClauses;
	private final MetricClauseTypeElements pMetricClauseType;
	private final DetectQueryElements pDetectQuery;
	private final DetectBottlenecksQueryElements pDetectBottlenecksQuery;
	private final ConstraintClauseElements pConstraintClause;
	private final DoFClauseElements pDoFClause;
	private final ExplorationStrategyClauseElements pExplorationStrategyClause;
	private final ConfigurationPropertiesClauseElements pConfigurationPropertiesClause;
	private final ConfigurationPropertyClauseElements pConfigurationPropertyClause;
	private final DoFVariationClauseElements pDoFVariationClause;
	private final ValueVariationClauseElements pValueVariationClause;
	private final IntervalVariationClauseElements pIntervalVariationClause;
	private final VaryingClauseElements pVaryingClause;
	private final DoFReferenceElements pDoFReference;
	private final MetricClauseElements pMetricClause;
	private final AggregateMetricClauseElements pAggregateMetricClause;
	private final MetricClausesElements pMetricClauses;
	private final MetricStarClauseElements pMetricStarClause;
	private final MetricReferenceElements pMetricReference;
	private final NavigationClauseElements pNavigationClause;
	private final ChildrenClauseElements pChildrenClause;
	private final ParentClauseElements pParentClause;
	private final FindClauseElements pFindClause;
	private final ForClauseElements pForClause;
	private final EntityReferenceClauseElements pEntityReferenceClause;
	private final EntityReferenceElements pEntityReference;
	private final AliasClauseElements pAliasClause;
	private final UsingClauseElements pUsingClause;
	private final WithClauseElements pWithClause;
	private final ModelReferenceClauseElements pModelReferenceClause;
	private final ModelFamilyElements pModelFamily;
	private final ModelLocationElements pModelLocation;
	private final FilterClauseElements pFilterClause;
	private final FilterConjunctionElements eFilterConjunction;
	private final FilterConditionClauseElements pFilterConditionClause;
	private final FilterConditionValueElements pFilterConditionValue;
	private final FilterConditionTypeElements eFilterConditionType;
	private final ObserveClauseElements pObserveClause;
	private final ObservationClauseElements pObservationClause;
	private final SampleClauseElements pSampleClause;
	private final ConnectorTimeUnitClauseElements pConnectorTimeUnitClause;
	private final ConnectorInstanceReferenceClauseElements pConnectorInstanceReferenceClause;
	private final ObserveRelativeClauseElements pObserveRelativeClause;
	private final ObserveBetweenClauseElements pObserveBetweenClause;
	private final RelativeTimeWithSignClauseElements pRelativeTimeWithSignClause;
	private final BetweenTimeClauseElements pBetweenTimeClause;
	private final TimeClauseElements pTimeClause;
	private final AbsoluteTimeClauseElements pAbsoluteTimeClause;
	private final RelativeTimeClauseElements pRelativeTimeClause;
	private final RelativeTimeDurationClauseElements pRelativeTimeDurationClause;
	private final ObserveRelativeDirectionTypeElements eObserveRelativeDirectionType;
	private final RelativeTimeSignTypeElements eRelativeTimeSignType;
	private final TimeModifierTypeElements eTimeModifierType;
	private final StatisticalAggregateTypeElements eStatisticalAggregateType;
	private final WhatIfQueryElements pWhatIfQuery;
	private final DeltaClauseElements pDeltaClause;
	private final WhatIfVariationElements pWhatIfVariation;
	private final FilteringClauseElements pFilteringClause;
	private final FilteringStrategyElements pFilteringStrategy;
	private final FilteringRuleElements pFilteringRule;
	private final WhatIfVariationClauseElements pWhatIfVariationClause;
	private final WhatIfValueVariationClauseElements pWhatIfValueVariationClause;
	private final MultipleVariationInstructionElements pMultipleVariationInstruction;
	private final VariationInstructionElements pVariationInstruction;
	private final MultipleArithmeticClauseElements pMultipleArithmeticClause;
	private final ArithmeticClauseElements pArithmeticClause;
	private final VariableValueElements pVariableValue;
	private final TerminalRule tDOUBLE;
	
	private final Grammar grammar;

	private final TerminalsGrammarAccess gaTerminals;

	@Inject
	public DescartesQLGrammarAccess(GrammarProvider grammarProvider,
		TerminalsGrammarAccess gaTerminals) {
		this.grammar = internalFindGrammar(grammarProvider);
		this.gaTerminals = gaTerminals;
		this.pDescartesQL = new DescartesQLElements();
		this.pGoal = new GoalElements();
		this.pSlaQuery = new SlaQueryElements();
		this.pSloQuery = new SloQueryElements();
		this.pSla = new SlaElements();
		this.pSlo = new SloElements();
		this.pWeightedSlo = new WeightedSloElements();
		this.pFuzziness = new FuzzinessElements();
		this.pPenalty = new PenaltyElements();
		this.pViolation = new ViolationElements();
		this.eComparator = new ComparatorElements();
		this.eCurrency = new CurrencyElements();
		this.pModelStructureQuery = new ModelStructureQueryElements();
		this.pPerformanceMetricsQuery = new PerformanceMetricsQueryElements();
		this.pPerformanceIssueQuery = new PerformanceIssueQueryElements();
		this.pConnectorCapabilityQuery = new ConnectorCapabilityQueryElements();
		this.pListQuery = new ListQueryElements();
		this.pGetQuery = new GetQueryElements();
		this.pGetConstraintsQuery = new GetConstraintsQueryElements();
		this.pGetExplorationStrategiesQuery = new GetExplorationStrategiesQueryElements();
		this.pGetTimeUnitsQuery = new GetTimeUnitsQueryElements();
		this.pListDoFQuery = new ListDoFQueryElements();
		this.pListEntitiesQuery = new ListEntitiesQueryElements();
		this.pListMetricsQuery = new ListMetricsQueryElements();
		this.pSelectQuery = new SelectQueryElements();
		this.pMetricReferenceClauses = new MetricReferenceClausesElements();
		this.pMetricClauseType = new MetricClauseTypeElements();
		this.pDetectQuery = new DetectQueryElements();
		this.pDetectBottlenecksQuery = new DetectBottlenecksQueryElements();
		this.pConstraintClause = new ConstraintClauseElements();
		this.pDoFClause = new DoFClauseElements();
		this.pExplorationStrategyClause = new ExplorationStrategyClauseElements();
		this.pConfigurationPropertiesClause = new ConfigurationPropertiesClauseElements();
		this.pConfigurationPropertyClause = new ConfigurationPropertyClauseElements();
		this.pDoFVariationClause = new DoFVariationClauseElements();
		this.pValueVariationClause = new ValueVariationClauseElements();
		this.pIntervalVariationClause = new IntervalVariationClauseElements();
		this.pVaryingClause = new VaryingClauseElements();
		this.pDoFReference = new DoFReferenceElements();
		this.pMetricClause = new MetricClauseElements();
		this.pAggregateMetricClause = new AggregateMetricClauseElements();
		this.pMetricClauses = new MetricClausesElements();
		this.pMetricStarClause = new MetricStarClauseElements();
		this.pMetricReference = new MetricReferenceElements();
		this.pNavigationClause = new NavigationClauseElements();
		this.pChildrenClause = new ChildrenClauseElements();
		this.pParentClause = new ParentClauseElements();
		this.pFindClause = new FindClauseElements();
		this.pForClause = new ForClauseElements();
		this.pEntityReferenceClause = new EntityReferenceClauseElements();
		this.pEntityReference = new EntityReferenceElements();
		this.pAliasClause = new AliasClauseElements();
		this.pUsingClause = new UsingClauseElements();
		this.pWithClause = new WithClauseElements();
		this.pModelReferenceClause = new ModelReferenceClauseElements();
		this.pModelFamily = new ModelFamilyElements();
		this.pModelLocation = new ModelLocationElements();
		this.pFilterClause = new FilterClauseElements();
		this.eFilterConjunction = new FilterConjunctionElements();
		this.pFilterConditionClause = new FilterConditionClauseElements();
		this.pFilterConditionValue = new FilterConditionValueElements();
		this.eFilterConditionType = new FilterConditionTypeElements();
		this.pObserveClause = new ObserveClauseElements();
		this.pObservationClause = new ObservationClauseElements();
		this.pSampleClause = new SampleClauseElements();
		this.pConnectorTimeUnitClause = new ConnectorTimeUnitClauseElements();
		this.pConnectorInstanceReferenceClause = new ConnectorInstanceReferenceClauseElements();
		this.pObserveRelativeClause = new ObserveRelativeClauseElements();
		this.pObserveBetweenClause = new ObserveBetweenClauseElements();
		this.pRelativeTimeWithSignClause = new RelativeTimeWithSignClauseElements();
		this.pBetweenTimeClause = new BetweenTimeClauseElements();
		this.pTimeClause = new TimeClauseElements();
		this.pAbsoluteTimeClause = new AbsoluteTimeClauseElements();
		this.pRelativeTimeClause = new RelativeTimeClauseElements();
		this.pRelativeTimeDurationClause = new RelativeTimeDurationClauseElements();
		this.eObserveRelativeDirectionType = new ObserveRelativeDirectionTypeElements();
		this.eRelativeTimeSignType = new RelativeTimeSignTypeElements();
		this.eTimeModifierType = new TimeModifierTypeElements();
		this.eStatisticalAggregateType = new StatisticalAggregateTypeElements();
		this.pWhatIfQuery = new WhatIfQueryElements();
		this.pDeltaClause = new DeltaClauseElements();
		this.pWhatIfVariation = new WhatIfVariationElements();
		this.pFilteringClause = new FilteringClauseElements();
		this.pFilteringStrategy = new FilteringStrategyElements();
		this.pFilteringRule = new FilteringRuleElements();
		this.pWhatIfVariationClause = new WhatIfVariationClauseElements();
		this.pWhatIfValueVariationClause = new WhatIfValueVariationClauseElements();
		this.pMultipleVariationInstruction = new MultipleVariationInstructionElements();
		this.pVariationInstruction = new VariationInstructionElements();
		this.pMultipleArithmeticClause = new MultipleArithmeticClauseElements();
		this.pArithmeticClause = new ArithmeticClauseElements();
		this.pVariableValue = new VariableValueElements();
		this.tDOUBLE = (TerminalRule) GrammarUtil.findRuleForName(getGrammar(), "tools.descartes.dql.lang.DescartesQL.DOUBLE");
	}
	
	protected Grammar internalFindGrammar(GrammarProvider grammarProvider) {
		Grammar grammar = grammarProvider.getGrammar(this);
		while (grammar != null) {
			if ("tools.descartes.dql.lang.DescartesQL".equals(grammar.getName())) {
				return grammar;
			}
			List<Grammar> grammars = grammar.getUsedGrammars();
			if (!grammars.isEmpty()) {
				grammar = grammars.iterator().next();
			} else {
				return null;
			}
		}
		return grammar;
	}
	
	@Override
	public Grammar getGrammar() {
		return grammar;
	}
	

	public TerminalsGrammarAccess getTerminalsGrammarAccess() {
		return gaTerminals;
	}

	
	//// @THESIS
	//DescartesQL:
	//	query=(ModelStructureQuery | PerformanceMetricsQuery | PerformanceIssueQuery | ConnectorCapabilityQuery | WhatIfQuery
	//	| Goal)
	//	';';
	public DescartesQLElements getDescartesQLAccess() {
		return pDescartesQL;
	}
	
	public ParserRule getDescartesQLRule() {
		return getDescartesQLAccess().getRule();
	}

	//Goal:
	//	queryType=('ENSURE' | 'MONITOR') slaQuery=SlaQuery sloQuery=SloQuery constraintClause=ConstraintClause?
	//	dofClause=DoFClause? forClause=ForClause? usingClause=UsingClause;
	public GoalElements getGoalAccess() {
		return pGoal;
	}
	
	public ParserRule getGoalRule() {
		return getGoalAccess().getRule();
	}

	//SlaQuery:
	//	type='AGREEMENTS' slas+=Sla (',' slas+=Sla)*;
	public SlaQueryElements getSlaQueryAccess() {
		return pSlaQuery;
	}
	
	public ParserRule getSlaQueryRule() {
		return getSlaQueryAccess().getRule();
	}

	//SloQuery:
	//	type='GOALS' slos+=Slo (',' slos+=Slo)*;
	public SloQueryElements getSloQueryAccess() {
		return pSloQuery;
	}
	
	public ParserRule getSloQueryRule() {
		return getSloQueryAccess().getRule();
	}

	//Sla:
	//	name=ID 'CONTAINS' '(' weightedSlo+=WeightedSlo (',' weightedSlo+=WeightedSlo)* ')';
	public SlaElements getSlaAccess() {
		return pSla;
	}
	
	public ParserRule getSlaRule() {
		return getSlaAccess().getRule();
	}

	//Slo:
	//	name=ID ':' metricClauseType=MetricClauseType comparator=Comparator value=VariableValue fuz=Fuzziness?
	//	pen=Penalty?;
	public SloElements getSloAccess() {
		return pSlo;
	}
	
	public ParserRule getSloRule() {
		return getSloAccess().getRule();
	}

	//WeightedSlo:
	//	slo=[Slo] ('*' weight=INT)?;
	public WeightedSloElements getWeightedSloAccess() {
		return pWeightedSlo;
	}
	
	public ParserRule getWeightedSloRule() {
		return getWeightedSloAccess().getRule();
	}

	//Fuzziness:
	//	type='FUZZINESS' deviation=VariableValue;
	public FuzzinessElements getFuzzinessAccess() {
		return pFuzziness;
	}
	
	public ParserRule getFuzzinessRule() {
		return getFuzzinessAccess().getRule();
	}

	//Penalty:
	//	type='PENALTY' value=DOUBLE currency=Currency violation=Violation?;
	public PenaltyElements getPenaltyAccess() {
		return pPenalty;
	}
	
	public ParserRule getPenaltyRule() {
		return getPenaltyAccess().getRule();
	}

	//Violation:
	//	'PER' amount=INT 'VIOLATIONS';
	public ViolationElements getViolationAccess() {
		return pViolation;
	}
	
	public ParserRule getViolationRule() {
		return getViolationAccess().getRule();
	}

	//enum Comparator:
	//	less='<' | lessEqual='<=' | greater='>' | greaterEqual='>=' | equal='==';
	public ComparatorElements getComparatorAccess() {
		return eComparator;
	}
	
	public EnumRule getComparatorRule() {
		return getComparatorAccess().getRule();
	}

	//enum Currency:
	//	euro='EUR' | usDollar='USD';
	public CurrencyElements getCurrencyAccess() {
		return eCurrency;
	}
	
	public EnumRule getCurrencyRule() {
		return getCurrencyAccess().getRule();
	}

	//// @THESIS
	//ModelStructureQuery:
	//	ListQuery;
	public ModelStructureQueryElements getModelStructureQueryAccess() {
		return pModelStructureQuery;
	}
	
	public ParserRule getModelStructureQueryRule() {
		return getModelStructureQueryAccess().getRule();
	}

	//// @THESIS
	//PerformanceMetricsQuery:
	//	SelectQuery;
	public PerformanceMetricsQueryElements getPerformanceMetricsQueryAccess() {
		return pPerformanceMetricsQuery;
	}
	
	public ParserRule getPerformanceMetricsQueryRule() {
		return getPerformanceMetricsQueryAccess().getRule();
	}

	//// @THESIS
	//PerformanceIssueQuery:
	//	DetectQuery;
	public PerformanceIssueQueryElements getPerformanceIssueQueryAccess() {
		return pPerformanceIssueQuery;
	}
	
	public ParserRule getPerformanceIssueQueryRule() {
		return getPerformanceIssueQueryAccess().getRule();
	}

	//ConnectorCapabilityQuery:
	//	GetQuery;
	public ConnectorCapabilityQueryElements getConnectorCapabilityQueryAccess() {
		return pConnectorCapabilityQuery;
	}
	
	public ParserRule getConnectorCapabilityQueryRule() {
		return getConnectorCapabilityQueryAccess().getRule();
	}

	//// @THESIS
	//ListQuery:
	//	'LIST' queryType=(ListEntitiesQuery | ListMetricsQuery | ListDoFQuery) filterClause=FilterClause?
	//	usingClause=UsingClause;
	public ListQueryElements getListQueryAccess() {
		return pListQuery;
	}
	
	public ParserRule getListQueryRule() {
		return getListQueryAccess().getRule();
	}

	//GetQuery:
	//	'GET' queryTape=(GetExplorationStrategiesQuery | GetTimeUnitsQuery | GetConstraintsQuery) usingClause=UsingClause;
	public GetQueryElements getGetQueryAccess() {
		return pGetQuery;
	}
	
	public ParserRule getGetQueryRule() {
		return getGetQueryAccess().getRule();
	}

	//GetConstraintsQuery:
	//	mode="CONSTRAINTS";
	public GetConstraintsQueryElements getGetConstraintsQueryAccess() {
		return pGetConstraintsQuery;
	}
	
	public ParserRule getGetConstraintsQueryRule() {
		return getGetConstraintsQueryAccess().getRule();
	}

	//GetExplorationStrategiesQuery:
	//	mode="EXPLORATION STRATEGIES";
	public GetExplorationStrategiesQueryElements getGetExplorationStrategiesQueryAccess() {
		return pGetExplorationStrategiesQuery;
	}
	
	public ParserRule getGetExplorationStrategiesQueryRule() {
		return getGetExplorationStrategiesQueryAccess().getRule();
	}

	//GetTimeUnitsQuery:
	//	mode="TIME UNITS";
	public GetTimeUnitsQueryElements getGetTimeUnitsQueryAccess() {
		return pGetTimeUnitsQuery;
	}
	
	public ParserRule getGetTimeUnitsQueryRule() {
		return getGetTimeUnitsQueryAccess().getRule();
	}

	//// @THESIS
	//ListDoFQuery:
	//	mode="DOF" withClause=WithClause?;
	public ListDoFQueryElements getListDoFQueryAccess() {
		return pListDoFQuery;
	}
	
	public ParserRule getListDoFQueryRule() {
		return getListDoFQueryAccess().getRule();
	}

	//// @THESIS
	//ListEntitiesQuery:
	//	mode='ENTITIES';
	public ListEntitiesQueryElements getListEntitiesQueryAccess() {
		return pListEntitiesQuery;
	}
	
	public ParserRule getListEntitiesQueryRule() {
		return getListEntitiesQueryAccess().getRule();
	}

	//// @THESIS
	//ListMetricsQuery:
	//	mode='METRICS' '(' entityReferenceClause=EntityReferenceClause ')';
	public ListMetricsQueryElements getListMetricsQueryAccess() {
		return pListMetricsQuery;
	}
	
	public ParserRule getListMetricsQueryRule() {
		return getListMetricsQueryAccess().getRule();
	}

	//// @THESIS
	//SelectQuery:
	//	'SELECT' metricReferenceClauses=MetricReferenceClauses constraintClause=ConstraintClause? dofClause=DoFClause?
	//	forClause=ForClause usingClause=UsingClause observeClause=ObserveClause?;
	public SelectQueryElements getSelectQueryAccess() {
		return pSelectQuery;
	}
	
	public ParserRule getSelectQueryRule() {
		return getSelectQueryAccess().getRule();
	}

	//// @THESIS
	//MetricReferenceClauses:
	//	metricClauseTypes+=MetricClauseType (',' metricClauseTypes+=MetricClauseType)*;
	public MetricReferenceClausesElements getMetricReferenceClausesAccess() {
		return pMetricReferenceClauses;
	}
	
	public ParserRule getMetricReferenceClausesRule() {
		return getMetricReferenceClausesAccess().getRule();
	}

	//// @THESIS
	//MetricClauseType:
	//	MetricClause | AggregateMetricClause;
	public MetricClauseTypeElements getMetricClauseTypeAccess() {
		return pMetricClauseType;
	}
	
	public ParserRule getMetricClauseTypeRule() {
		return getMetricClauseTypeAccess().getRule();
	}

	//// @THESIS
	//DetectQuery:
	//	'DETECT' queryType=DetectBottlenecksQuery;
	public DetectQueryElements getDetectQueryAccess() {
		return pDetectQuery;
	}
	
	public ParserRule getDetectQueryRule() {
		return getDetectQueryAccess().getRule();
	}

	//// @THESIS
	//DetectBottlenecksQuery:
	//	'BOTTLENECKS' dofClause=DoFClause usingClause=UsingClause;
	public DetectBottlenecksQueryElements getDetectBottlenecksQueryAccess() {
		return pDetectBottlenecksQuery;
	}
	
	public ParserRule getDetectBottlenecksQueryRule() {
		return getDetectBottlenecksQueryAccess().getRule();
	}

	/// *
	// * Clause to specify a constraint on the model solver
	// * / // @THESIS
	//ConstraintClause:
	//	'CONSTRAINED AS' type=STRING;
	public ConstraintClauseElements getConstraintClauseAccess() {
		return pConstraintClause;
	}
	
	public ParserRule getConstraintClauseRule() {
		return getConstraintClauseAccess().getRule();
	}

	/// *
	// * Clause for expressing DoF 
	// * / // @THESIS
	//DoFClause:
	//	mode='EVALUATE DOF' varyingClause=VaryingClause? explorationStrategy=ExplorationStrategyClause?
	//	constraintClause=ConstraintClause? withClause=WithClause?;
	public DoFClauseElements getDoFClauseAccess() {
		return pDoFClause;
	}
	
	public ParserRule getDoFClauseRule() {
		return getDoFClauseAccess().getRule();
	}

	/// *
	// * Rule to specify an exploration strategy
	// * / // @THESIS
	//ExplorationStrategyClause:
	//	mode='GUIDED BY' name=STRING parameterClause=ConfigurationPropertiesClause?;
	public ExplorationStrategyClauseElements getExplorationStrategyClauseAccess() {
		return pExplorationStrategyClause;
	}
	
	public ParserRule getExplorationStrategyClauseRule() {
		return getExplorationStrategyClauseAccess().getRule();
	}

	//// @THESIS
	//ConfigurationPropertiesClause:
	//	mode1='[' properties+=ConfigurationPropertyClause (',' properties+=ConfigurationPropertyClause)* mode2=']';
	public ConfigurationPropertiesClauseElements getConfigurationPropertiesClauseAccess() {
		return pConfigurationPropertiesClause;
	}
	
	public ParserRule getConfigurationPropertiesClauseRule() {
		return getConfigurationPropertiesClauseAccess().getRule();
	}

	//// @THESIS
	//ConfigurationPropertyClause:
	//	key+=ID ('.' key+=ID)* '=' value=STRING;
	public ConfigurationPropertyClauseElements getConfigurationPropertyClauseAccess() {
		return pConfigurationPropertyClause;
	}
	
	public ParserRule getConfigurationPropertyClauseRule() {
		return getConfigurationPropertyClauseAccess().getRule();
	}

	//// @THESIS
	//DoFVariationClause:
	//	mode1='<' variation=(IntervalVariationClause | ValueVariationClause) mode2='>';
	public DoFVariationClauseElements getDoFVariationClauseAccess() {
		return pDoFVariationClause;
	}
	
	public ParserRule getDoFVariationClauseRule() {
		return getDoFVariationClauseAccess().getRule();
	}

	//// @THESIS
	//ValueVariationClause:
	//	value+=INT (',' value+=INT)*;
	public ValueVariationClauseElements getValueVariationClauseAccess() {
		return pValueVariationClause;
	}
	
	public ParserRule getValueVariationClauseRule() {
		return getValueVariationClauseAccess().getRule();
	}

	//// @THESIS
	//IntervalVariationClause:
	//	start=INT '..' end=INT 'BY' step=INT;
	public IntervalVariationClauseElements getIntervalVariationClauseAccess() {
		return pIntervalVariationClause;
	}
	
	public ParserRule getIntervalVariationClauseRule() {
		return getIntervalVariationClauseAccess().getRule();
	}

	/// *
	// * Clause to define which DoF to vary
	// * / // @THESIS
	//VaryingClause:
	//	mode='VARYING' dofReferences+=DoFReference (',' dofReferences+=DoFReference)*;
	public VaryingClauseElements getVaryingClauseAccess() {
		return pVaryingClause;
	}
	
	public ParserRule getVaryingClauseRule() {
		return getVaryingClauseAccess().getRule();
	}

	/// * 
	// * Rule to reference DoF model entities
	// * / // @THESIS
	//DoFReference:
	//	doFIdentifier=STRING doFAliasClause=AliasClause? doFVariationClause=(ConfigurationPropertiesClause |
	//	DoFVariationClause)?;
	public DoFReferenceElements getDoFReferenceAccess() {
		return pDoFReference;
	}
	
	public ParserRule getDoFReferenceRule() {
		return getDoFReferenceAccess().getRule();
	}

	/// *
	// * Clause to reference multiple metrics
	// * / // @THESIS
	//MetricClause:
	//	metricReference=MetricReference;
	public MetricClauseElements getMetricClauseAccess() {
		return pMetricClause;
	}
	
	public ParserRule getMetricClauseRule() {
		return getMetricClauseAccess().getRule();
	}

	//// @THESIS
	//AggregateMetricClause:
	//	function=StatisticalAggregateType '(' metrics=(MetricStarClause | MetricClauses) ')'
	//	properties=ConfigurationPropertiesClause?;
	public AggregateMetricClauseElements getAggregateMetricClauseAccess() {
		return pAggregateMetricClause;
	}
	
	public ParserRule getAggregateMetricClauseRule() {
		return getAggregateMetricClauseAccess().getRule();
	}

	//// @THESIS
	//MetricClauses:
	//	metrics+=MetricClause (',' metrics+=MetricClause)*;
	public MetricClausesElements getMetricClausesAccess() {
		return pMetricClauses;
	}
	
	public ParserRule getMetricClausesRule() {
		return getMetricClausesAccess().getRule();
	}

	//// @THESIS
	//MetricStarClause:
	//	'*.' metricName=ID;
	public MetricStarClauseElements getMetricStarClauseAccess() {
		return pMetricStarClause;
	}
	
	public ParserRule getMetricStarClauseRule() {
		return getMetricStarClauseAccess().getRule();
	}

	/// *
	// * Rule for referencing metrics bound to entities
	// * / // @THESIS
	//MetricReference:
	//	entityReference=ID (seperatorn="." navigationClause=NavigationClause)? separator='.' metricReference=ID
	//	(separatorv="." statTypeReference=ID)?;
	public MetricReferenceElements getMetricReferenceAccess() {
		return pMetricReference;
	}
	
	public ParserRule getMetricReferenceRule() {
		return getMetricReferenceAccess().getRule();
	}

	//NavigationClause:
	//	ParentClause | ChildrenClause | FindClause;
	public NavigationClauseElements getNavigationClauseAccess() {
		return pNavigationClause;
	}
	
	public ParserRule getNavigationClauseRule() {
		return getNavigationClauseAccess().getRule();
	}

	//ChildrenClause:
	//	content='children';
	public ChildrenClauseElements getChildrenClauseAccess() {
		return pChildrenClause;
	}
	
	public ParserRule getChildrenClauseRule() {
		return getChildrenClauseAccess().getRule();
	}

	//ParentClause:
	//	content='parent';
	public ParentClauseElements getParentClauseAccess() {
		return pParentClause;
	}
	
	public ParserRule getParentClauseRule() {
		return getParentClauseAccess().getRule();
	}

	//FindClause:
	//	start='find(' childName=STRING end=')';
	public FindClauseElements getFindClauseAccess() {
		return pFindClause;
	}
	
	public ParserRule getFindClauseRule() {
		return getFindClauseAccess().getRule();
	}

	/// *
	// * Clauses to build entity references in a query
	// * / // @THESIS
	//ForClause:
	//	mode='FOR' entityReferenceClause=EntityReferenceClause;
	public ForClauseElements getForClauseAccess() {
		return pForClause;
	}
	
	public ParserRule getForClauseRule() {
		return getForClauseAccess().getRule();
	}

	//// @THESIS
	//EntityReferenceClause:
	//	entityReferences+=EntityReference (',' entityReferences+=EntityReference)*;
	public EntityReferenceClauseElements getEntityReferenceClauseAccess() {
		return pEntityReferenceClause;
	}
	
	public ParserRule getEntityReferenceClauseRule() {
		return getEntityReferenceClauseAccess().getRule();
	}

	/// *
	// * Rules for referencing entities
	// * / // @THESIS
	//EntityReference:
	//	type=ID? identifier=STRING alias=AliasClause?;
	public EntityReferenceElements getEntityReferenceAccess() {
		return pEntityReference;
	}
	
	public ParserRule getEntityReferenceRule() {
		return getEntityReferenceAccess().getRule();
	}

	//// @THESIS
	//AliasClause:
	//	mode='AS' alias=ID;
	public AliasClauseElements getAliasClauseAccess() {
		return pAliasClause;
	}
	
	public ParserRule getAliasClauseRule() {
		return getAliasClauseAccess().getRule();
	}

	/// * 
	// * Clauses used for referencing model instances
	// * / // @THESIS
	//UsingClause:
	//	mode='USING' modelReference=ModelReferenceClause;
	public UsingClauseElements getUsingClauseAccess() {
		return pUsingClause;
	}
	
	public ParserRule getUsingClauseRule() {
		return getUsingClauseAccess().getRule();
	}

	//// @THESIS
	//WithClause:
	//	mode='WITH' modelReference=ModelReferenceClause;
	public WithClauseElements getWithClauseAccess() {
		return pWithClause;
	}
	
	public ParserRule getWithClauseRule() {
		return getWithClauseAccess().getRule();
	}

	/// *
	// * Rules for referencing a model instances
	// * / // @THESIS 
	//ModelReferenceClause:
	//	family=ModelFamily '@' model=ModelLocation;
	public ModelReferenceClauseElements getModelReferenceClauseAccess() {
		return pModelReferenceClause;
	}
	
	public ParserRule getModelReferenceClauseRule() {
		return getModelReferenceClauseAccess().getRule();
	}

	//// @THESIS
	//ModelFamily:
	//	family=ID;
	public ModelFamilyElements getModelFamilyAccess() {
		return pModelFamily;
	}
	
	public ParserRule getModelFamilyRule() {
		return getModelFamilyAccess().getRule();
	}

	//// @THESIS
	//ModelLocation:
	//	location=STRING;
	public ModelLocationElements getModelLocationAccess() {
		return pModelLocation;
	}
	
	public ParserRule getModelLocationRule() {
		return getModelLocationAccess().getRule();
	}

	/// *
	// * Rules for defining filters in ListQuery
	// * / FilterClause:
	//	mode='FILTERED BY'
	//	filterConditions+=FilterConditionClause (filterConjunctions+=FilterConjunction
	//	filterConditions+=FilterConditionClause)*;
	public FilterClauseElements getFilterClauseAccess() {
		return pFilterClause;
	}
	
	public ParserRule getFilterClauseRule() {
		return getFilterClauseAccess().getRule();
	}

	//enum FilterConjunction:
	//	AND | XOR | OR;
	public FilterConjunctionElements getFilterConjunctionAccess() {
		return eFilterConjunction;
	}
	
	public EnumRule getFilterConjunctionRule() {
		return getFilterConjunctionAccess().getRule();
	}

	//FilterConditionClause:
	//	mode='CONDITION' '(' condition=FilterConditionType ',' value=FilterConditionValue ')';
	public FilterConditionClauseElements getFilterConditionClauseAccess() {
		return pFilterConditionClause;
	}
	
	public ParserRule getFilterConditionClauseRule() {
		return getFilterConditionClauseAccess().getRule();
	}

	//FilterConditionValue:
	//	value=STRING;
	public FilterConditionValueElements getFilterConditionValueAccess() {
		return pFilterConditionValue;
	}
	
	public ParserRule getFilterConditionValueRule() {
		return getFilterConditionValueAccess().getRule();
	}

	//enum FilterConditionType:
	//	INSTANCEOF | CLASSREGEX;
	public FilterConditionTypeElements getFilterConditionTypeAccess() {
		return eFilterConditionType;
	}
	
	public EnumRule getFilterConditionTypeRule() {
		return getFilterConditionTypeAccess().getRule();
	}

	//// @THESIS
	//ObserveClause:
	//	mode='OBSERVE' observation=ObservationClause sampleClause=SampleClause?;
	public ObserveClauseElements getObserveClauseAccess() {
		return pObserveClause;
	}
	
	public ParserRule getObserveClauseRule() {
		return getObserveClauseAccess().getRule();
	}

	//// @THESIS
	//ObservationClause:
	//	ConnectorTimeUnitClause | ConnectorInstanceReferenceClause | ObserveRelativeClause | ObserveBetweenClause;
	public ObservationClauseElements getObservationClauseAccess() {
		return pObservationClause;
	}
	
	public ParserRule getObservationClauseRule() {
		return getObservationClauseAccess().getRule();
	}

	/// * Connector-dependent aggregation of values * / // @THESIS
	//SampleClause:
	//	mode='SAMPLED BY' durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*;
	public SampleClauseElements getSampleClauseAccess() {
		return pSampleClause;
	}
	
	public ParserRule getSampleClauseRule() {
		return getSampleClauseAccess().getRule();
	}

	/// * Connector-dependent * / // @THESIS
	//ConnectorTimeUnitClause:
	//	count=INT timeIndicator=ID;
	public ConnectorTimeUnitClauseElements getConnectorTimeUnitClauseAccess() {
		return pConnectorTimeUnitClause;
	}
	
	public ParserRule getConnectorTimeUnitClauseRule() {
		return getConnectorTimeUnitClauseAccess().getRule();
	}

	//// @THESIS
	//ConnectorInstanceReferenceClause:
	//	type=ID identifier=STRING;
	public ConnectorInstanceReferenceClauseElements getConnectorInstanceReferenceClauseAccess() {
		return pConnectorInstanceReferenceClause;
	}
	
	public ParserRule getConnectorInstanceReferenceClauseRule() {
		return getConnectorInstanceReferenceClauseAccess().getRule();
	}

	/// * Specialization of BETWEEN * / // @THESIS
	//ObserveRelativeClause:
	//	direction=ObserveRelativeDirectionType timeTarget=(AbsoluteTimeClause | RelativeTimeClause);
	public ObserveRelativeClauseElements getObserveRelativeClauseAccess() {
		return pObserveRelativeClause;
	}
	
	public ParserRule getObserveRelativeClauseRule() {
		return getObserveRelativeClauseAccess().getRule();
	}

	/// * Time-dependent (defined by DQL) * / // @THESIS
	//ObserveBetweenClause:
	//	mode1='BETWEEN' startingTime=(AbsoluteTimeClause | RelativeTimeWithSignClause) mode2='AND'
	//	endingTime=(AbsoluteTimeClause | RelativeTimeWithSignClause);
	public ObserveBetweenClauseElements getObserveBetweenClauseAccess() {
		return pObserveBetweenClause;
	}
	
	public ParserRule getObserveBetweenClauseRule() {
		return getObserveBetweenClauseAccess().getRule();
	}

	//// @THESIS
	//RelativeTimeWithSignClause:
	//	sign=RelativeTimeSignType timeClause=RelativeTimeClause;
	public RelativeTimeWithSignClauseElements getRelativeTimeWithSignClauseAccess() {
		return pRelativeTimeWithSignClause;
	}
	
	public ParserRule getRelativeTimeWithSignClauseRule() {
		return getRelativeTimeWithSignClauseAccess().getRule();
	}

	//BetweenTimeClause:
	//	AbsoluteTimeClause | RelativeTimeWithSignClause;
	public BetweenTimeClauseElements getBetweenTimeClauseAccess() {
		return pBetweenTimeClause;
	}
	
	public ParserRule getBetweenTimeClauseRule() {
		return getBetweenTimeClauseAccess().getRule();
	}

	//TimeClause:
	//	AbsoluteTimeClause | RelativeTimeClause;
	public TimeClauseElements getTimeClauseAccess() {
		return pTimeClause;
	}
	
	public ParserRule getTimeClauseRule() {
		return getTimeClauseAccess().getRule();
	}

	//// @THESIS
	//AbsoluteTimeClause:
	//	timeSpec=STRING;
	public AbsoluteTimeClauseElements getAbsoluteTimeClauseAccess() {
		return pAbsoluteTimeClause;
	}
	
	public ParserRule getAbsoluteTimeClauseRule() {
		return getAbsoluteTimeClauseAccess().getRule();
	}

	//// @THESIS
	//RelativeTimeClause:
	//	durationClause+=RelativeTimeDurationClause durationClause+=RelativeTimeDurationClause*;
	public RelativeTimeClauseElements getRelativeTimeClauseAccess() {
		return pRelativeTimeClause;
	}
	
	public ParserRule getRelativeTimeClauseRule() {
		return getRelativeTimeClauseAccess().getRule();
	}

	//// @THESIS
	//RelativeTimeDurationClause:
	//	duration=INT timeModifier=TimeModifierType;
	public RelativeTimeDurationClauseElements getRelativeTimeDurationClauseAccess() {
		return pRelativeTimeDurationClause;
	}
	
	public ParserRule getRelativeTimeDurationClauseRule() {
		return getRelativeTimeDurationClauseAccess().getRule();
	}

	//enum ObserveRelativeDirectionType:
	//	SINCE | NEXT;
	public ObserveRelativeDirectionTypeElements getObserveRelativeDirectionTypeAccess() {
		return eObserveRelativeDirectionType;
	}
	
	public EnumRule getObserveRelativeDirectionTypeRule() {
		return getObserveRelativeDirectionTypeAccess().getRule();
	}

	//enum RelativeTimeSignType:
	//	MINUS='-' | PLUS='+';
	public RelativeTimeSignTypeElements getRelativeTimeSignTypeAccess() {
		return eRelativeTimeSignType;
	}
	
	public EnumRule getRelativeTimeSignTypeRule() {
		return getRelativeTimeSignTypeAccess().getRule();
	}

	//enum TimeModifierType:
	//	YEAR='y' | MONTH='m' | WEEK='w' | DAY='d' | HOUR='h' | MINUTE='M' | SECOND='s' | MILLISECOND='S';
	public TimeModifierTypeElements getTimeModifierTypeAccess() {
		return eTimeModifierType;
	}
	
	public EnumRule getTimeModifierTypeRule() {
		return getTimeModifierTypeAccess().getRule();
	}

	//enum StatisticalAggregateType:
	//	MIN | MAX | GEOMEAN | N | SUM | SUMOFSQUARES | STDDEV |
	//	VAR | PERCENTILE | MEAN;
	public StatisticalAggregateTypeElements getStatisticalAggregateTypeAccess() {
		return eStatisticalAggregateType;
	}
	
	public EnumRule getStatisticalAggregateTypeRule() {
		return getStatisticalAggregateTypeAccess().getRule();
	}

	/// **
	// * Following lines of code are added during the Bachelor Thesis of Andreas Knapp at the University of Wuerzburg (Germany) to extend DQL with a "What if...?" feature
	// * / // @BachelorThesis_AndreasKnapp
	//WhatIfQuery:
	//	'WHAT IF' whatIfVariation=WhatIfVariation ('SELECT'
	//	metricReferenceClauses=MetricReferenceClauses forClause=ForClause)?
	//	filteringClause=FilteringClause? deltaClause=DeltaClause? usingClause=UsingClause;
	public WhatIfQueryElements getWhatIfQueryAccess() {
		return pWhatIfQuery;
	}
	
	public ParserRule getWhatIfQueryRule() {
		return getWhatIfQueryAccess().getRule();
	}

	//DeltaClause:
	//	'DELTA';
	public DeltaClauseElements getDeltaClauseAccess() {
		return pDeltaClause;
	}
	
	public ParserRule getDeltaClauseRule() {
		return getDeltaClauseAccess().getRule();
	}

	//WhatIfVariation:
	//	whatIfVariationClause+=WhatIfVariationClause (',' whatIfVariationClause+=WhatIfVariationClause)*;
	public WhatIfVariationElements getWhatIfVariationAccess() {
		return pWhatIfVariation;
	}
	
	public ParserRule getWhatIfVariationRule() {
		return getWhatIfVariationAccess().getRule();
	}

	//// Filtering Clause for WhatIfQuery, filtering Values (other filtering then filtering for lists)
	//FilteringClause:
	//	'FILTERING' (filteringRule=FilteringRule | filteringStrategy=FilteringStrategy);
	public FilteringClauseElements getFilteringClauseAccess() {
		return pFilteringClause;
	}
	
	public ParserRule getFilteringClauseRule() {
		return getFilteringClauseAccess().getRule();
	}

	////Mögliche Erweiterung mit "Filter-Subqueries"
	//// Connectorimplemented filtering strategy
	//FilteringStrategy:
	//	filteringStrategy=STRING;
	public FilteringStrategyElements getFilteringStrategyAccess() {
		return pFilteringStrategy;
	}
	
	public ParserRule getFilteringStrategyRule() {
		return getFilteringStrategyAccess().getRule();
	}

	//// User-defined ignoring for values. If % used, relativ value less then "value" are ignored, else absolut values
	//FilteringRule:
	//	filteringValue=VariableValue modifier='%'?;
	public FilteringRuleElements getFilteringRuleAccess() {
		return pFilteringRule;
	}
	
	public ParserRule getFilteringRuleRule() {
		return getFilteringRuleAccess().getRule();
	}

	//// changeable values for WhatIfQuery
	//WhatIfVariationClause:
	//	variationPoint=STRING values=WhatIfValueVariationClause;
	public WhatIfVariationClauseElements getWhatIfVariationClauseAccess() {
		return pWhatIfVariationClause;
	}
	
	public ParserRule getWhatIfVariationClauseRule() {
		return getWhatIfVariationClauseAccess().getRule();
	}

	//// Values can change like DoFVariationClauses (already exists) or like new ArithmeticClauses
	//WhatIfValueVariationClause:
	//	'<' variationClause+=(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction) (','
	//	variationClause+=(IntervalVariationClause | ValueVariationClause | ArithmeticClause | VariationInstruction)+)*
	//	'>'
	//	// DoFVariationClause already existing
	//;
	public WhatIfValueVariationClauseElements getWhatIfValueVariationClauseAccess() {
		return pWhatIfValueVariationClause;
	}
	
	public ParserRule getWhatIfValueVariationClauseRule() {
		return getWhatIfValueVariationClauseAccess().getRule();
	}

	//MultipleVariationInstruction:
	//	'<' multiVariation+=VariationInstruction (',' multiVariation+=VariationInstruction)* '>';
	public MultipleVariationInstructionElements getMultipleVariationInstructionAccess() {
		return pMultipleVariationInstruction;
	}
	
	public ParserRule getMultipleVariationInstructionRule() {
		return getMultipleVariationInstructionAccess().getRule();
	}

	//VariationInstruction:
	//	variation=ID ('(' argument=STRING ')');
	public VariationInstructionElements getVariationInstructionAccess() {
		return pVariationInstruction;
	}
	
	public ParserRule getVariationInstructionRule() {
		return getVariationInstructionAccess().getRule();
	}

	//// To enable things like 'var1' <ADD 10, ADD 10>
	//MultipleArithmeticClause:
	//	'<' multiClause+=ArithmeticClause (',' multiClause+=ArithmeticClause)* '>';
	public MultipleArithmeticClauseElements getMultipleArithmeticClauseAccess() {
		return pMultipleArithmeticClause;
	}
	
	public ParserRule getMultipleArithmeticClauseRule() {
		return getMultipleArithmeticClauseAccess().getRule();
	}

	//// To add Valuechangeing like "MULTIPLY 2" for example double usercount on a server
	//ArithmeticClause:
	//	mode=('ADD' | 'SUB' | 'MULTIPLY') value=VariableValue;
	public ArithmeticClauseElements getArithmeticClauseAccess() {
		return pArithmeticClause;
	}
	
	public ParserRule getArithmeticClauseRule() {
		return getArithmeticClauseAccess().getRule();
	}

	//// To Enable Integer and Double Values
	//VariableValue:
	//	intValue=INT | doubleValue=DOUBLE;
	public VariableValueElements getVariableValueAccess() {
		return pVariableValue;
	}
	
	public ParserRule getVariableValueRule() {
		return getVariableValueAccess().getRule();
	}

	//terminal DOUBLE returns ecore::EDouble:
	//	('0' | '1'..'9' '0'..'9'*) ('.' '0'..'9'+);
	public TerminalRule getDOUBLERule() {
		return tDOUBLE;
	} 

	//terminal ID:
	//	'^'? ('a'..'z' | 'A'..'Z' | '_') ('a'..'z' | 'A'..'Z' | '_' | '0'..'9')*;
	public TerminalRule getIDRule() {
		return gaTerminals.getIDRule();
	} 

	//terminal INT returns ecore::EInt:
	//	'0'..'9'+;
	public TerminalRule getINTRule() {
		return gaTerminals.getINTRule();
	} 

	//terminal STRING:
	//	'"' ('\\' . | !('\\' | '"'))* '"' | "'" ('\\' . | !('\\' | "'"))* "'";
	public TerminalRule getSTRINGRule() {
		return gaTerminals.getSTRINGRule();
	} 

	//terminal ML_COMMENT:
	//	'/ *'->'* /';
	public TerminalRule getML_COMMENTRule() {
		return gaTerminals.getML_COMMENTRule();
	} 

	//terminal SL_COMMENT:
	//	'//' !('\n' | '\r')* ('\r'? '\n')?;
	public TerminalRule getSL_COMMENTRule() {
		return gaTerminals.getSL_COMMENTRule();
	} 

	//terminal WS:
	//	' ' | '\t' | '\r' | '\n'+;
	public TerminalRule getWSRule() {
		return gaTerminals.getWSRule();
	} 

	//terminal ANY_OTHER:
	//	.;
	public TerminalRule getANY_OTHERRule() {
		return gaTerminals.getANY_OTHERRule();
	} 
}
